searchData={"items":[{"type":"module","title":"ElixirScope","doc":"ElixirScope - AI-Powered Execution Cinema Debugger\n\nElixirScope provides deep observability and \"execution cinema\" capabilities \nfor Elixir applications. It enables time-travel debugging, comprehensive\nevent capture, and AI-powered analysis of concurrent systems.","ref":"ElixirScope.html"},{"type":"module","title":"Features - ElixirScope","doc":"- **Total Recall**: Capture complete execution history with minimal overhead\n- **AI-Driven Instrumentation**: Intelligent, automatic code instrumentation\n- **Execution Cinema**: Visual time-travel debugging interface\n- **Multi-Dimensional Analysis**: Correlate events across time, processes, state, and causality\n- **Performance Aware**: <1% overhead in production with smart sampling","ref":"ElixirScope.html#module-features"},{"type":"module","title":"Quick Start - ElixirScope","doc":"# Start ElixirScope with default configuration\n    ElixirScope.start()\n\n    # Configure for development with full tracing\n    ElixirScope.start(strategy: :full_trace)\n\n    # Query captured events\n    events = ElixirScope.get_events(pid: self(), limit: 100)\n\n    # Stop tracing\n    ElixirScope.stop()","ref":"ElixirScope.html#module-quick-start"},{"type":"module","title":"Configuration - ElixirScope","doc":"ElixirScope can be configured via `config.exs`:\n\n    config :elixir_scope,\n      ai: [\n        planning: [\n          default_strategy: :balanced,\n          performance_target: 0.01,\n          sampling_rate: 1.0\n        ]\n      ],\n      capture: [\n        ring_buffer: [\n          size: 1_048_576,\n          max_events: 100_000\n        ]\n      ]\n\nSee `ElixirScope.Config` for all available configuration options.","ref":"ElixirScope.html#module-configuration"},{"type":"function","title":"ElixirScope.analyze_codebase/1","doc":"Manually triggers AI analysis of the current codebase.\n\nThis can be useful to refresh instrumentation plans after code changes\nor to analyze new modules.","ref":"ElixirScope.html#analyze_codebase/1"},{"type":"function","title":"Examples - ElixirScope.analyze_codebase/1","doc":"# Analyze entire codebase\n    ElixirScope.analyze_codebase()\n\n    # Analyze specific modules\n    ElixirScope.analyze_codebase(modules: [MyApp.NewModule])","ref":"ElixirScope.html#analyze_codebase/1-examples"},{"type":"type","title":"ElixirScope.event_query/0","doc":"","ref":"ElixirScope.html#t:event_query/0"},{"type":"function","title":"ElixirScope.get_config/0","doc":"Gets the current configuration.","ref":"ElixirScope.html#get_config/0"},{"type":"function","title":"Examples - ElixirScope.get_config/0","doc":"config = ElixirScope.get_config()\n    sampling_rate = config.ai.planning.sampling_rate","ref":"ElixirScope.html#get_config/0-examples"},{"type":"function","title":"ElixirScope.get_events/1","doc":"Queries captured events based on the given criteria.","ref":"ElixirScope.html#get_events/1"},{"type":"function","title":"Query Options - ElixirScope.get_events/1","doc":"- `:pid` - Filter by process ID (`:all` for all processes)\n- `:event_type` - Filter by event type (`:all` for all types)\n- `:since` - Events since timestamp or DateTime\n- `:until` - Events until timestamp or DateTime  \n- `:limit` - Maximum number of events to return","ref":"ElixirScope.html#get_events/1-query-options"},{"type":"function","title":"Examples - ElixirScope.get_events/1","doc":"# Get last 100 events for current process\n    events = ElixirScope.get_events(pid: self(), limit: 100)\n\n    # Get all function entry events\n    events = ElixirScope.get_events(event_type: :function_entry)\n\n    # Get events from the last minute\n    since = DateTime.utc_now() |> DateTime.add(-60, :second)\n    events = ElixirScope.get_events(since: since)","ref":"ElixirScope.html#get_events/1-examples"},{"type":"function","title":"ElixirScope.get_message_flow/3","doc":"Gets message flow between two processes.\n\nReturns all messages sent between the specified processes within\nthe given time range.","ref":"ElixirScope.html#get_message_flow/3"},{"type":"function","title":"Examples - ElixirScope.get_message_flow/3","doc":"# Get all messages between two processes\n    messages = ElixirScope.get_message_flow(sender_pid, receiver_pid)\n\n    # Get messages in a time range\n    messages = ElixirScope.get_message_flow(\n      sender_pid, \n      receiver_pid, \n      since: start_time, \n      until: end_time\n    )","ref":"ElixirScope.html#get_message_flow/3-examples"},{"type":"function","title":"ElixirScope.get_state_at/2","doc":"Reconstructs the state of a GenServer at a specific timestamp.","ref":"ElixirScope.html#get_state_at/2"},{"type":"function","title":"Examples - ElixirScope.get_state_at/2","doc":"timestamp = ElixirScope.Utils.monotonic_timestamp()\n    state = ElixirScope.get_state_at(pid, timestamp)","ref":"ElixirScope.html#get_state_at/2-examples"},{"type":"function","title":"ElixirScope.get_state_history/1","doc":"Gets the state history for a GenServer process.\n\nReturns a chronological list of state changes for the given process.","ref":"ElixirScope.html#get_state_history/1"},{"type":"function","title":"Examples - ElixirScope.get_state_history/1","doc":"# Get state history for a GenServer\n    history = ElixirScope.get_state_history(pid)\n\n    # Get state at a specific time\n    state = ElixirScope.get_state_at(pid, timestamp)","ref":"ElixirScope.html#get_state_history/1-examples"},{"type":"function","title":"ElixirScope.running?/0","doc":"Checks if ElixirScope is currently running.","ref":"ElixirScope.html#running?/0"},{"type":"function","title":"Examples - ElixirScope.running?/0","doc":"if ElixirScope.running?() do\n      # ElixirScope is active\n    end","ref":"ElixirScope.html#running?/0-examples"},{"type":"function","title":"ElixirScope.start/1","doc":"Starts ElixirScope with the given options.","ref":"ElixirScope.html#start/1"},{"type":"function","title":"Options - ElixirScope.start/1","doc":"- `:strategy` - Instrumentation strategy (`:minimal`, `:balanced`, `:full_trace`)\n- `:sampling_rate` - Event sampling rate (0.0 to 1.0)\n- `:modules` - Specific modules to instrument (overrides AI planning)\n- `:exclude_modules` - Modules to exclude from instrumentation","ref":"ElixirScope.html#start/1-options"},{"type":"function","title":"Examples - ElixirScope.start/1","doc":"# Start with default configuration\n    ElixirScope.start()\n\n    # Start with full tracing for debugging\n    ElixirScope.start(strategy: :full_trace, sampling_rate: 1.0)\n\n    # Start with minimal overhead for production\n    ElixirScope.start(strategy: :minimal, sampling_rate: 0.1)\n\n    # Instrument only specific modules\n    ElixirScope.start(modules: [MyApp.Worker, MyApp.Server])","ref":"ElixirScope.html#start/1-examples"},{"type":"type","title":"ElixirScope.start_option/0","doc":"","ref":"ElixirScope.html#t:start_option/0"},{"type":"function","title":"ElixirScope.status/0","doc":"Gets the current status of ElixirScope.\n\nReturns a map with information about:\n- Whether ElixirScope is running\n- Current configuration\n- Performance statistics\n- Storage usage","ref":"ElixirScope.html#status/0"},{"type":"function","title":"Examples - ElixirScope.status/0","doc":"status = ElixirScope.status()\n    # %{\n    #   running: true,\n    #   config: %{...},\n    #   stats: %{events_captured: 12345, ...},\n    #   storage: %{hot_events: 5000, memory_usage: \"2.1 MB\"}\n    # }","ref":"ElixirScope.html#status/0-examples"},{"type":"function","title":"ElixirScope.stop/0","doc":"Stops ElixirScope and all tracing.","ref":"ElixirScope.html#stop/0"},{"type":"function","title":"Examples - ElixirScope.stop/0","doc":"ElixirScope.stop()","ref":"ElixirScope.html#stop/0-examples"},{"type":"function","title":"ElixirScope.update_config/2","doc":"Updates configuration at runtime.\n\nOnly certain configuration paths can be updated at runtime for safety.","ref":"ElixirScope.html#update_config/2"},{"type":"function","title":"Examples - ElixirScope.update_config/2","doc":"# Update sampling rate\n    ElixirScope.update_config([:ai, :planning, :sampling_rate], 0.8)\n\n    # Update query timeout\n    ElixirScope.update_config([:interface, :query_timeout], 10_000)","ref":"ElixirScope.html#update_config/2-examples"},{"type":"function","title":"ElixirScope.update_instrumentation/1","doc":"Updates the instrumentation plan at runtime.\n\nThis allows changing which modules and functions are being traced\nwithout restarting the application.","ref":"ElixirScope.html#update_instrumentation/1"},{"type":"function","title":"Examples - ElixirScope.update_instrumentation/1","doc":"# Change sampling rate\n    ElixirScope.update_instrumentation(sampling_rate: 0.5)\n\n    # Add modules to trace\n    ElixirScope.update_instrumentation(add_modules: [MyApp.NewModule])\n\n    # Change strategy  \n    ElixirScope.update_instrumentation(strategy: :full_trace)","ref":"ElixirScope.html#update_instrumentation/1-examples"},{"type":"module","title":"ElixirScope.AI.Analysis.IntelligentCodeAnalyzer","doc":"AI-powered code analyzer that provides deep semantic analysis, quality assessment,\nand intelligent refactoring suggestions using advanced pattern recognition.\n\nThis module implements:\n- Semantic code understanding using AST analysis\n- Multi-dimensional code quality scoring\n- Context-aware refactoring suggestions\n- Design pattern and anti-pattern recognition","ref":"ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.html"},{"type":"function","title":"ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.analyze_semantics/1","doc":"Analyzes code semantics and provides deep understanding insights.","ref":"ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.html#analyze_semantics/1"},{"type":"function","title":"Examples - ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.analyze_semantics/1","doc":"iex> code_ast = quote do: def hello(name), do: \"Hello \" <> name\n    iex> IntelligentCodeAnalyzer.analyze_semantics(code_ast)\n    {:ok, %{\n      complexity: %{cyclomatic: 1, cognitive: 1},\n      patterns: [:simple_function],\n      semantic_tags: [:greeting, :user_interaction],\n      maintainability_score: 0.95\n    }}","ref":"ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.html#analyze_semantics/1-examples"},{"type":"function","title":"ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.assess_quality/1","doc":"Assesses code quality across multiple dimensions.","ref":"ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.html#assess_quality/1"},{"type":"function","title":"Examples - ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.assess_quality/1","doc":"iex> module_code = \"defmodule MyModule do...\"\n    iex> IntelligentCodeAnalyzer.assess_quality(module_code)\n    {:ok, %{\n      overall_score: 0.87,\n      dimensions: %{\n        readability: 0.9,\n        maintainability: 0.85,\n        testability: 0.8,\n        performance: 0.9\n      },\n      issues: [%{type: :warning, message: \"Long function detected\"}]\n    }}","ref":"ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.html#assess_quality/1-examples"},{"type":"function","title":"ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.html#child_spec/1"},{"type":"function","title":"ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.get_stats/0","doc":"Gets current analyzer statistics and performance metrics.","ref":"ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.html#get_stats/0"},{"type":"function","title":"ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.identify_patterns/1","doc":"Identifies design patterns and anti-patterns in code.","ref":"ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.html#identify_patterns/1"},{"type":"function","title":"Examples - ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.identify_patterns/1","doc":"iex> IntelligentCodeAnalyzer.identify_patterns(module_ast)\n    {:ok, %{\n      patterns: [\n        %{type: :observer, confidence: 0.9, location: {:function, :notify, 1}},\n        %{type: :factory, confidence: 0.7, location: {:function, :create, 2}}\n      ],\n      anti_patterns: [\n        %{type: :god_object, confidence: 0.6, severity: :medium}\n      ]\n    }}","ref":"ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.html#identify_patterns/1-examples"},{"type":"function","title":"ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.start_link/1","doc":"Starts the IntelligentCodeAnalyzer GenServer.","ref":"ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.html#start_link/1"},{"type":"function","title":"ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.suggest_refactoring/1","doc":"Generates intelligent refactoring suggestions based on code analysis.","ref":"ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.html#suggest_refactoring/1"},{"type":"function","title":"Examples - ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.suggest_refactoring/1","doc":"iex> code_section = \"def process(data) do...\"\n    iex> IntelligentCodeAnalyzer.suggest_refactoring(code_section)\n    {:ok, [\n      %{\n        type: :extract_function,\n        confidence: 0.8,\n        description: \"Extract validation logic into separate function\",\n        before: \"...\",\n        after: \"...\"\n      }\n    ]}","ref":"ElixirScope.AI.Analysis.IntelligentCodeAnalyzer.html#suggest_refactoring/1-examples"},{"type":"module","title":"ElixirScope.AI.CodeAnalyzer","doc":"AI-powered code analysis engine for ElixirScope.\n\nAnalyzes Elixir codebases to understand structure, complexity, and patterns\nto generate intelligent instrumentation recommendations.\n\nInitially implemented with rule-based heuristics, designed to be enhanced\nwith actual LLM integration.","ref":"ElixirScope.AI.CodeAnalyzer.html"},{"type":"function","title":"ElixirScope.AI.CodeAnalyzer.analyze_code/1","doc":"Analyzes a single piece of Elixir code and returns analysis results.","ref":"ElixirScope.AI.CodeAnalyzer.html#analyze_code/1"},{"type":"function","title":"ElixirScope.AI.CodeAnalyzer.analyze_function/1","doc":"Analyzes a single function for complexity and performance characteristics.","ref":"ElixirScope.AI.CodeAnalyzer.html#analyze_function/1"},{"type":"function","title":"ElixirScope.AI.CodeAnalyzer.analyze_message_flows/1","doc":"Analyzes message flow patterns across modules.","ref":"ElixirScope.AI.CodeAnalyzer.html#analyze_message_flows/1"},{"type":"function","title":"ElixirScope.AI.CodeAnalyzer.analyze_project/1","doc":"Analyzes a complete Elixir project directory.","ref":"ElixirScope.AI.CodeAnalyzer.html#analyze_project/1"},{"type":"function","title":"ElixirScope.AI.CodeAnalyzer.generate_instrumentation_plan/1","doc":"Generates an instrumentation plan for a project.","ref":"ElixirScope.AI.CodeAnalyzer.html#generate_instrumentation_plan/1"},{"type":"module","title":"ElixirScope.AI.ComplexityAnalyzer","doc":"Analyzes code complexity for Elixir modules and functions.\n\nProvides rule-based complexity analysis to inform instrumentation decisions.\nInitially implemented with heuristics, designed to be enhanced with ML models.","ref":"ElixirScope.AI.ComplexityAnalyzer.html"},{"type":"function","title":"ElixirScope.AI.ComplexityAnalyzer.analyze_module/1","doc":"Analyzes complexity for an entire module.","ref":"ElixirScope.AI.ComplexityAnalyzer.html#analyze_module/1"},{"type":"function","title":"ElixirScope.AI.ComplexityAnalyzer.analyze_state_complexity/1","doc":"Analyzes state complexity for stateful modules (GenServer, Agent, etc.).","ref":"ElixirScope.AI.ComplexityAnalyzer.html#analyze_state_complexity/1"},{"type":"function","title":"ElixirScope.AI.ComplexityAnalyzer.calculate_complexity/1","doc":"Calculates complexity for a single AST node (function or expression).","ref":"ElixirScope.AI.ComplexityAnalyzer.html#calculate_complexity/1"},{"type":"function","title":"ElixirScope.AI.ComplexityAnalyzer.is_performance_critical?/1","doc":"Determines if a module or function is performance critical.","ref":"ElixirScope.AI.ComplexityAnalyzer.html#is_performance_critical?/1"},{"type":"module","title":"ElixirScope.AI.LLM.Client","doc":"Main LLM client interface for ElixirScope.\n\nProvides a simple, unified API for code analysis, error explanation,\nand fix suggestions. Handles provider selection and automatic fallback\nfrom Vertex/Gemini to Mock provider on errors.","ref":"ElixirScope.AI.LLM.Client.html"},{"type":"function","title":"ElixirScope.AI.LLM.Client.analyze_code/2","doc":"Analyzes code using the configured LLM provider.","ref":"ElixirScope.AI.LLM.Client.html#analyze_code/2"},{"type":"function","title":"Examples - ElixirScope.AI.LLM.Client.analyze_code/2","doc":"iex> ElixirScope.AI.LLM.Client.analyze_code(\"def hello, do: :world\")\n    %ElixirScope.AI.LLM.Response{\n      text: \"This is a simple function definition...\",\n      success: true,\n      provider: :vertex\n    }","ref":"ElixirScope.AI.LLM.Client.html#analyze_code/2-examples"},{"type":"function","title":"ElixirScope.AI.LLM.Client.explain_error/2","doc":"Explains an error using the configured LLM provider.","ref":"ElixirScope.AI.LLM.Client.html#explain_error/2"},{"type":"function","title":"Examples - ElixirScope.AI.LLM.Client.explain_error/2","doc":"iex> ElixirScope.AI.LLM.Client.explain_error(\"undefined function foo/0\")\n    %ElixirScope.AI.LLM.Response{\n      text: \"This error occurs when...\",\n      success: true,\n      provider: :vertex\n    }","ref":"ElixirScope.AI.LLM.Client.html#explain_error/2-examples"},{"type":"function","title":"ElixirScope.AI.LLM.Client.get_provider_status/0","doc":"Gets the current provider configuration.","ref":"ElixirScope.AI.LLM.Client.html#get_provider_status/0"},{"type":"function","title":"ElixirScope.AI.LLM.Client.suggest_fix/2","doc":"Suggests a fix using the configured LLM provider.","ref":"ElixirScope.AI.LLM.Client.html#suggest_fix/2"},{"type":"function","title":"Examples - ElixirScope.AI.LLM.Client.suggest_fix/2","doc":"iex> ElixirScope.AI.LLM.Client.suggest_fix(\"function is too complex\")\n    %ElixirScope.AI.LLM.Response{\n      text: \"To reduce complexity, consider...\",\n      success: true,\n      provider: :vertex\n    }","ref":"ElixirScope.AI.LLM.Client.html#suggest_fix/2-examples"},{"type":"function","title":"ElixirScope.AI.LLM.Client.test_connection/0","doc":"Tests connectivity to the primary provider.","ref":"ElixirScope.AI.LLM.Client.html#test_connection/0"},{"type":"module","title":"ElixirScope.AI.LLM.Config","doc":"Configuration management for LLM providers.\n\nHandles API keys, provider selection, and other configuration\noptions for the LLM integration layer.","ref":"ElixirScope.AI.LLM.Config.html"},{"type":"function","title":"ElixirScope.AI.LLM.Config.debug_config/0","doc":"Gets all configuration as a map for debugging.\nNote: API keys and credentials are masked for security.","ref":"ElixirScope.AI.LLM.Config.html#debug_config/0"},{"type":"function","title":"ElixirScope.AI.LLM.Config.get_fallback_provider/0","doc":"Gets the fallback provider to use when primary fails.","ref":"ElixirScope.AI.LLM.Config.html#get_fallback_provider/0"},{"type":"function","title":"ElixirScope.AI.LLM.Config.get_gemini_api_key/0","doc":"Gets the Gemini API key from configuration or environment.\n\nChecks in order:\n1. Application config: config :elixir_scope, :gemini_api_key\n2. Environment variable: GEMINI_API_KEY\n3. Returns nil if not found","ref":"ElixirScope.AI.LLM.Config.html#get_gemini_api_key/0"},{"type":"function","title":"ElixirScope.AI.LLM.Config.get_gemini_base_url/0","doc":"Gets the Gemini API base URL.","ref":"ElixirScope.AI.LLM.Config.html#get_gemini_base_url/0"},{"type":"function","title":"ElixirScope.AI.LLM.Config.get_gemini_model/0","doc":"Gets the Gemini model to use.","ref":"ElixirScope.AI.LLM.Config.html#get_gemini_model/0"},{"type":"function","title":"ElixirScope.AI.LLM.Config.get_primary_provider/0","doc":"Gets the primary provider to use.\n\nReturns :vertex if Vertex credentials are available, :gemini if API key is available, otherwise :mock.\nCan be overridden with config or environment variable.\nIn test environment, always returns :mock unless explicitly overridden.","ref":"ElixirScope.AI.LLM.Config.html#get_primary_provider/0"},{"type":"function","title":"ElixirScope.AI.LLM.Config.get_request_timeout/0","doc":"Gets the request timeout in milliseconds.","ref":"ElixirScope.AI.LLM.Config.html#get_request_timeout/0"},{"type":"function","title":"ElixirScope.AI.LLM.Config.get_vertex_base_url/0","doc":"Gets the Vertex AI base URL.","ref":"ElixirScope.AI.LLM.Config.html#get_vertex_base_url/0"},{"type":"function","title":"ElixirScope.AI.LLM.Config.get_vertex_credentials/0","doc":"Gets the Vertex AI credentials from the JSON file.\n\nReturns a map with the parsed JSON credentials or nil if file not found/invalid.","ref":"ElixirScope.AI.LLM.Config.html#get_vertex_credentials/0"},{"type":"function","title":"ElixirScope.AI.LLM.Config.get_vertex_json_file/0","doc":"Gets the Vertex AI JSON credentials file path.\n\nChecks in order:\n1. Environment variable: VERTEX_JSON_FILE\n2. Application config: config :elixir_scope, :vertex_json_file\n3. Returns nil if not found","ref":"ElixirScope.AI.LLM.Config.html#get_vertex_json_file/0"},{"type":"function","title":"ElixirScope.AI.LLM.Config.get_vertex_model/0","doc":"Gets the Vertex AI model to use.","ref":"ElixirScope.AI.LLM.Config.html#get_vertex_model/0"},{"type":"function","title":"ElixirScope.AI.LLM.Config.valid_config?/1","doc":"Checks if the configuration is valid for the given provider.","ref":"ElixirScope.AI.LLM.Config.html#valid_config?/1"},{"type":"behaviour","title":"ElixirScope.AI.LLM.Provider","doc":"Behaviour defining the common interface for all LLM providers in ElixirScope.\n\nThis ensures all providers (Gemini, Mock, future providers) implement\nthe same API, allowing for easy switching and fallback between providers.","ref":"ElixirScope.AI.LLM.Provider.html"},{"type":"callback","title":"ElixirScope.AI.LLM.Provider.analyze_code/2","doc":"Analyzes code using the provider's LLM.","ref":"ElixirScope.AI.LLM.Provider.html#c:analyze_code/2"},{"type":"callback","title":"Parameters - ElixirScope.AI.LLM.Provider.analyze_code/2","doc":"- `code`: The Elixir code to analyze\n- `context`: Additional context for the analysis (metadata, file info, etc.)","ref":"ElixirScope.AI.LLM.Provider.html#c:analyze_code/2-parameters"},{"type":"callback","title":"Returns - ElixirScope.AI.LLM.Provider.analyze_code/2","doc":"- `Response.t()`: Standardized response with analysis results","ref":"ElixirScope.AI.LLM.Provider.html#c:analyze_code/2-returns"},{"type":"callback","title":"ElixirScope.AI.LLM.Provider.configured?/0","doc":"Checks if the provider is properly configured and ready to use.","ref":"ElixirScope.AI.LLM.Provider.html#c:configured?/0"},{"type":"callback","title":"Returns - ElixirScope.AI.LLM.Provider.configured?/0","doc":"- `boolean()`: true if provider is configured, false otherwise","ref":"ElixirScope.AI.LLM.Provider.html#c:configured?/0-returns"},{"type":"callback","title":"ElixirScope.AI.LLM.Provider.explain_error/2","doc":"Explains an error using the provider's LLM.","ref":"ElixirScope.AI.LLM.Provider.html#c:explain_error/2"},{"type":"callback","title":"Parameters - ElixirScope.AI.LLM.Provider.explain_error/2","doc":"- `error_message`: The error message to explain\n- `context`: Additional context (code, stack trace, etc.)","ref":"ElixirScope.AI.LLM.Provider.html#c:explain_error/2-parameters"},{"type":"callback","title":"Returns - ElixirScope.AI.LLM.Provider.explain_error/2","doc":"- `Response.t()`: Standardized response with error explanation","ref":"ElixirScope.AI.LLM.Provider.html#c:explain_error/2-returns"},{"type":"callback","title":"ElixirScope.AI.LLM.Provider.provider_name/0","doc":"Returns the provider's name as an atom.","ref":"ElixirScope.AI.LLM.Provider.html#c:provider_name/0"},{"type":"callback","title":"Returns - ElixirScope.AI.LLM.Provider.provider_name/0","doc":"- `atom()`: Provider identifier (e.g., :gemini, :mock, :anthropic)","ref":"ElixirScope.AI.LLM.Provider.html#c:provider_name/0-returns"},{"type":"callback","title":"ElixirScope.AI.LLM.Provider.suggest_fix/2","doc":"Suggests a fix for a problem using the provider's LLM.","ref":"ElixirScope.AI.LLM.Provider.html#c:suggest_fix/2"},{"type":"callback","title":"Parameters - ElixirScope.AI.LLM.Provider.suggest_fix/2","doc":"- `problem_description`: Description of the problem to fix\n- `context`: Additional context (code, error details, etc.)","ref":"ElixirScope.AI.LLM.Provider.html#c:suggest_fix/2-parameters"},{"type":"callback","title":"Returns - ElixirScope.AI.LLM.Provider.suggest_fix/2","doc":"- `Response.t()`: Standardized response with fix suggestions","ref":"ElixirScope.AI.LLM.Provider.html#c:suggest_fix/2-returns"},{"type":"callback","title":"ElixirScope.AI.LLM.Provider.test_connection/0","doc":"Tests the provider's connectivity and basic functionality.","ref":"ElixirScope.AI.LLM.Provider.html#c:test_connection/0"},{"type":"callback","title":"Returns - ElixirScope.AI.LLM.Provider.test_connection/0","doc":"- `Response.t()`: Response indicating success or failure of connection test","ref":"ElixirScope.AI.LLM.Provider.html#c:test_connection/0-returns"},{"type":"module","title":"ElixirScope.AI.LLM.Providers.Gemini","doc":"Gemini LLM provider for real AI-powered code analysis.\n\nMakes HTTP requests to Google's Gemini API for code analysis,\nerror explanation, and fix suggestions.","ref":"ElixirScope.AI.LLM.Providers.Gemini.html"},{"type":"function","title":"ElixirScope.AI.LLM.Providers.Gemini.analyze_code/2","doc":"Analyzes code using Gemini API.","ref":"ElixirScope.AI.LLM.Providers.Gemini.html#analyze_code/2"},{"type":"function","title":"ElixirScope.AI.LLM.Providers.Gemini.explain_error/2","doc":"Explains an error using Gemini API.","ref":"ElixirScope.AI.LLM.Providers.Gemini.html#explain_error/2"},{"type":"function","title":"ElixirScope.AI.LLM.Providers.Gemini.suggest_fix/2","doc":"Suggests a fix using Gemini API.","ref":"ElixirScope.AI.LLM.Providers.Gemini.html#suggest_fix/2"},{"type":"module","title":"ElixirScope.AI.LLM.Providers.Mock","doc":"Mock LLM provider for testing and fallback scenarios.\n\nProvides realistic responses without external API calls,\nuseful for testing, development, and when real providers fail.","ref":"ElixirScope.AI.LLM.Providers.Mock.html"},{"type":"function","title":"ElixirScope.AI.LLM.Providers.Mock.analyze_code/2","doc":"Analyzes code and returns a mock analysis.","ref":"ElixirScope.AI.LLM.Providers.Mock.html#analyze_code/2"},{"type":"function","title":"ElixirScope.AI.LLM.Providers.Mock.explain_error/2","doc":"Explains an error and returns a mock explanation.","ref":"ElixirScope.AI.LLM.Providers.Mock.html#explain_error/2"},{"type":"function","title":"ElixirScope.AI.LLM.Providers.Mock.simulate_error/1","doc":"Simulates an error response for testing error handling.","ref":"ElixirScope.AI.LLM.Providers.Mock.html#simulate_error/1"},{"type":"function","title":"ElixirScope.AI.LLM.Providers.Mock.suggest_fix/2","doc":"Suggests a fix and returns a mock suggestion.","ref":"ElixirScope.AI.LLM.Providers.Mock.html#suggest_fix/2"},{"type":"module","title":"ElixirScope.AI.LLM.Providers.Vertex","doc":"Vertex AI LLM provider for real AI-powered code analysis.\n\nMakes HTTP requests to Google's Vertex AI API using service account\nauthentication for code analysis, error explanation, and fix suggestions.","ref":"ElixirScope.AI.LLM.Providers.Vertex.html"},{"type":"function","title":"ElixirScope.AI.LLM.Providers.Vertex.analyze_code/2","doc":"Analyzes code using Vertex AI API.","ref":"ElixirScope.AI.LLM.Providers.Vertex.html#analyze_code/2"},{"type":"function","title":"ElixirScope.AI.LLM.Providers.Vertex.explain_error/2","doc":"Explains an error using Vertex AI API.","ref":"ElixirScope.AI.LLM.Providers.Vertex.html#explain_error/2"},{"type":"function","title":"ElixirScope.AI.LLM.Providers.Vertex.suggest_fix/2","doc":"Suggests a fix using Vertex AI API.","ref":"ElixirScope.AI.LLM.Providers.Vertex.html#suggest_fix/2"},{"type":"module","title":"ElixirScope.AI.LLM.Response","doc":"Standardized response format for LLM providers.\n\nThis module defines a common response structure that all providers\n(Gemini, Mock, future providers) must return, ensuring consistent\nhandling throughout ElixirScope.","ref":"ElixirScope.AI.LLM.Response.html"},{"type":"function","title":"ElixirScope.AI.LLM.Response.error/3","doc":"Creates an error response.","ref":"ElixirScope.AI.LLM.Response.html#error/3"},{"type":"function","title":"Examples - ElixirScope.AI.LLM.Response.error/3","doc":"iex> ElixirScope.AI.LLM.Response.error(\"API timeout\", :gemini)\n    %ElixirScope.AI.LLM.Response{\n      text: \"\",\n      confidence: 0.0,\n      provider: :gemini,\n      success: false,\n      error: \"API timeout\"\n    }","ref":"ElixirScope.AI.LLM.Response.html#error/3-examples"},{"type":"function","title":"ElixirScope.AI.LLM.Response.get_error/1","doc":"Gets the error message, returning nil for successful responses.","ref":"ElixirScope.AI.LLM.Response.html#get_error/1"},{"type":"function","title":"ElixirScope.AI.LLM.Response.get_text/1","doc":"Gets the response text, returning empty string for errors.","ref":"ElixirScope.AI.LLM.Response.html#get_text/1"},{"type":"function","title":"ElixirScope.AI.LLM.Response.success/4","doc":"Creates a successful response.","ref":"ElixirScope.AI.LLM.Response.html#success/4"},{"type":"function","title":"Examples - ElixirScope.AI.LLM.Response.success/4","doc":"iex> ElixirScope.AI.LLM.Response.success(\"Analysis complete\", 0.95, :gemini)\n    %ElixirScope.AI.LLM.Response{\n      text: \"Analysis complete\",\n      confidence: 0.95,\n      provider: :gemini,\n      success: true,\n      error: nil\n    }","ref":"ElixirScope.AI.LLM.Response.html#success/4-examples"},{"type":"function","title":"ElixirScope.AI.LLM.Response.success?/1","doc":"Checks if the response is successful.","ref":"ElixirScope.AI.LLM.Response.html#success?/1"},{"type":"type","title":"ElixirScope.AI.LLM.Response.t/0","doc":"","ref":"ElixirScope.AI.LLM.Response.html#t:t/0"},{"type":"module","title":"ElixirScope.AI.Orchestrator","doc":"AI orchestrator for ElixirScope instrumentation planning.\n\nCoordinates between different AI components to analyze code and generate\ninstrumentation plans. Acts as the central coordinator for AI-driven decisions.","ref":"ElixirScope.AI.Orchestrator.html"},{"type":"function","title":"ElixirScope.AI.Orchestrator.analyze_and_plan/1","doc":"Analyzes a project and generates a comprehensive instrumentation plan.","ref":"ElixirScope.AI.Orchestrator.html#analyze_and_plan/1"},{"type":"function","title":"ElixirScope.AI.Orchestrator.analyze_runtime_feedback/1","doc":"Analyzes runtime performance data and suggests plan adjustments.","ref":"ElixirScope.AI.Orchestrator.html#analyze_runtime_feedback/1"},{"type":"function","title":"ElixirScope.AI.Orchestrator.get_instrumentation_plan/0","doc":"Gets the current instrumentation plan if one exists.","ref":"ElixirScope.AI.Orchestrator.html#get_instrumentation_plan/0"},{"type":"function","title":"ElixirScope.AI.Orchestrator.plan_for_module/1","doc":"Generates a simple instrumentation plan for a specific module.","ref":"ElixirScope.AI.Orchestrator.html#plan_for_module/1"},{"type":"function","title":"ElixirScope.AI.Orchestrator.update_plan/1","doc":"Updates an existing instrumentation plan with new analysis data.","ref":"ElixirScope.AI.Orchestrator.html#update_plan/1"},{"type":"function","title":"ElixirScope.AI.Orchestrator.validate_plan/1","doc":"Validates an instrumentation plan for correctness and performance impact.","ref":"ElixirScope.AI.Orchestrator.html#validate_plan/1"},{"type":"module","title":"ElixirScope.AI.PatternRecognizer","doc":"Pattern recognition for Elixir code structures.\n\nIdentifies common OTP patterns, Phoenix patterns, and architectural structures\nto inform instrumentation decisions.","ref":"ElixirScope.AI.PatternRecognizer.html"},{"type":"function","title":"ElixirScope.AI.PatternRecognizer.extract_patterns/1","doc":"Extracts patterns and characteristics from module AST.","ref":"ElixirScope.AI.PatternRecognizer.html#extract_patterns/1"},{"type":"function","title":"ElixirScope.AI.PatternRecognizer.identify_module_type/1","doc":"Identifies the primary type of an Elixir module based on its AST.","ref":"ElixirScope.AI.PatternRecognizer.html#identify_module_type/1"},{"type":"module","title":"ElixirScope.AI.Predictive.ExecutionPredictor","doc":"Predicts execution paths, resource usage, and concurrency impacts based on \nhistorical execution data and code analysis.\n\nThis module implements machine learning models to:\n- Predict likely execution paths for function calls\n- Estimate resource requirements (memory, CPU, I/O)\n- Analyze concurrency bottlenecks and scaling factors\n- Identify edge cases and rarely-executed code paths","ref":"ElixirScope.AI.Predictive.ExecutionPredictor.html"},{"type":"function","title":"ElixirScope.AI.Predictive.ExecutionPredictor.analyze_concurrency_impact/1","doc":"Analyzes concurrency impact for a function signature.","ref":"ElixirScope.AI.Predictive.ExecutionPredictor.html#analyze_concurrency_impact/1"},{"type":"function","title":"Examples - ElixirScope.AI.Predictive.ExecutionPredictor.analyze_concurrency_impact/1","doc":"iex> ExecutionPredictor.analyze_concurrency_impact({:handle_call, 3})\n    {:ok, %{\n      bottleneck_risk: 0.7,\n      recommended_pool_size: 10,\n      scaling_factor: 0.85,\n      contention_points: [:database_access, :file_io]\n    }}","ref":"ElixirScope.AI.Predictive.ExecutionPredictor.html#analyze_concurrency_impact/1-examples"},{"type":"function","title":"ElixirScope.AI.Predictive.ExecutionPredictor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ElixirScope.AI.Predictive.ExecutionPredictor.html#child_spec/1"},{"type":"function","title":"ElixirScope.AI.Predictive.ExecutionPredictor.get_stats/0","doc":"Gets current model statistics and performance metrics.","ref":"ElixirScope.AI.Predictive.ExecutionPredictor.html#get_stats/0"},{"type":"function","title":"ElixirScope.AI.Predictive.ExecutionPredictor.predict_batch/1","doc":"Performs batch predictions for multiple contexts.","ref":"ElixirScope.AI.Predictive.ExecutionPredictor.html#predict_batch/1"},{"type":"function","title":"ElixirScope.AI.Predictive.ExecutionPredictor.predict_path/3","doc":"Predicts the execution path for a given function call.\n\nReturns a prediction with confidence scores and alternative paths.","ref":"ElixirScope.AI.Predictive.ExecutionPredictor.html#predict_path/3"},{"type":"function","title":"Examples - ElixirScope.AI.Predictive.ExecutionPredictor.predict_path/3","doc":"iex> ExecutionPredictor.predict_path(MyModule, :my_function, [arg1, arg2])\n    {:ok, %{\n      predicted_path: [:entry, :condition_check, :main_logic, :exit],\n      confidence: 0.85,\n      alternatives: [\n        %{path: [:entry, :error_handling, :exit], probability: 0.15}\n      ],\n      edge_cases: [\n        %{type: :nil_input, probability: 0.02}\n      ]\n    }}","ref":"ElixirScope.AI.Predictive.ExecutionPredictor.html#predict_path/3-examples"},{"type":"function","title":"ElixirScope.AI.Predictive.ExecutionPredictor.predict_resources/1","doc":"Predicts resource usage for a given execution context.","ref":"ElixirScope.AI.Predictive.ExecutionPredictor.html#predict_resources/1"},{"type":"function","title":"Examples - ElixirScope.AI.Predictive.ExecutionPredictor.predict_resources/1","doc":"iex> context = %{function: :process_data, input_size: 1000}\n    iex> ExecutionPredictor.predict_resources(context)\n    {:ok, %{\n      memory: 2048,  # KB\n      cpu: 15.5,     # percentage\n      io: 100,       # operations\n      execution_time: 250  # milliseconds\n    }}","ref":"ElixirScope.AI.Predictive.ExecutionPredictor.html#predict_resources/1-examples"},{"type":"function","title":"ElixirScope.AI.Predictive.ExecutionPredictor.start_link/1","doc":"Starts the ExecutionPredictor GenServer.","ref":"ElixirScope.AI.Predictive.ExecutionPredictor.html#start_link/1"},{"type":"function","title":"ElixirScope.AI.Predictive.ExecutionPredictor.train/1","doc":"Trains the prediction models with historical data.","ref":"ElixirScope.AI.Predictive.ExecutionPredictor.html#train/1"},{"type":"module","title":"ElixirScope.AST.EnhancedTransformer","doc":"Enhanced AST transformer for granular compile-time instrumentation.\n\nProvides \"Cinema Data\" - rich, detailed execution traces including:\n- Local variable capture at specific lines\n- Expression-level value tracking  \n- Custom debugging logic injection","ref":"ElixirScope.AST.EnhancedTransformer.html"},{"type":"function","title":"ElixirScope.AST.EnhancedTransformer.ast_tracing_enabled?/1","doc":"","ref":"ElixirScope.AST.EnhancedTransformer.html#ast_tracing_enabled?/1"},{"type":"function","title":"ElixirScope.AST.EnhancedTransformer.inject_custom_debugging_logic/2","doc":"Injects custom debugging logic at specified points.","ref":"ElixirScope.AST.EnhancedTransformer.html#inject_custom_debugging_logic/2"},{"type":"function","title":"ElixirScope.AST.EnhancedTransformer.inject_expression_tracing/2","doc":"Injects expression tracing for specified expressions.","ref":"ElixirScope.AST.EnhancedTransformer.html#inject_expression_tracing/2"},{"type":"function","title":"ElixirScope.AST.EnhancedTransformer.inject_local_variable_capture/2","doc":"Injects local variable capture at specified lines or after specific expressions.","ref":"ElixirScope.AST.EnhancedTransformer.html#inject_local_variable_capture/2"},{"type":"function","title":"ElixirScope.AST.EnhancedTransformer.transform_with_enhanced_instrumentation/2","doc":"Transforms AST with enhanced capabilities.","ref":"ElixirScope.AST.EnhancedTransformer.html#transform_with_enhanced_instrumentation/2"},{"type":"function","title":"ElixirScope.AST.EnhancedTransformer.transform_with_granular_instrumentation/2","doc":"Transforms AST with granular instrumentation capabilities.","ref":"ElixirScope.AST.EnhancedTransformer.html#transform_with_granular_instrumentation/2"},{"type":"module","title":"ElixirScope.AST.InjectorHelpers","doc":"Helper functions for injecting ElixirScope instrumentation into AST nodes.\n\nProvides utilities for generating instrumentation calls while preserving\noriginal code semantics and structure.","ref":"ElixirScope.AST.InjectorHelpers.html"},{"type":"function","title":"ElixirScope.AST.InjectorHelpers.capture_genserver_state_after_call/2","doc":"Captures GenServer state after a callback call.","ref":"ElixirScope.AST.InjectorHelpers.html#capture_genserver_state_after_call/2"},{"type":"function","title":"ElixirScope.AST.InjectorHelpers.capture_genserver_state_before_call/2","doc":"Captures GenServer state before a callback call.","ref":"ElixirScope.AST.InjectorHelpers.html#capture_genserver_state_before_call/2"},{"type":"function","title":"ElixirScope.AST.InjectorHelpers.capture_liveview_event/2","doc":"Captures LiveView event data.","ref":"ElixirScope.AST.InjectorHelpers.html#capture_liveview_event/2"},{"type":"function","title":"ElixirScope.AST.InjectorHelpers.capture_liveview_socket_assigns/2","doc":"Captures LiveView socket assigns.","ref":"ElixirScope.AST.InjectorHelpers.html#capture_liveview_socket_assigns/2"},{"type":"function","title":"ElixirScope.AST.InjectorHelpers.capture_phoenix_conn_state_after_and_response/2","doc":"Captures Phoenix connection state and response after action.","ref":"ElixirScope.AST.InjectorHelpers.html#capture_phoenix_conn_state_after_and_response/2"},{"type":"function","title":"ElixirScope.AST.InjectorHelpers.capture_phoenix_conn_state_before/2","doc":"Captures Phoenix connection state before action.","ref":"ElixirScope.AST.InjectorHelpers.html#capture_phoenix_conn_state_before/2"},{"type":"function","title":"ElixirScope.AST.InjectorHelpers.capture_phoenix_params/2","doc":"Captures Phoenix controller parameters.","ref":"ElixirScope.AST.InjectorHelpers.html#capture_phoenix_params/2"},{"type":"function","title":"ElixirScope.AST.InjectorHelpers.report_function_entry_call/2","doc":"Generates a function entry call for instrumentation.","ref":"ElixirScope.AST.InjectorHelpers.html#report_function_entry_call/2"},{"type":"function","title":"ElixirScope.AST.InjectorHelpers.wrap_genserver_callback_body/3","doc":"Wraps GenServer callback body with state monitoring.","ref":"ElixirScope.AST.InjectorHelpers.html#wrap_genserver_callback_body/3"},{"type":"function","title":"ElixirScope.AST.InjectorHelpers.wrap_liveview_callback_body/3","doc":"Wraps LiveView callback body with monitoring.","ref":"ElixirScope.AST.InjectorHelpers.html#wrap_liveview_callback_body/3"},{"type":"function","title":"ElixirScope.AST.InjectorHelpers.wrap_phoenix_action_body/3","doc":"Wraps Phoenix action body with monitoring.","ref":"ElixirScope.AST.InjectorHelpers.html#wrap_phoenix_action_body/3"},{"type":"function","title":"ElixirScope.AST.InjectorHelpers.wrap_with_try_catch/3","doc":"Wraps function body with try/catch for exit and exception handling.","ref":"ElixirScope.AST.InjectorHelpers.html#wrap_with_try_catch/3"},{"type":"module","title":"ElixirScope.AST.Transformer","doc":"Core AST transformation engine for ElixirScope instrumentation.\n\nThis module provides the core logic for transforming Elixir ASTs to inject\ninstrumentation calls while preserving original semantics and behavior.","ref":"ElixirScope.AST.Transformer.html"},{"type":"function","title":"ElixirScope.AST.Transformer.transform_function/2","doc":"Transforms a function definition based on instrumentation plan.","ref":"ElixirScope.AST.Transformer.html#transform_function/2"},{"type":"function","title":"ElixirScope.AST.Transformer.transform_genserver_callback/2","doc":"Transforms a GenServer callback based on instrumentation plan.","ref":"ElixirScope.AST.Transformer.html#transform_genserver_callback/2"},{"type":"function","title":"ElixirScope.AST.Transformer.transform_liveview_callback/2","doc":"Transforms a LiveView callback based on instrumentation plan.","ref":"ElixirScope.AST.Transformer.html#transform_liveview_callback/2"},{"type":"function","title":"ElixirScope.AST.Transformer.transform_module/2","doc":"Transforms a complete module AST based on the instrumentation plan.","ref":"ElixirScope.AST.Transformer.html#transform_module/2"},{"type":"function","title":"ElixirScope.AST.Transformer.transform_phoenix_action/2","doc":"Transforms a Phoenix controller action based on instrumentation plan.","ref":"ElixirScope.AST.Transformer.html#transform_phoenix_action/2"},{"type":"module","title":"ElixirScope.ASTRepository.FunctionData","doc":"Function-level data structure with static analysis and runtime correlation.\n\nThis structure stores comprehensive information about individual functions including:\n- Function AST and metadata\n- Static analysis results\n- Runtime execution data\n- Performance metrics\n- Error patterns","ref":"ElixirScope.ASTRepository.FunctionData.html"},{"type":"function","title":"ElixirScope.ASTRepository.FunctionData.add_call_pattern/2","doc":"Adds a call pattern observation.","ref":"ElixirScope.ASTRepository.FunctionData.html#add_call_pattern/2"},{"type":"function","title":"ElixirScope.ASTRepository.FunctionData.add_return_pattern/2","doc":"Adds a return pattern observation.","ref":"ElixirScope.ASTRepository.FunctionData.html#add_return_pattern/2"},{"type":"type","title":"ElixirScope.ASTRepository.FunctionData.ast_node_id/0","doc":"","ref":"ElixirScope.ASTRepository.FunctionData.html#t:ast_node_id/0"},{"type":"type","title":"ElixirScope.ASTRepository.FunctionData.correlation_id/0","doc":"","ref":"ElixirScope.ASTRepository.FunctionData.html#t:correlation_id/0"},{"type":"function","title":"ElixirScope.ASTRepository.FunctionData.error_rate/1","doc":"Calculates the error rate for this function.","ref":"ElixirScope.ASTRepository.FunctionData.html#error_rate/1"},{"type":"type","title":"ElixirScope.ASTRepository.FunctionData.function_key/0","doc":"","ref":"ElixirScope.ASTRepository.FunctionData.html#t:function_key/0"},{"type":"type","title":"ElixirScope.ASTRepository.FunctionData.function_name/0","doc":"","ref":"ElixirScope.ASTRepository.FunctionData.html#t:function_name/0"},{"type":"function","title":"ElixirScope.ASTRepository.FunctionData.get_ast_node_ids/1","doc":"Gets the AST node IDs for this function.","ref":"ElixirScope.ASTRepository.FunctionData.html#get_ast_node_ids/1"},{"type":"function","title":"ElixirScope.ASTRepository.FunctionData.get_correlation_ids/1","doc":"Gets the correlation IDs associated with this function.","ref":"ElixirScope.ASTRepository.FunctionData.html#get_correlation_ids/1"},{"type":"function","title":"ElixirScope.ASTRepository.FunctionData.has_runtime_data?/1","doc":"Checks if this function has runtime execution data.","ref":"ElixirScope.ASTRepository.FunctionData.html#has_runtime_data?/1"},{"type":"function","title":"ElixirScope.ASTRepository.FunctionData.is_bottleneck?/1","doc":"Checks if this function is considered a performance bottleneck.","ref":"ElixirScope.ASTRepository.FunctionData.html#is_bottleneck?/1"},{"type":"type","title":"ElixirScope.ASTRepository.FunctionData.module_name/0","doc":"","ref":"ElixirScope.ASTRepository.FunctionData.html#t:module_name/0"},{"type":"function","title":"ElixirScope.ASTRepository.FunctionData.new/3","doc":"Creates a new FunctionData structure from function AST.","ref":"ElixirScope.ASTRepository.FunctionData.html#new/3"},{"type":"function","title":"Parameters - ElixirScope.ASTRepository.FunctionData.new/3","doc":"- `function_key` - The {module, function, arity} tuple\n- `ast` - The function AST\n- `opts` - Optional parameters including source_location, visibility, etc.","ref":"ElixirScope.ASTRepository.FunctionData.html#new/3-parameters"},{"type":"function","title":"ElixirScope.ASTRepository.FunctionData.record_error/2","doc":"Records an error event for this function.","ref":"ElixirScope.ASTRepository.FunctionData.html#record_error/2"},{"type":"function","title":"ElixirScope.ASTRepository.FunctionData.record_execution/2","doc":"Records a function execution event.","ref":"ElixirScope.ASTRepository.FunctionData.html#record_execution/2"},{"type":"type","title":"ElixirScope.ASTRepository.FunctionData.t/0","doc":"","ref":"ElixirScope.ASTRepository.FunctionData.html#t:t/0"},{"type":"function","title":"ElixirScope.ASTRepository.FunctionData.update_performance_profile/2","doc":"Updates the performance profile with new execution data.","ref":"ElixirScope.ASTRepository.FunctionData.html#update_performance_profile/2"},{"type":"module","title":"ElixirScope.ASTRepository.InstrumentationMapper","doc":"Maps AST nodes to instrumentation strategies and points.\n\nProvides systematic instrumentation point mapping for compile-time transformation.\nThis module analyzes AST structures and determines the optimal instrumentation\nstrategy for each node type, enabling intelligent compile-time instrumentation.\n\nKey responsibilities:\n- Map AST nodes to appropriate instrumentation strategies\n- Generate instrumentation point configurations\n- Support different instrumentation levels (function, expression, line)\n- Integrate with the Enhanced Parser for systematic instrumentation","ref":"ElixirScope.ASTRepository.InstrumentationMapper.html"},{"type":"type","title":"ElixirScope.ASTRepository.InstrumentationMapper.ast_node/0","doc":"","ref":"ElixirScope.ASTRepository.InstrumentationMapper.html#t:ast_node/0"},{"type":"type","title":"ElixirScope.ASTRepository.InstrumentationMapper.ast_node_id/0","doc":"","ref":"ElixirScope.ASTRepository.InstrumentationMapper.html#t:ast_node_id/0"},{"type":"function","title":"ElixirScope.ASTRepository.InstrumentationMapper.configure_instrumentation/2","doc":"Configures instrumentation for a specific point.\n\nGenerates the configuration map that will be used by the AST transformer\nto inject the appropriate instrumentation code.","ref":"ElixirScope.ASTRepository.InstrumentationMapper.html#configure_instrumentation/2"},{"type":"type","title":"ElixirScope.ASTRepository.InstrumentationMapper.context/0","doc":"","ref":"ElixirScope.ASTRepository.InstrumentationMapper.html#t:context/0"},{"type":"function","title":"ElixirScope.ASTRepository.InstrumentationMapper.estimate_performance_impact/1","doc":"Estimates the performance impact of an instrumentation configuration.\n\nReturns a performance impact score from 0.0 (no impact) to 1.0 (high impact).","ref":"ElixirScope.ASTRepository.InstrumentationMapper.html#estimate_performance_impact/1"},{"type":"type","title":"ElixirScope.ASTRepository.InstrumentationMapper.instrumentation_level/0","doc":"","ref":"ElixirScope.ASTRepository.InstrumentationMapper.html#t:instrumentation_level/0"},{"type":"type","title":"ElixirScope.ASTRepository.InstrumentationMapper.instrumentation_point/0","doc":"","ref":"ElixirScope.ASTRepository.InstrumentationMapper.html#t:instrumentation_point/0"},{"type":"type","title":"ElixirScope.ASTRepository.InstrumentationMapper.instrumentation_strategy/0","doc":"","ref":"ElixirScope.ASTRepository.InstrumentationMapper.html#t:instrumentation_strategy/0"},{"type":"function","title":"ElixirScope.ASTRepository.InstrumentationMapper.map_instrumentation_points/2","doc":"Maps AST nodes to instrumentation points with appropriate strategies.\n\nAnalyzes the AST structure and generates a comprehensive list of instrumentation\npoints, each with an appropriate strategy based on the node type and context.","ref":"ElixirScope.ASTRepository.InstrumentationMapper.html#map_instrumentation_points/2"},{"type":"function","title":"Options - ElixirScope.ASTRepository.InstrumentationMapper.map_instrumentation_points/2","doc":"- `:instrumentation_level` - :minimal, :balanced, :comprehensive, or :debug\n- `:include_expressions` - Whether to instrument individual expressions\n- `:include_variables` - Whether to capture variable snapshots\n- `:performance_focus` - Optimize for performance vs. completeness","ref":"ElixirScope.ASTRepository.InstrumentationMapper.html#map_instrumentation_points/2-options"},{"type":"function","title":"ElixirScope.ASTRepository.InstrumentationMapper.optimize_for_performance/2","doc":"Optimizes instrumentation points for performance.\n\nReduces the number of instrumentation points while maintaining\nessential debugging capabilities.","ref":"ElixirScope.ASTRepository.InstrumentationMapper.html#optimize_for_performance/2"},{"type":"function","title":"ElixirScope.ASTRepository.InstrumentationMapper.select_instrumentation_strategy/2","doc":"Selects the appropriate instrumentation strategy for a specific AST node.\n\nDetermines the best instrumentation approach based on the node type,\ncontext, and configuration preferences.","ref":"ElixirScope.ASTRepository.InstrumentationMapper.html#select_instrumentation_strategy/2"},{"type":"module","title":"ElixirScope.ASTRepository.ModuleData","doc":"Complete module representation with static AST and runtime correlation data.\n\nThis structure stores all information about a module including:\n- Original AST with instrumentation metadata\n- Static analysis results\n- Runtime correlation data\n- Performance metrics","ref":"ElixirScope.ASTRepository.ModuleData.html"},{"type":"function","title":"ElixirScope.ASTRepository.ModuleData.add_error_pattern/2","doc":"Adds an error pattern to the module's runtime data.","ref":"ElixirScope.ASTRepository.ModuleData.html#add_error_pattern/2"},{"type":"type","title":"ElixirScope.ASTRepository.ModuleData.ast_node_id/0","doc":"","ref":"ElixirScope.ASTRepository.ModuleData.html#t:ast_node_id/0"},{"type":"type","title":"ElixirScope.ASTRepository.ModuleData.correlation_id/0","doc":"","ref":"ElixirScope.ASTRepository.ModuleData.html#t:correlation_id/0"},{"type":"type","title":"ElixirScope.ASTRepository.ModuleData.function_key/0","doc":"","ref":"ElixirScope.ASTRepository.ModuleData.html#t:function_key/0"},{"type":"function","title":"ElixirScope.ASTRepository.ModuleData.get_ast_node_ids/1","doc":"Gets the AST node IDs for this module.","ref":"ElixirScope.ASTRepository.ModuleData.html#get_ast_node_ids/1"},{"type":"function","title":"ElixirScope.ASTRepository.ModuleData.get_correlation_ids/1","doc":"Gets the correlation IDs associated with this module.","ref":"ElixirScope.ASTRepository.ModuleData.html#get_correlation_ids/1"},{"type":"function","title":"ElixirScope.ASTRepository.ModuleData.get_function_keys/1","doc":"Gets all function keys for this module.","ref":"ElixirScope.ASTRepository.ModuleData.html#get_function_keys/1"},{"type":"function","title":"ElixirScope.ASTRepository.ModuleData.has_runtime_data?/1","doc":"Checks if the module has runtime correlation data.","ref":"ElixirScope.ASTRepository.ModuleData.html#has_runtime_data?/1"},{"type":"type","title":"ElixirScope.ASTRepository.ModuleData.module_name/0","doc":"","ref":"ElixirScope.ASTRepository.ModuleData.html#t:module_name/0"},{"type":"function","title":"ElixirScope.ASTRepository.ModuleData.new/3","doc":"Creates a new ModuleData structure from parsed AST.","ref":"ElixirScope.ASTRepository.ModuleData.html#new/3"},{"type":"function","title":"Parameters - ElixirScope.ASTRepository.ModuleData.new/3","doc":"- `module_name` - The module name (atom)\n- `ast` - The parsed AST\n- `opts` - Optional parameters including source_file, instrumentation_points, etc.","ref":"ElixirScope.ASTRepository.ModuleData.html#new/3-parameters"},{"type":"type","title":"ElixirScope.ASTRepository.ModuleData.t/0","doc":"","ref":"ElixirScope.ASTRepository.ModuleData.html#t:t/0"},{"type":"function","title":"ElixirScope.ASTRepository.ModuleData.update_execution_frequency/3","doc":"Updates execution frequency data for a specific function.","ref":"ElixirScope.ASTRepository.ModuleData.html#update_execution_frequency/3"},{"type":"function","title":"ElixirScope.ASTRepository.ModuleData.update_performance_data/3","doc":"Updates performance data for a specific function.","ref":"ElixirScope.ASTRepository.ModuleData.html#update_performance_data/3"},{"type":"function","title":"ElixirScope.ASTRepository.ModuleData.update_runtime_insights/2","doc":"Updates the runtime insights for this module.","ref":"ElixirScope.ASTRepository.ModuleData.html#update_runtime_insights/2"},{"type":"module","title":"ElixirScope.ASTRepository.Parser","doc":"Enhanced AST parser that assigns unique node IDs to instrumentable AST nodes,\nextracts instrumentation points, and builds correlation indexes for runtime correlation.\n\nThis module is the foundation for compile-time AST analysis with runtime correlation.","ref":"ElixirScope.ASTRepository.Parser.html"},{"type":"function","title":"ElixirScope.ASTRepository.Parser.assign_node_ids/1","doc":"Assigns unique node IDs to instrumentable AST nodes.\n\nInstrumentable nodes include:\n- Function definitions (def, defp)\n- Pipe operations (|>)\n- Case statements\n- Try-catch blocks\n- Module attributes\n\nReturns {:ok, enhanced_ast} or {:error, reason}.","ref":"ElixirScope.ASTRepository.Parser.html#assign_node_ids/1"},{"type":"function","title":"ElixirScope.ASTRepository.Parser.build_correlation_index/2","doc":"Builds a correlation index from enhanced AST and instrumentation points.\n\nReturns {:ok, correlation_index} where correlation_index is a map of\ncorrelation_id -> ast_node_id.","ref":"ElixirScope.ASTRepository.Parser.html#build_correlation_index/2"},{"type":"function","title":"ElixirScope.ASTRepository.Parser.extract_instrumentation_points/1","doc":"Extracts instrumentation points from an enhanced AST.\n\nReturns {:ok, instrumentation_points} or {:error, reason}.","ref":"ElixirScope.ASTRepository.Parser.html#extract_instrumentation_points/1"},{"type":"module","title":"ElixirScope.ASTRepository.Repository","doc":"Central repository for AST storage with runtime correlation capabilities.\n\nDesigned for high-performance access patterns:\n- O(1) module lookup by name\n- O(log n) correlation ID to AST node mapping  \n- O(1) instrumentation point retrieval\n- O(log n) temporal range queries\n\nIntegrates with existing ElixirScope infrastructure:\n- Uses ElixirScope.Storage.DataAccess patterns for ETS storage\n- Follows ElixirScope.Config for configuration management\n- Implements GenServer pattern like PipelineManager","ref":"ElixirScope.ASTRepository.Repository.html"},{"type":"type","title":"ElixirScope.ASTRepository.Repository.ast_node_id/0","doc":"","ref":"ElixirScope.ASTRepository.Repository.html#t:ast_node_id/0"},{"type":"function","title":"ElixirScope.ASTRepository.Repository.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ElixirScope.ASTRepository.Repository.html#child_spec/1"},{"type":"function","title":"ElixirScope.ASTRepository.Repository.correlate_event/2","doc":"Correlates a runtime event with AST nodes using correlation ID.\nReturns the AST node ID that correlates with the event.","ref":"ElixirScope.ASTRepository.Repository.html#correlate_event/2"},{"type":"type","title":"ElixirScope.ASTRepository.Repository.correlation_id/0","doc":"","ref":"ElixirScope.ASTRepository.Repository.html#t:correlation_id/0"},{"type":"type","title":"ElixirScope.ASTRepository.Repository.function_key/0","doc":"","ref":"ElixirScope.ASTRepository.Repository.html#t:function_key/0"},{"type":"function","title":"ElixirScope.ASTRepository.Repository.get_function/2","doc":"Retrieves function data by function key.","ref":"ElixirScope.ASTRepository.Repository.html#get_function/2"},{"type":"function","title":"ElixirScope.ASTRepository.Repository.get_instrumentation_points/2","doc":"Gets instrumentation points for a specific AST node.","ref":"ElixirScope.ASTRepository.Repository.html#get_instrumentation_points/2"},{"type":"function","title":"ElixirScope.ASTRepository.Repository.get_module/2","doc":"Retrieves a module's data by name.","ref":"ElixirScope.ASTRepository.Repository.html#get_module/2"},{"type":"function","title":"ElixirScope.ASTRepository.Repository.get_statistics/1","doc":"Gets repository statistics and performance metrics.","ref":"ElixirScope.ASTRepository.Repository.html#get_statistics/1"},{"type":"function","title":"ElixirScope.ASTRepository.Repository.health_check/1","doc":"Performs a health check on the repository.","ref":"ElixirScope.ASTRepository.Repository.html#health_check/1"},{"type":"type","title":"ElixirScope.ASTRepository.Repository.module_name/0","doc":"","ref":"ElixirScope.ASTRepository.Repository.html#t:module_name/0"},{"type":"function","title":"ElixirScope.ASTRepository.Repository.new/1","doc":"Creates a new repository instance (for testing or multiple repositories).","ref":"ElixirScope.ASTRepository.Repository.html#new/1"},{"type":"type","title":"ElixirScope.ASTRepository.Repository.repository_id/0","doc":"","ref":"ElixirScope.ASTRepository.Repository.html#t:repository_id/0"},{"type":"function","title":"ElixirScope.ASTRepository.Repository.start_link/1","doc":"Starts the AST Repository with optional configuration.","ref":"ElixirScope.ASTRepository.Repository.html#start_link/1"},{"type":"function","title":"Options - ElixirScope.ASTRepository.Repository.start_link/1","doc":"- `:name` - Process name (default: __MODULE__)\n- `:config` - Repository configuration (merged with defaults)\n- `:data_access` - Existing DataAccess instance (optional)","ref":"ElixirScope.ASTRepository.Repository.html#start_link/1-options"},{"type":"function","title":"ElixirScope.ASTRepository.Repository.store_function/2","doc":"Stores function-level data with runtime correlation capabilities.","ref":"ElixirScope.ASTRepository.Repository.html#store_function/2"},{"type":"function","title":"ElixirScope.ASTRepository.Repository.store_module/2","doc":"Stores a module's AST data with instrumentation metadata.","ref":"ElixirScope.ASTRepository.Repository.html#store_module/2"},{"type":"type","title":"ElixirScope.ASTRepository.Repository.t/0","doc":"","ref":"ElixirScope.ASTRepository.Repository.html#t:t/0"},{"type":"function","title":"ElixirScope.ASTRepository.Repository.update_module/3","doc":"Updates a module's data using an update function.","ref":"ElixirScope.ASTRepository.Repository.html#update_module/3"},{"type":"module","title":"ElixirScope.ASTRepository.RuntimeCorrelator","doc":"Runtime correlation bridge that maps runtime events to AST nodes.\n\nThis module provides the core functionality for correlating runtime execution\nevents with static AST analysis data, enabling the hybrid architecture.\n\nKey responsibilities:\n- Map correlation IDs from runtime events to AST node IDs\n- Maintain temporal correlation data\n- Provide fast lookup capabilities (<5ms target)\n- Update AST repository with runtime insights","ref":"ElixirScope.ASTRepository.RuntimeCorrelator.html"},{"type":"type","title":"ElixirScope.ASTRepository.RuntimeCorrelator.ast_node_id/0","doc":"","ref":"ElixirScope.ASTRepository.RuntimeCorrelator.html#t:ast_node_id/0"},{"type":"function","title":"ElixirScope.ASTRepository.RuntimeCorrelator.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ElixirScope.ASTRepository.RuntimeCorrelator.html#child_spec/1"},{"type":"function","title":"ElixirScope.ASTRepository.RuntimeCorrelator.correlate_event/2","doc":"Correlates a runtime event with AST nodes.\n\nReturns the AST node ID that correlates with the event, or an error if\nno correlation can be established.","ref":"ElixirScope.ASTRepository.RuntimeCorrelator.html#correlate_event/2"},{"type":"function","title":"ElixirScope.ASTRepository.RuntimeCorrelator.correlate_events/2","doc":"Batch correlates multiple runtime events for better performance.","ref":"ElixirScope.ASTRepository.RuntimeCorrelator.html#correlate_events/2"},{"type":"type","title":"ElixirScope.ASTRepository.RuntimeCorrelator.correlation_id/0","doc":"","ref":"ElixirScope.ASTRepository.RuntimeCorrelator.html#t:correlation_id/0"},{"type":"type","title":"ElixirScope.ASTRepository.RuntimeCorrelator.correlation_result/0","doc":"","ref":"ElixirScope.ASTRepository.RuntimeCorrelator.html#t:correlation_result/0"},{"type":"function","title":"ElixirScope.ASTRepository.RuntimeCorrelator.get_correlated_events/2","doc":"Gets all runtime events correlated with a specific AST node.","ref":"ElixirScope.ASTRepository.RuntimeCorrelator.html#get_correlated_events/2"},{"type":"function","title":"ElixirScope.ASTRepository.RuntimeCorrelator.get_events_for_ast_node/2","doc":"Gets all runtime events correlated with a specific AST node, ordered chronologically.\n\nThis is the primary function for AST-centric debugging queries.","ref":"ElixirScope.ASTRepository.RuntimeCorrelator.html#get_events_for_ast_node/2"},{"type":"function","title":"ElixirScope.ASTRepository.RuntimeCorrelator.get_statistics/1","doc":"Gets correlation statistics and performance metrics.","ref":"ElixirScope.ASTRepository.RuntimeCorrelator.html#get_statistics/1"},{"type":"function","title":"ElixirScope.ASTRepository.RuntimeCorrelator.health_check/1","doc":"Performs a health check on the correlator.","ref":"ElixirScope.ASTRepository.RuntimeCorrelator.html#health_check/1"},{"type":"function","title":"ElixirScope.ASTRepository.RuntimeCorrelator.query_temporal_events/3","doc":"Queries events within a time range for temporal correlation.","ref":"ElixirScope.ASTRepository.RuntimeCorrelator.html#query_temporal_events/3"},{"type":"type","title":"ElixirScope.ASTRepository.RuntimeCorrelator.runtime_event/0","doc":"","ref":"ElixirScope.ASTRepository.RuntimeCorrelator.html#t:runtime_event/0"},{"type":"function","title":"ElixirScope.ASTRepository.RuntimeCorrelator.start_link/1","doc":"Starts the RuntimeCorrelator with the given repository and configuration.","ref":"ElixirScope.ASTRepository.RuntimeCorrelator.html#start_link/1"},{"type":"type","title":"ElixirScope.ASTRepository.RuntimeCorrelator.t/0","doc":"","ref":"ElixirScope.ASTRepository.RuntimeCorrelator.html#t:t/0"},{"type":"function","title":"ElixirScope.ASTRepository.RuntimeCorrelator.update_correlation_mapping/3","doc":"Updates the correlation mapping for an AST node.","ref":"ElixirScope.ASTRepository.RuntimeCorrelator.html#update_correlation_mapping/3"},{"type":"module","title":"ElixirScope.Application","doc":"ElixirScope Application Supervisor\n\nManages the lifecycle of all ElixirScope components in a supervised manner.\nThe supervision tree is designed to be fault-tolerant and to restart \ncomponents in the correct order if failures occur.","ref":"ElixirScope.Application.html"},{"type":"module","title":"ElixirScope.Capture.AsyncWriter","doc":"AsyncWriter is a worker process that consumes events from ring buffers,\nenriches them with metadata, and processes them asynchronously.\n\nKey responsibilities:\n- Read events from ring buffers in configurable batches\n- Enrich events with correlation and processing metadata\n- Handle errors gracefully without affecting the pipeline\n- Track processing metrics and performance","ref":"ElixirScope.Capture.AsyncWriter.html"},{"type":"function","title":"ElixirScope.Capture.AsyncWriter.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ElixirScope.Capture.AsyncWriter.html#child_spec/1"},{"type":"function","title":"ElixirScope.Capture.AsyncWriter.enrich_event/1","doc":"Enriches an event with correlation and processing metadata.","ref":"ElixirScope.Capture.AsyncWriter.html#enrich_event/1"},{"type":"function","title":"ElixirScope.Capture.AsyncWriter.get_metrics/1","doc":"Gets current metrics about processing performance.","ref":"ElixirScope.Capture.AsyncWriter.html#get_metrics/1"},{"type":"function","title":"ElixirScope.Capture.AsyncWriter.get_state/1","doc":"Gets the current state of the AsyncWriter.","ref":"ElixirScope.Capture.AsyncWriter.html#get_state/1"},{"type":"function","title":"ElixirScope.Capture.AsyncWriter.set_position/2","doc":"Sets the current position in the ring buffer.","ref":"ElixirScope.Capture.AsyncWriter.html#set_position/2"},{"type":"function","title":"ElixirScope.Capture.AsyncWriter.start_link/1","doc":"Starts an AsyncWriter with the given configuration.","ref":"ElixirScope.Capture.AsyncWriter.html#start_link/1"},{"type":"function","title":"ElixirScope.Capture.AsyncWriter.stop/1","doc":"Gracefully stops the AsyncWriter.","ref":"ElixirScope.Capture.AsyncWriter.html#stop/1"},{"type":"module","title":"ElixirScope.Capture.AsyncWriterPool","doc":"AsyncWriterPool manages a pool of AsyncWriter processes that consume\nevents from ring buffers and process them asynchronously.\n\nKey responsibilities:\n- Manage a configurable pool of AsyncWriter workers\n- Distribute work segments across workers to avoid duplication\n- Monitor and restart failed workers automatically\n- Provide scaling, metrics aggregation, and health monitoring\n- Coordinate workers to process events efficiently","ref":"ElixirScope.Capture.AsyncWriterPool.html"},{"type":"function","title":"ElixirScope.Capture.AsyncWriterPool.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ElixirScope.Capture.AsyncWriterPool.html#child_spec/1"},{"type":"function","title":"ElixirScope.Capture.AsyncWriterPool.get_metrics/1","doc":"Gets aggregated metrics from all workers.","ref":"ElixirScope.Capture.AsyncWriterPool.html#get_metrics/1"},{"type":"function","title":"ElixirScope.Capture.AsyncWriterPool.get_state/1","doc":"Gets the current state of the pool.","ref":"ElixirScope.Capture.AsyncWriterPool.html#get_state/1"},{"type":"function","title":"ElixirScope.Capture.AsyncWriterPool.get_worker_assignments/1","doc":"Gets worker assignment information.","ref":"ElixirScope.Capture.AsyncWriterPool.html#get_worker_assignments/1"},{"type":"function","title":"ElixirScope.Capture.AsyncWriterPool.health_check/1","doc":"Performs a health check on all workers.","ref":"ElixirScope.Capture.AsyncWriterPool.html#health_check/1"},{"type":"function","title":"ElixirScope.Capture.AsyncWriterPool.scale_pool/2","doc":"Scales the pool to the specified size.","ref":"ElixirScope.Capture.AsyncWriterPool.html#scale_pool/2"},{"type":"function","title":"ElixirScope.Capture.AsyncWriterPool.start_link/1","doc":"Starts the AsyncWriterPool with the given configuration.","ref":"ElixirScope.Capture.AsyncWriterPool.html#start_link/1"},{"type":"function","title":"ElixirScope.Capture.AsyncWriterPool.start_mock/0","doc":"","ref":"ElixirScope.Capture.AsyncWriterPool.html#start_mock/0"},{"type":"function","title":"ElixirScope.Capture.AsyncWriterPool.stop/1","doc":"Gracefully stops the pool and all workers.","ref":"ElixirScope.Capture.AsyncWriterPool.html#stop/1"},{"type":"module","title":"ElixirScope.Capture.EventCorrelator","doc":"EventCorrelator establishes causal relationships between events in the ElixirScope\nexecution cinema system.\n\nKey responsibilities:\n- Correlate function call entry/exit events using call stacks\n- Correlate message send/receive events\n- Maintain correlation state with automatic cleanup\n- Provide correlation chains for debugging and analysis\n- Track correlation metrics and health status\n\nThe correlator uses ETS tables for fast correlation state management:\n- Call stacks per process for function correlation\n- Message registry for message correlation\n- Correlation metadata for tracking and cleanup\n- Correlation links for establishing relationships\n\nPerformance targets:\n- <500ns per event correlation\n- Support for 10,000+ events/second\n- Memory-bounded with automatic cleanup","ref":"ElixirScope.Capture.EventCorrelator.html"},{"type":"function","title":"ElixirScope.Capture.EventCorrelator.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ElixirScope.Capture.EventCorrelator.html#child_spec/1"},{"type":"function","title":"ElixirScope.Capture.EventCorrelator.cleanup_expired_correlations/1","doc":"Manually triggers cleanup of expired correlations.","ref":"ElixirScope.Capture.EventCorrelator.html#cleanup_expired_correlations/1"},{"type":"function","title":"ElixirScope.Capture.EventCorrelator.correlate_batch/2","doc":"Correlates multiple events in batch for better performance.","ref":"ElixirScope.Capture.EventCorrelator.html#correlate_batch/2"},{"type":"function","title":"ElixirScope.Capture.EventCorrelator.correlate_event/2","doc":"Correlates a single event, establishing causal relationships.","ref":"ElixirScope.Capture.EventCorrelator.html#correlate_event/2"},{"type":"function","title":"ElixirScope.Capture.EventCorrelator.get_correlation_chain/2","doc":"Gets the correlation chain for a given correlation ID.","ref":"ElixirScope.Capture.EventCorrelator.html#get_correlation_chain/2"},{"type":"function","title":"ElixirScope.Capture.EventCorrelator.get_correlation_metadata/2","doc":"Gets correlation metadata for a given correlation ID.","ref":"ElixirScope.Capture.EventCorrelator.html#get_correlation_metadata/2"},{"type":"function","title":"ElixirScope.Capture.EventCorrelator.get_metrics/1","doc":"Gets correlation metrics.","ref":"ElixirScope.Capture.EventCorrelator.html#get_metrics/1"},{"type":"function","title":"ElixirScope.Capture.EventCorrelator.get_state/1","doc":"Gets the current state (for testing).","ref":"ElixirScope.Capture.EventCorrelator.html#get_state/1"},{"type":"function","title":"ElixirScope.Capture.EventCorrelator.health_check/1","doc":"Performs a health check.","ref":"ElixirScope.Capture.EventCorrelator.html#health_check/1"},{"type":"function","title":"ElixirScope.Capture.EventCorrelator.start_link/1","doc":"Starts the EventCorrelator with the given configuration.","ref":"ElixirScope.Capture.EventCorrelator.html#start_link/1"},{"type":"function","title":"ElixirScope.Capture.EventCorrelator.stop/1","doc":"Gracefully stops the correlator.","ref":"ElixirScope.Capture.EventCorrelator.html#stop/1"},{"type":"module","title":"ElixirScope.Capture.EventCorrelator.CorrelatedEvent","doc":"Enhanced event structure with correlation metadata and causal links.","ref":"ElixirScope.Capture.EventCorrelator.CorrelatedEvent.html"},{"type":"module","title":"ElixirScope.Capture.Ingestor","doc":"Ultra-fast event ingestor for ElixirScope.\n\nThis is the critical hot path for event capture. Every microsecond counts here.\nTarget: <1µs per event processing time.\n\nKey optimizations:\n- Direct ring buffer writes with minimal function call overhead\n- Pre-allocated event structs where possible\n- Inline timestamp generation\n- Minimal validation in hot path\n- Batch processing for better throughput","ref":"ElixirScope.Capture.Ingestor.html"},{"type":"function","title":"ElixirScope.Capture.Ingestor.benchmark_ingestion/3","doc":"Measures the ingestion performance for benchmarking.\n\nReturns timing statistics for the ingestion operation.","ref":"ElixirScope.Capture.Ingestor.html#benchmark_ingestion/3"},{"type":"function","title":"ElixirScope.Capture.Ingestor.create_fast_ingestor/1","doc":"Creates a pre-configured ingestor for a specific buffer.\n\nReturns a function that can be called with minimal overhead for repeated ingestion.\nThis is useful for hot paths where the buffer doesn't change.","ref":"ElixirScope.Capture.Ingestor.html#create_fast_ingestor/1"},{"type":"function","title":"ElixirScope.Capture.Ingestor.get_buffer/0","doc":"Gets the current buffer for runtime components.\n\nThis allows runtime tracing components to access the shared event buffer.","ref":"ElixirScope.Capture.Ingestor.html#get_buffer/0"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_batch/2","doc":"Ingests multiple events in batch for improved performance.\n\nThis is more efficient than individual ingestion for large numbers of events\nto process at once.","ref":"ElixirScope.Capture.Ingestor.html#ingest_batch/2"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_ecto_query_complete/6","doc":"Ingests an Ecto query complete event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_ecto_query_complete/6"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_ecto_query_start/6","doc":"Ingests an Ecto query start event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_ecto_query_start/6"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_error/4","doc":"Ingests an error event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_error/4"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_function_call/6","doc":"Ingests a function call event.\n\nThis is the most common event type and is heavily optimized.","ref":"ElixirScope.Capture.Ingestor.html#ingest_function_call/6"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_function_return/4","doc":"Ingests a function return event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_function_return/4"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_generic_event/7","doc":"Ingests a generic event from runtime tracing components.\n\nThis function converts runtime trace data into appropriate ElixirScope.Events\nand forwards them to the existing ingestion pipeline.","ref":"ElixirScope.Capture.Ingestor.html#ingest_generic_event/7"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_genserver_callback_complete/4","doc":"Ingests a GenServer callback complete event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_genserver_callback_complete/4"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_genserver_callback_error/5","doc":"Ingests a GenServer callback error event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_genserver_callback_error/5"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_genserver_callback_start/4","doc":"Ingests a GenServer callback start event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_genserver_callback_start/4"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_genserver_callback_success/4","doc":"Ingests a GenServer callback success event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_genserver_callback_success/4"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_liveview_assigns/3","doc":"Ingests LiveView assigns change event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_liveview_assigns/3"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_liveview_callback/3","doc":"Ingests LiveView callback event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_liveview_callback/3"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_liveview_callback_error/5","doc":"Ingests LiveView callback error event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_liveview_callback_error/5"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_liveview_callback_success/4","doc":"Ingests LiveView callback success event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_liveview_callback_success/4"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_liveview_event/4","doc":"Ingests LiveView event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_liveview_event/4"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_liveview_handle_event_complete/6","doc":"Ingests a LiveView handle_event complete event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_liveview_handle_event_complete/6"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_liveview_handle_event_start/5","doc":"Ingests a LiveView handle_event start event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_liveview_handle_event_start/5"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_liveview_mount_complete/4","doc":"Ingests a LiveView mount complete event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_liveview_mount_complete/4"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_liveview_mount_start/5","doc":"Ingests a LiveView mount start event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_liveview_mount_start/5"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_message_send/4","doc":"Ingests a message send event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_message_send/4"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_node_event/4","doc":"Ingests a node event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_node_event/4"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_partition_detected/3","doc":"Ingests a partition detected event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_partition_detected/3"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_performance_metric/4","doc":"Ingests a performance metric event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_performance_metric/4"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_phoenix_action_complete/3","doc":"Ingests Phoenix action complete event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_phoenix_action_complete/3"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_phoenix_action_error/5","doc":"Ingests Phoenix action error event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_phoenix_action_error/5"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_phoenix_action_params/4","doc":"Ingests Phoenix action parameters.","ref":"ElixirScope.Capture.Ingestor.html#ingest_phoenix_action_params/4"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_phoenix_action_start/3","doc":"Ingests Phoenix action start event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_phoenix_action_start/3"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_phoenix_action_success/4","doc":"Ingests Phoenix action success event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_phoenix_action_success/4"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_phoenix_channel_join_complete/5","doc":"Ingests a Phoenix channel join complete event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_phoenix_channel_join_complete/5"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_phoenix_channel_join_start/5","doc":"Ingests a Phoenix channel join start event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_phoenix_channel_join_start/5"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_phoenix_channel_message_complete/5","doc":"Ingests a Phoenix channel message complete event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_phoenix_channel_message_complete/5"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_phoenix_channel_message_start/5","doc":"Ingests a Phoenix channel message start event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_phoenix_channel_message_start/5"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_phoenix_controller_entry/5","doc":"Ingests a Phoenix controller entry event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_phoenix_controller_entry/5"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_phoenix_controller_exit/5","doc":"Ingests a Phoenix controller exit event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_phoenix_controller_exit/5"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_phoenix_request_complete/5","doc":"Ingests a Phoenix request complete event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_phoenix_request_complete/5"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_phoenix_request_start/6","doc":"Ingests a Phoenix request start event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_phoenix_request_start/6"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_process_spawn/3","doc":"Ingests a process spawn event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_process_spawn/3"},{"type":"type","title":"ElixirScope.Capture.Ingestor.ingest_result/0","doc":"","ref":"ElixirScope.Capture.Ingestor.html#t:ingest_result/0"},{"type":"function","title":"ElixirScope.Capture.Ingestor.ingest_state_change/4","doc":"Ingests a state change event.","ref":"ElixirScope.Capture.Ingestor.html#ingest_state_change/4"},{"type":"function","title":"ElixirScope.Capture.Ingestor.set_buffer/1","doc":"Sets the current buffer for runtime components.\n\nThis should be called during ElixirScope initialization.","ref":"ElixirScope.Capture.Ingestor.html#set_buffer/1"},{"type":"function","title":"ElixirScope.Capture.Ingestor.validate_performance/1","doc":"Validates that ingestion performance meets targets.\n\nReturns `:ok` if performance is acceptable, `{:error, reason}` otherwise.","ref":"ElixirScope.Capture.Ingestor.html#validate_performance/1"},{"type":"module","title":"ElixirScope.Capture.InstrumentationRuntime","doc":"Runtime API for instrumented code to report events to ElixirScope.\n\nThis module provides the interface that AST-transformed code will call.\nIt must be extremely fast and have graceful degradation when ElixirScope\nis disabled or not available.\n\nKey design principles:\n- Minimal overhead when disabled (single boolean check)\n- No crashes if ElixirScope is not running\n- Efficient correlation ID management\n- Support for nested function calls","ref":"ElixirScope.Capture.InstrumentationRuntime.html"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.clear_context/0","doc":"Clears the instrumentation context for the current process.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#clear_context/0"},{"type":"type","title":"ElixirScope.Capture.InstrumentationRuntime.correlation_id/0","doc":"","ref":"ElixirScope.Capture.InstrumentationRuntime.html#t:correlation_id/0"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.current_correlation_id/0","doc":"Gets the current correlation ID (for nested calls).","ref":"ElixirScope.Capture.InstrumentationRuntime.html#current_correlation_id/0"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.enabled?/0","doc":"Checks if instrumentation is enabled for the current process.\n\nThis is the fastest possible check - just a process dictionary lookup.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#enabled?/0"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.get_ast_correlation_metadata/0","doc":"Gets AST correlation metadata for the current context.\n\nReturns metadata that can be used to correlate runtime events with AST nodes.\nUsed internally by AST correlation functions.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#get_ast_correlation_metadata/0"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.initialize_context/0","doc":"Initializes the instrumentation context for the current process.\n\nThis should be called when a process starts or when ElixirScope is enabled.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#initialize_context/0"},{"type":"type","title":"ElixirScope.Capture.InstrumentationRuntime.instrumentation_context/0","doc":"","ref":"ElixirScope.Capture.InstrumentationRuntime.html#t:instrumentation_context/0"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.measure_overhead/1","doc":"Measures the overhead of instrumentation calls.\n\nReturns timing statistics for performance validation.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#measure_overhead/1"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_ast_branch_execution/6","doc":"Reports AST conditional branch execution with node correlation.\n\nUsed to track which branches of conditionals (if/case/cond) are taken.\nProvides insights into code path execution patterns.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_ast_branch_execution/6"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_ast_correlation_performance/3","doc":"Reports AST correlation performance metrics.\n\nUsed to track the performance impact of AST correlation features.\nHelps ensure <5ms correlation latency target is met.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_ast_correlation_performance/3"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_ast_expression_value/5","doc":"Reports AST expression evaluation with node correlation.\n\nThis version includes AST node ID for direct correlation with the AST Repository.\nUsed to track specific expression evaluations in the hybrid architecture.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_ast_expression_value/5"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_ast_function_entry/4","doc":"Reports AST function entry with source tagging.\n\nThis is similar to report_function_entry but specifically for AST-injected calls.\nEnhanced to support AST node correlation for hybrid architecture.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_ast_function_entry/4"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_ast_function_entry_with_node_id/5","doc":"Reports AST function entry with enhanced correlation metadata.\n\nThis version includes AST node ID for direct correlation with the AST Repository.\nUsed by the enhanced AST transformer for hybrid architecture support.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_ast_function_entry_with_node_id/5"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_ast_function_exit/3","doc":"Reports AST function exit with source tagging.\nEnhanced to support AST node correlation for hybrid architecture.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_ast_function_exit/3"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_ast_function_exit_with_node_id/4","doc":"Reports AST function exit with enhanced correlation metadata.\n\nThis version includes AST node ID for direct correlation with the AST Repository.\nUsed by the enhanced AST transformer for hybrid architecture support.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_ast_function_exit_with_node_id/4"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_ast_line_execution/4","doc":"Reports AST line execution with node correlation.\n\nThis version includes AST node ID for direct correlation with the AST Repository.\nUsed to track specific line executions in the hybrid architecture.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_ast_line_execution/4"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_ast_loop_iteration/6","doc":"Reports AST loop iteration with node correlation.\n\nUsed to track loop iterations (Enum.map, for comprehensions, etc.).\nProvides insights into iteration patterns and performance.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_ast_loop_iteration/6"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_ast_pattern_match/6","doc":"Reports AST pattern match with node correlation.\n\nUsed to track pattern matching operations in the hybrid architecture.\nProvides insights into pattern match success/failure and variable bindings.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_ast_pattern_match/6"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_ast_variable_snapshot/4","doc":"Reports a local variable snapshot with AST node correlation.\n\nThis version includes AST node ID for direct correlation with the AST Repository.\nUsed by the enhanced AST transformer for hybrid architecture support.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_ast_variable_snapshot/4"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_ecto_query_complete/5","doc":"Reports Ecto query completion.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_ecto_query_complete/5"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_ecto_query_start/5","doc":"Reports Ecto query start.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_ecto_query_start/5"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_error/3","doc":"Reports an error event.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_error/3"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_expression_value/5","doc":"Reports an expression value (AST-specific).\n\nThis is called by AST-injected code to capture the value of specific\nexpressions during execution.\nEnhanced to support AST node correlation for hybrid architecture.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_expression_value/5"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_function_entry/3","doc":"Reports a function call entry.\n\nThis is called at the beginning of every instrumented function.\nMust be extremely fast - target <100ns when disabled, <500ns when enabled.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_function_entry/3"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_function_entry/4","doc":"Reports function entry (4-arity version).","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_function_entry/4"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_function_exit/3","doc":"Reports a function call exit.\n\nThis is called at the end of every instrumented function.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_function_exit/3"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_function_exit/5","doc":"Reports function exit (5-arity version).","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_function_exit/5"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_genserver_callback_complete/3","doc":"Reports GenServer callback completion.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_genserver_callback_complete/3"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_genserver_callback_error/4","doc":"Reports GenServer callback error.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_genserver_callback_error/4"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_genserver_callback_start/3","doc":"Reports GenServer callback start.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_genserver_callback_start/3"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_genserver_callback_success/3","doc":"Reports GenServer callback success.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_genserver_callback_success/3"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_line_execution/4","doc":"Reports line execution (AST-specific).\n\nThis is called by AST-injected code to mark execution of specific lines.\nEnhanced to support AST node correlation for hybrid architecture.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_line_execution/4"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_liveview_assigns/3","doc":"Reports LiveView assigns.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_liveview_assigns/3"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_liveview_callback/2","doc":"Reports LiveView callback.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_liveview_callback/2"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_liveview_callback_error/4","doc":"Reports LiveView callback error.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_liveview_callback_error/4"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_liveview_callback_success/3","doc":"Reports LiveView callback success.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_liveview_callback_success/3"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_liveview_event/4","doc":"Reports LiveView event.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_liveview_event/4"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_liveview_handle_event_complete/5","doc":"Reports LiveView handle_event completion.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_liveview_handle_event_complete/5"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_liveview_handle_event_start/4","doc":"Reports LiveView handle_event start.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_liveview_handle_event_start/4"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_liveview_mount_complete/3","doc":"Reports LiveView mount completion.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_liveview_mount_complete/3"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_liveview_mount_start/4","doc":"Reports LiveView mount start.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_liveview_mount_start/4"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_local_variable_snapshot/4","doc":"Reports a local variable snapshot (AST-specific).\n\nThis is called by AST-injected code to capture local variable values\nat specific points in function execution.\nEnhanced to support AST node correlation for hybrid architecture.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_local_variable_snapshot/4"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_message_send/2","doc":"Reports a message send event.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_message_send/2"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_node_event/3","doc":"Reports node events.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_node_event/3"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_partition_detected/2","doc":"Reports partition detection.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_partition_detected/2"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_phoenix_action_complete/3","doc":"Reports Phoenix action completion.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_phoenix_action_complete/3"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_phoenix_action_error/4","doc":"Reports Phoenix action error.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_phoenix_action_error/4"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_phoenix_action_params/4","doc":"Reports Phoenix action parameters.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_phoenix_action_params/4"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_phoenix_action_start/3","doc":"Reports Phoenix action start.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_phoenix_action_start/3"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_phoenix_action_success/3","doc":"Reports Phoenix action success.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_phoenix_action_success/3"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_phoenix_channel_join_complete/4","doc":"Reports Phoenix channel join completion.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_phoenix_channel_join_complete/4"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_phoenix_channel_join_start/4","doc":"Reports Phoenix channel join start.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_phoenix_channel_join_start/4"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_phoenix_channel_message_complete/4","doc":"Reports Phoenix channel message completion.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_phoenix_channel_message_complete/4"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_phoenix_channel_message_start/4","doc":"Reports Phoenix channel message start.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_phoenix_channel_message_start/4"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_phoenix_controller_entry/4","doc":"Reports Phoenix controller entry.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_phoenix_controller_entry/4"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_phoenix_controller_exit/4","doc":"Reports Phoenix controller exit.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_phoenix_controller_exit/4"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_phoenix_request_complete/4","doc":"Reports Phoenix request completion.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_phoenix_request_complete/4"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_phoenix_request_start/5","doc":"Reports Phoenix request start.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_phoenix_request_start/5"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_process_spawn/1","doc":"Reports a process spawn event.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_process_spawn/1"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.report_state_change/2","doc":"Reports a state change event (for GenServer, Agent, etc.).","ref":"ElixirScope.Capture.InstrumentationRuntime.html#report_state_change/2"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.validate_ast_node_id/1","doc":"Validates AST node ID format for correlation.\n\nEnsures AST node IDs follow the expected format for the hybrid architecture.\nReturns {:ok, node_id} or {:error, reason}.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#validate_ast_node_id/1"},{"type":"function","title":"ElixirScope.Capture.InstrumentationRuntime.with_instrumentation_disabled/1","doc":"Temporarily disables instrumentation for the current process.\n\nUseful for avoiding recursive instrumentation in ElixirScope's own code.","ref":"ElixirScope.Capture.InstrumentationRuntime.html#with_instrumentation_disabled/1"},{"type":"module","title":"ElixirScope.Capture.PipelineManager","doc":"PipelineManager supervises all Layer 2 asynchronous processing components.\n\nThis module manages:\n- AsyncWriterPool for processing events from ring buffers\n- EventCorrelator for establishing causal relationships\n- BackpressureManager for load management\n- Dynamic configuration updates","ref":"ElixirScope.Capture.PipelineManager.html"},{"type":"function","title":"ElixirScope.Capture.PipelineManager.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ElixirScope.Capture.PipelineManager.html#child_spec/1"},{"type":"function","title":"ElixirScope.Capture.PipelineManager.get_metrics/1","doc":"Gets current metrics about pipeline performance.","ref":"ElixirScope.Capture.PipelineManager.html#get_metrics/1"},{"type":"function","title":"ElixirScope.Capture.PipelineManager.get_state/1","doc":"Gets the current state of the PipelineManager.","ref":"ElixirScope.Capture.PipelineManager.html#get_state/1"},{"type":"function","title":"ElixirScope.Capture.PipelineManager.health_check/1","doc":"Performs a health check on the pipeline.","ref":"ElixirScope.Capture.PipelineManager.html#health_check/1"},{"type":"function","title":"ElixirScope.Capture.PipelineManager.shutdown/1","doc":"Gracefully shuts down the pipeline manager and all children.","ref":"ElixirScope.Capture.PipelineManager.html#shutdown/1"},{"type":"function","title":"ElixirScope.Capture.PipelineManager.start_link/1","doc":"Starts the PipelineManager with optional configuration.","ref":"ElixirScope.Capture.PipelineManager.html#start_link/1"},{"type":"function","title":"ElixirScope.Capture.PipelineManager.update_config/2","doc":"Updates the configuration dynamically.","ref":"ElixirScope.Capture.PipelineManager.html#update_config/2"},{"type":"module","title":"ElixirScope.Capture.RingBuffer","doc":"High-performance lock-free ring buffer for event ingestion.\n\nUses :atomics for lock-free operations and :persistent_term for metadata storage.\nDesigned for >100k events/sec throughput with bounded memory usage.\n\nKey features:\n- Lock-free writes using atomic compare-and-swap\n- Bounded memory with configurable overflow behavior\n- Multiple reader support with position tracking\n- Minimal allocation overhead\n- Graceful degradation under extreme load","ref":"ElixirScope.Capture.RingBuffer.html"},{"type":"type","title":"ElixirScope.Capture.RingBuffer.buffer_id/0","doc":"","ref":"ElixirScope.Capture.RingBuffer.html#t:buffer_id/0"},{"type":"function","title":"ElixirScope.Capture.RingBuffer.clear/1","doc":"Clears all events from the buffer and resets counters.","ref":"ElixirScope.Capture.RingBuffer.html#clear/1"},{"type":"function","title":"ElixirScope.Capture.RingBuffer.destroy/1","doc":"Destroys the buffer and cleans up resources.","ref":"ElixirScope.Capture.RingBuffer.html#destroy/1"},{"type":"function","title":"ElixirScope.Capture.RingBuffer.new/1","doc":"Creates a new ring buffer with the specified configuration.","ref":"ElixirScope.Capture.RingBuffer.html#new/1"},{"type":"function","title":"Options - ElixirScope.Capture.RingBuffer.new/1","doc":"- `:size` - Buffer size (must be power of 2, default: 1024)\n- `:overflow_strategy` - What to do when buffer is full (default: drop_oldest)\n- `:name` - Optional name for the buffer (default: generates unique name)","ref":"ElixirScope.Capture.RingBuffer.html#new/1-options"},{"type":"function","title":"Examples - ElixirScope.Capture.RingBuffer.new/1","doc":"iex> {:ok, buffer} = RingBuffer.new(size: 1024)\n    iex> RingBuffer.size(buffer)\n    1024","ref":"ElixirScope.Capture.RingBuffer.html#new/1-examples"},{"type":"type","title":"ElixirScope.Capture.RingBuffer.overflow_strategy/0","doc":"","ref":"ElixirScope.Capture.RingBuffer.html#t:overflow_strategy/0"},{"type":"type","title":"ElixirScope.Capture.RingBuffer.position/0","doc":"","ref":"ElixirScope.Capture.RingBuffer.html#t:position/0"},{"type":"function","title":"ElixirScope.Capture.RingBuffer.read/2","doc":"Reads the next available event from the buffer.\n\nReturns `{:ok, event, new_position}` or `:empty` if no events available.","ref":"ElixirScope.Capture.RingBuffer.html#read/2"},{"type":"function","title":"ElixirScope.Capture.RingBuffer.read_batch/3","doc":"Reads multiple events in batch for better throughput.\n\nReturns `{events, new_position}` where events is a list of up to `count` events.","ref":"ElixirScope.Capture.RingBuffer.html#read_batch/3"},{"type":"function","title":"ElixirScope.Capture.RingBuffer.size/1","doc":"Returns the buffer size.","ref":"ElixirScope.Capture.RingBuffer.html#size/1"},{"type":"function","title":"ElixirScope.Capture.RingBuffer.stats/1","doc":"Gets current buffer statistics.","ref":"ElixirScope.Capture.RingBuffer.html#stats/1"},{"type":"type","title":"ElixirScope.Capture.RingBuffer.t/0","doc":"","ref":"ElixirScope.Capture.RingBuffer.html#t:t/0"},{"type":"function","title":"ElixirScope.Capture.RingBuffer.write/2","doc":"Writes an event to the ring buffer.\n\nThis is the critical hot path - optimized for minimal latency.\nTarget: <1µs per write operation.","ref":"ElixirScope.Capture.RingBuffer.html#write/2"},{"type":"function","title":"Examples - ElixirScope.Capture.RingBuffer.write/2","doc":"iex> {:ok, buffer} = RingBuffer.new()\n    iex> event = %Events.FunctionExecution{function: :test}\n    iex> :ok = RingBuffer.write(buffer, event)","ref":"ElixirScope.Capture.RingBuffer.html#write/2-examples"},{"type":"module","title":"ElixirScope.Capture.TemporalBridge","doc":"Bridge between InstrumentationRuntime and TemporalStorage for real-time temporal correlation.\n\nThis module provides the integration layer that connects runtime event capture\nwith temporal storage and AST correlation, enabling Cinema Debugger functionality.","ref":"ElixirScope.Capture.TemporalBridge.html"},{"type":"module","title":"Features - ElixirScope.Capture.TemporalBridge","doc":"- Real-time event correlation with AST nodes\n- Temporal indexing of runtime events\n- Integration with existing InstrumentationRuntime\n- Cinema Debugger query interface\n- Performance-optimized event processing","ref":"ElixirScope.Capture.TemporalBridge.html#module-features"},{"type":"module","title":"Architecture - ElixirScope.Capture.TemporalBridge","doc":"```\nInstrumentationRuntime → TemporalBridge → TemporalStorage\n                              ↓\n                      AST Node Correlation\n                              ↓\n                      Cinema Debugger Queries\n```","ref":"ElixirScope.Capture.TemporalBridge.html#module-architecture"},{"type":"module","title":"Usage - ElixirScope.Capture.TemporalBridge","doc":"# Start the temporal bridge\n    {:ok, bridge} = TemporalBridge.start_link()\n    \n    # Events from InstrumentationRuntime are automatically correlated\n    # and stored in TemporalStorage for Cinema Debugger queries\n    \n    # Query temporal events\n    {:ok, events} = TemporalBridge.get_events_in_range(bridge, start_time, end_time)\n    {:ok, events} = TemporalBridge.get_events_for_ast_node(bridge, \"function_def_123\")","ref":"ElixirScope.Capture.TemporalBridge.html#module-usage"},{"type":"type","title":"ElixirScope.Capture.TemporalBridge.ast_node_id/0","doc":"","ref":"ElixirScope.Capture.TemporalBridge.html#t:ast_node_id/0"},{"type":"type","title":"ElixirScope.Capture.TemporalBridge.bridge_ref/0","doc":"","ref":"ElixirScope.Capture.TemporalBridge.html#t:bridge_ref/0"},{"type":"function","title":"ElixirScope.Capture.TemporalBridge.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ElixirScope.Capture.TemporalBridge.html#child_spec/1"},{"type":"function","title":"ElixirScope.Capture.TemporalBridge.correlate_event/2","doc":"Correlates and stores a runtime event with temporal indexing.\n\nThis is called by InstrumentationRuntime to store events with\nAST correlation and temporal indexing.","ref":"ElixirScope.Capture.TemporalBridge.html#correlate_event/2"},{"type":"function","title":"Examples - ElixirScope.Capture.TemporalBridge.correlate_event/2","doc":"event = %{\n      timestamp: Utils.monotonic_timestamp(),\n      correlation_id: \"exec_123\",\n      ast_node_id: \"function_def_456\",\n      event_type: :function_entry,\n      data: %{module: MyModule, function: :my_function}\n    }\n    \n    :ok = TemporalBridge.correlate_event(bridge, event)","ref":"ElixirScope.Capture.TemporalBridge.html#correlate_event/2-examples"},{"type":"type","title":"ElixirScope.Capture.TemporalBridge.correlation_id/0","doc":"","ref":"ElixirScope.Capture.TemporalBridge.html#t:correlation_id/0"},{"type":"function","title":"ElixirScope.Capture.TemporalBridge.flush_buffer/1","doc":"Flushes the event buffer to TemporalStorage.","ref":"ElixirScope.Capture.TemporalBridge.html#flush_buffer/1"},{"type":"function","title":"Examples - ElixirScope.Capture.TemporalBridge.flush_buffer/1","doc":":ok = TemporalBridge.flush_buffer(bridge)","ref":"ElixirScope.Capture.TemporalBridge.html#flush_buffer/1-examples"},{"type":"function","title":"ElixirScope.Capture.TemporalBridge.get_active_ast_nodes/3","doc":"Gets AST nodes that were active during a time range.\n\nThis is a Cinema Debugger primitive that shows which AST nodes\nhad events during a specific time window.","ref":"ElixirScope.Capture.TemporalBridge.html#get_active_ast_nodes/3"},{"type":"function","title":"Examples - ElixirScope.Capture.TemporalBridge.get_active_ast_nodes/3","doc":"{:ok, nodes} = TemporalBridge.get_active_ast_nodes(bridge, start_time, end_time)","ref":"ElixirScope.Capture.TemporalBridge.html#get_active_ast_nodes/3-examples"},{"type":"function","title":"ElixirScope.Capture.TemporalBridge.get_events_for_ast_node/2","doc":"Gets events associated with a specific AST node.","ref":"ElixirScope.Capture.TemporalBridge.html#get_events_for_ast_node/2"},{"type":"function","title":"Examples - ElixirScope.Capture.TemporalBridge.get_events_for_ast_node/2","doc":"{:ok, events} = TemporalBridge.get_events_for_ast_node(bridge, \"function_def_123\")","ref":"ElixirScope.Capture.TemporalBridge.html#get_events_for_ast_node/2-examples"},{"type":"function","title":"ElixirScope.Capture.TemporalBridge.get_events_for_correlation/2","doc":"Gets events associated with a specific correlation ID.","ref":"ElixirScope.Capture.TemporalBridge.html#get_events_for_correlation/2"},{"type":"function","title":"Examples - ElixirScope.Capture.TemporalBridge.get_events_for_correlation/2","doc":"{:ok, events} = TemporalBridge.get_events_for_correlation(bridge, \"exec_456\")","ref":"ElixirScope.Capture.TemporalBridge.html#get_events_for_correlation/2-examples"},{"type":"function","title":"ElixirScope.Capture.TemporalBridge.get_events_in_range/3","doc":"Gets events within a time range with AST correlation.","ref":"ElixirScope.Capture.TemporalBridge.html#get_events_in_range/3"},{"type":"function","title":"Examples - ElixirScope.Capture.TemporalBridge.get_events_in_range/3","doc":"{:ok, events} = TemporalBridge.get_events_in_range(bridge, start_time, end_time)","ref":"ElixirScope.Capture.TemporalBridge.html#get_events_in_range/3-examples"},{"type":"function","title":"ElixirScope.Capture.TemporalBridge.get_registered_bridge/0","doc":"Gets the currently registered temporal bridge.\n\nThis is used by InstrumentationRuntime to send events to the bridge.","ref":"ElixirScope.Capture.TemporalBridge.html#get_registered_bridge/0"},{"type":"function","title":"Examples - ElixirScope.Capture.TemporalBridge.get_registered_bridge/0","doc":"{:ok, bridge} = TemporalBridge.get_registered_bridge()","ref":"ElixirScope.Capture.TemporalBridge.html#get_registered_bridge/0-examples"},{"type":"function","title":"ElixirScope.Capture.TemporalBridge.get_stats/1","doc":"Gets bridge statistics and performance metrics.","ref":"ElixirScope.Capture.TemporalBridge.html#get_stats/1"},{"type":"function","title":"Examples - ElixirScope.Capture.TemporalBridge.get_stats/1","doc":"{:ok, stats} = TemporalBridge.get_stats(bridge)","ref":"ElixirScope.Capture.TemporalBridge.html#get_stats/1-examples"},{"type":"function","title":"ElixirScope.Capture.TemporalBridge.reconstruct_state_at/2","doc":"Reconstructs system state at a specific point in time.\n\nThis is a Cinema Debugger primitive that analyzes all events\nup to a specific timestamp to reconstruct system state.","ref":"ElixirScope.Capture.TemporalBridge.html#reconstruct_state_at/2"},{"type":"function","title":"Examples - ElixirScope.Capture.TemporalBridge.reconstruct_state_at/2","doc":"{:ok, state} = TemporalBridge.reconstruct_state_at(bridge, timestamp)","ref":"ElixirScope.Capture.TemporalBridge.html#reconstruct_state_at/2-examples"},{"type":"function","title":"ElixirScope.Capture.TemporalBridge.register_as_handler/1","doc":"Registers this bridge as the temporal correlation handler.\n\nThis integrates the bridge with InstrumentationRuntime so that\nevents are automatically correlated and stored.","ref":"ElixirScope.Capture.TemporalBridge.html#register_as_handler/1"},{"type":"function","title":"Examples - ElixirScope.Capture.TemporalBridge.register_as_handler/1","doc":":ok = TemporalBridge.register_as_handler(bridge)","ref":"ElixirScope.Capture.TemporalBridge.html#register_as_handler/1-examples"},{"type":"function","title":"ElixirScope.Capture.TemporalBridge.start_link/1","doc":"Starts the TemporalBridge process.","ref":"ElixirScope.Capture.TemporalBridge.html#start_link/1"},{"type":"function","title":"Options - ElixirScope.Capture.TemporalBridge.start_link/1","doc":"- `:name` - Process name (optional)\n- `:temporal_storage` - Existing TemporalStorage process (optional)\n- `:buffer_size` - Event buffer size (default: 1000)\n- `:flush_interval` - Buffer flush interval in ms (default: 100)","ref":"ElixirScope.Capture.TemporalBridge.html#start_link/1-options"},{"type":"function","title":"Examples - ElixirScope.Capture.TemporalBridge.start_link/1","doc":"{:ok, bridge} = TemporalBridge.start_link()\n    {:ok, bridge} = TemporalBridge.start_link(name: :main_bridge)","ref":"ElixirScope.Capture.TemporalBridge.html#start_link/1-examples"},{"type":"type","title":"ElixirScope.Capture.TemporalBridge.t/0","doc":"","ref":"ElixirScope.Capture.TemporalBridge.html#t:t/0"},{"type":"type","title":"ElixirScope.Capture.TemporalBridge.temporal_event/0","doc":"","ref":"ElixirScope.Capture.TemporalBridge.html#t:temporal_event/0"},{"type":"function","title":"ElixirScope.Capture.TemporalBridge.trace_execution_path/2","doc":"Traces execution path leading to a specific event.\n\nThis is a Cinema Debugger primitive that reconstructs the\nexecution sequence that led to a particular event.","ref":"ElixirScope.Capture.TemporalBridge.html#trace_execution_path/2"},{"type":"function","title":"Examples - ElixirScope.Capture.TemporalBridge.trace_execution_path/2","doc":"{:ok, path} = TemporalBridge.trace_execution_path(bridge, target_event)","ref":"ElixirScope.Capture.TemporalBridge.html#trace_execution_path/2-examples"},{"type":"function","title":"ElixirScope.Capture.TemporalBridge.unregister_handler/0","doc":"Unregisters this bridge as the temporal correlation handler.","ref":"ElixirScope.Capture.TemporalBridge.html#unregister_handler/0"},{"type":"function","title":"Examples - ElixirScope.Capture.TemporalBridge.unregister_handler/0","doc":":ok = TemporalBridge.unregister_handler()","ref":"ElixirScope.Capture.TemporalBridge.html#unregister_handler/0-examples"},{"type":"module","title":"ElixirScope.Capture.TemporalStorage","doc":"Temporal storage for events with AST correlation and time-based indexing.\n\nProvides efficient storage and querying of events with temporal ordering\nand AST node correlation for Cinema Debugger functionality.","ref":"ElixirScope.Capture.TemporalStorage.html"},{"type":"module","title":"Features - ElixirScope.Capture.TemporalStorage","doc":"- Time-ordered event storage\n- AST node correlation tracking\n- Efficient time-range queries\n- Memory-efficient indexing","ref":"ElixirScope.Capture.TemporalStorage.html#module-features"},{"type":"module","title":"Usage - ElixirScope.Capture.TemporalStorage","doc":"{:ok, storage} = TemporalStorage.start_link()\n    \n    event = %{\n      timestamp: 1000,\n      ast_node_id: \"node1\", \n      correlation_id: \"corr1\",\n      data: %{...}\n    }\n    \n    :ok = TemporalStorage.store_event(storage, event)\n    \n    {:ok, events} = TemporalStorage.get_events_in_range(storage, 1000, 2000)","ref":"ElixirScope.Capture.TemporalStorage.html#module-usage"},{"type":"function","title":"ElixirScope.Capture.TemporalStorage.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ElixirScope.Capture.TemporalStorage.html#child_spec/1"},{"type":"type","title":"ElixirScope.Capture.TemporalStorage.event/0","doc":"","ref":"ElixirScope.Capture.TemporalStorage.html#t:event/0"},{"type":"function","title":"ElixirScope.Capture.TemporalStorage.get_all_events/1","doc":"Gets all events in chronological order.","ref":"ElixirScope.Capture.TemporalStorage.html#get_all_events/1"},{"type":"function","title":"Examples - ElixirScope.Capture.TemporalStorage.get_all_events/1","doc":"{:ok, all_events} = TemporalStorage.get_all_events(storage)","ref":"ElixirScope.Capture.TemporalStorage.html#get_all_events/1-examples"},{"type":"function","title":"ElixirScope.Capture.TemporalStorage.get_events_for_ast_node/2","doc":"Gets events associated with a specific AST node.","ref":"ElixirScope.Capture.TemporalStorage.html#get_events_for_ast_node/2"},{"type":"function","title":"Examples - ElixirScope.Capture.TemporalStorage.get_events_for_ast_node/2","doc":"{:ok, events} = TemporalStorage.get_events_for_ast_node(storage, \"function_def_123\")","ref":"ElixirScope.Capture.TemporalStorage.html#get_events_for_ast_node/2-examples"},{"type":"function","title":"ElixirScope.Capture.TemporalStorage.get_events_for_correlation/2","doc":"Gets events associated with a specific correlation ID.","ref":"ElixirScope.Capture.TemporalStorage.html#get_events_for_correlation/2"},{"type":"function","title":"Examples - ElixirScope.Capture.TemporalStorage.get_events_for_correlation/2","doc":"{:ok, events} = TemporalStorage.get_events_for_correlation(storage, \"exec_456\")","ref":"ElixirScope.Capture.TemporalStorage.html#get_events_for_correlation/2-examples"},{"type":"function","title":"ElixirScope.Capture.TemporalStorage.get_events_in_range/3","doc":"Retrieves events within a time range, ordered chronologically.","ref":"ElixirScope.Capture.TemporalStorage.html#get_events_in_range/3"},{"type":"function","title":"Examples - ElixirScope.Capture.TemporalStorage.get_events_in_range/3","doc":"# Get events from last 5 seconds\n    now = Utils.monotonic_timestamp()\n    {:ok, events} = TemporalStorage.get_events_in_range(storage, now - 5000, now)\n    \n    # Get all events in a specific window\n    {:ok, events} = TemporalStorage.get_events_in_range(storage, 1000, 2000)","ref":"ElixirScope.Capture.TemporalStorage.html#get_events_in_range/3-examples"},{"type":"function","title":"ElixirScope.Capture.TemporalStorage.get_stats/1","doc":"Gets storage statistics.","ref":"ElixirScope.Capture.TemporalStorage.html#get_stats/1"},{"type":"function","title":"Examples - ElixirScope.Capture.TemporalStorage.get_stats/1","doc":"{:ok, stats} = TemporalStorage.get_stats(storage)\n    # %{\n    #   total_events: 1234,\n    #   memory_usage: 5678,\n    #   oldest_event: 1000,\n    #   newest_event: 2000\n    # }","ref":"ElixirScope.Capture.TemporalStorage.html#get_stats/1-examples"},{"type":"function","title":"ElixirScope.Capture.TemporalStorage.start_link/1","doc":"Starts a new TemporalStorage process.","ref":"ElixirScope.Capture.TemporalStorage.html#start_link/1"},{"type":"function","title":"Options - ElixirScope.Capture.TemporalStorage.start_link/1","doc":"- `:name` - Process name (optional)\n- `:max_events` - Maximum events to store (default: 100,000)\n- `:cleanup_interval` - Cleanup interval in ms (default: 60,000)","ref":"ElixirScope.Capture.TemporalStorage.html#start_link/1-options"},{"type":"function","title":"Examples - ElixirScope.Capture.TemporalStorage.start_link/1","doc":"{:ok, storage} = TemporalStorage.start_link()\n    {:ok, storage} = TemporalStorage.start_link(name: :my_storage)","ref":"ElixirScope.Capture.TemporalStorage.html#start_link/1-examples"},{"type":"type","title":"ElixirScope.Capture.TemporalStorage.storage_ref/0","doc":"","ref":"ElixirScope.Capture.TemporalStorage.html#t:storage_ref/0"},{"type":"function","title":"ElixirScope.Capture.TemporalStorage.store_event/2","doc":"Stores an event with temporal indexing.\n\nEvents are automatically indexed by timestamp and optionally by\nAST node ID and correlation ID for efficient querying.","ref":"ElixirScope.Capture.TemporalStorage.html#store_event/2"},{"type":"function","title":"Examples - ElixirScope.Capture.TemporalStorage.store_event/2","doc":"event = %{\n      timestamp: Utils.monotonic_timestamp(),\n      ast_node_id: \"function_def_123\",\n      correlation_id: \"exec_456\",\n      data: %{function: :my_function, args: [1, 2, 3]}\n    }\n    \n    :ok = TemporalStorage.store_event(storage, event)","ref":"ElixirScope.Capture.TemporalStorage.html#store_event/2-examples"},{"type":"type","title":"ElixirScope.Capture.TemporalStorage.t/0","doc":"","ref":"ElixirScope.Capture.TemporalStorage.html#t:t/0"},{"type":"type","title":"ElixirScope.Capture.TemporalStorage.time_range/0","doc":"","ref":"ElixirScope.Capture.TemporalStorage.html#t:time_range/0"},{"type":"module","title":"ElixirScope.CompileTime.Orchestrator","doc":"Orchestrates compile-time AST instrumentation by generating detailed plans\nbased on user requests and AI analysis.\n\nThis module:\n- Takes high-level instrumentation requests\n- Analyzes target modules using AI.CodeAnalyzer\n- Generates detailed AST transformation plans\n- Coordinates with the unified tracing system","ref":"ElixirScope.CompileTime.Orchestrator.html"},{"type":"function","title":"ElixirScope.CompileTime.Orchestrator.generate_function_plan/4","doc":"Generates a plan for on-demand instrumentation of a specific function.","ref":"ElixirScope.CompileTime.Orchestrator.html#generate_function_plan/4"},{"type":"function","title":"ElixirScope.CompileTime.Orchestrator.generate_plan/2","doc":"Generates an AST instrumentation plan for the given target and options.","ref":"ElixirScope.CompileTime.Orchestrator.html#generate_plan/2"},{"type":"function","title":"Examples - ElixirScope.CompileTime.Orchestrator.generate_plan/2","doc":"# Basic function instrumentation\n    plan = generate_plan(MyModule, %{functions: [:my_func]})\n    \n    # Granular variable capture\n    plan = generate_plan(MyModule, %{\n      functions: [:complex_calc],\n      capture_locals: [:temp1, :temp2, :result],\n      after_line: 42\n    })\n    \n    # Expression tracing\n    plan = generate_plan(MyModule, %{\n      functions: [:algorithm],\n      trace_expressions: [:process_item, :calculate_result]\n    })","ref":"ElixirScope.CompileTime.Orchestrator.html#generate_plan/2-examples"},{"type":"module","title":"ElixirScope.Compiler.MixTask","doc":"","ref":"ElixirScope.Compiler.MixTask.html"},{"type":"function","title":"ElixirScope.Compiler.MixTask.transform_ast/2","doc":"See  Mix.Tasks.Compile.ElixirScope.transform_ast/2 .","ref":"ElixirScope.Compiler.MixTask.html#transform_ast/2"},{"type":"module","title":"ElixirScope.Config","doc":"Configuration management for ElixirScope.\n\nHandles loading, validation, and runtime access to ElixirScope configuration.\nSupports configuration from multiple sources:\n- Application environment (config.exs files)\n- Environment variables\n- Runtime configuration updates\n\nThe configuration is validated on startup and cached for fast access.","ref":"ElixirScope.Config.html"},{"type":"function","title":"ElixirScope.Config.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ElixirScope.Config.html#child_spec/1"},{"type":"function","title":"ElixirScope.Config.get/0","doc":"Gets the current configuration.","ref":"ElixirScope.Config.html#get/0"},{"type":"function","title":"ElixirScope.Config.get/1","doc":"Gets a specific configuration value by path.","ref":"ElixirScope.Config.html#get/1"},{"type":"function","title":"Examples - ElixirScope.Config.get/1","doc":"iex> ElixirScope.Config.get([:ai, :provider])\n    :mock\n    \n    iex> ElixirScope.Config.get([:capture, :ring_buffer, :size])\n    1048576","ref":"ElixirScope.Config.html#get/1-examples"},{"type":"function","title":"ElixirScope.Config.start_link/1","doc":"Starts the configuration server.","ref":"ElixirScope.Config.html#start_link/1"},{"type":"function","title":"ElixirScope.Config.update/2","doc":"Updates configuration at runtime (for specific allowed keys).","ref":"ElixirScope.Config.html#update/2"},{"type":"function","title":"ElixirScope.Config.validate/1","doc":"Validates a configuration structure.\nReturns {:ok, config} or {:error, reasons}.","ref":"ElixirScope.Config.html#validate/1"},{"type":"module","title":"ElixirScope.Core.AIManager","doc":"Manages AI integration and analysis capabilities.\n\nProvides functionality for AI-powered codebase analysis and intelligent\ninstrumentation planning. This module will be enhanced in future iterations\nto provide full AI integration capabilities.","ref":"ElixirScope.Core.AIManager.html"},{"type":"function","title":"ElixirScope.Core.AIManager.analyze_codebase/1","doc":"Analyzes the codebase using AI capabilities.\n\nCurrently returns a not implemented error. This will be enhanced\nin future iterations to provide actual AI-powered analysis.","ref":"ElixirScope.Core.AIManager.html#analyze_codebase/1"},{"type":"function","title":"ElixirScope.Core.AIManager.available?/0","doc":"Checks if AI capabilities are available and configured.","ref":"ElixirScope.Core.AIManager.html#available?/0"},{"type":"function","title":"ElixirScope.Core.AIManager.configure/1","doc":"Configures AI integration settings.","ref":"ElixirScope.Core.AIManager.html#configure/1"},{"type":"function","title":"ElixirScope.Core.AIManager.get_model_info/0","doc":"Gets AI model information and capabilities.","ref":"ElixirScope.Core.AIManager.html#get_model_info/0"},{"type":"function","title":"ElixirScope.Core.AIManager.get_statistics/0","doc":"Gets AI analysis statistics and capabilities.\n\nReturns information about AI model status, analysis history, etc.","ref":"ElixirScope.Core.AIManager.html#get_statistics/0"},{"type":"function","title":"ElixirScope.Core.AIManager.recommend_instrumentation/1","doc":"Generates instrumentation recommendations for specific modules.","ref":"ElixirScope.Core.AIManager.html#recommend_instrumentation/1"},{"type":"function","title":"ElixirScope.Core.AIManager.update_instrumentation/1","doc":"Updates instrumentation configuration based on AI recommendations.\n\nCurrently returns a not implemented error. This will be enhanced\nin future iterations to provide intelligent instrumentation updates.","ref":"ElixirScope.Core.AIManager.html#update_instrumentation/1"},{"type":"module","title":"ElixirScope.Core.EventManager","doc":"Manages runtime event querying and filtering.\n\nBridges RuntimeCorrelator with main API to provide user-facing event querying\ncapabilities. This module translates high-level query requests into specific\nRuntimeCorrelator operations.","ref":"ElixirScope.Core.EventManager.html"},{"type":"type","title":"ElixirScope.Core.EventManager.event_query/0","doc":"","ref":"ElixirScope.Core.EventManager.html#t:event_query/0"},{"type":"function","title":"ElixirScope.Core.EventManager.get_correlation_statistics/0","doc":"Gets correlation statistics from RuntimeCorrelator.","ref":"ElixirScope.Core.EventManager.html#get_correlation_statistics/0"},{"type":"function","title":"ElixirScope.Core.EventManager.get_events/1","doc":"Gets events based on query criteria.\n\nDelegates to RuntimeCorrelator for actual event retrieval and applies\nfiltering based on the query parameters.","ref":"ElixirScope.Core.EventManager.html#get_events/1"},{"type":"function","title":"ElixirScope.Core.EventManager.get_events_for_ast_node/1","doc":"Gets events for a specific AST node.\n\nProvides direct access to AST-correlated events through RuntimeCorrelator.","ref":"ElixirScope.Core.EventManager.html#get_events_for_ast_node/1"},{"type":"function","title":"ElixirScope.Core.EventManager.get_events_with_query/1","doc":"Gets events with a specific query filter.\n\nProvides more advanced querying capabilities with custom filter functions.","ref":"ElixirScope.Core.EventManager.html#get_events_with_query/1"},{"type":"module","title":"ElixirScope.Core.MessageTracker","doc":"Tracks message flows between processes.\n\nProvides functionality for capturing and querying message exchanges\nbetween processes. This module will be enhanced in future iterations\nto provide comprehensive message flow analysis.","ref":"ElixirScope.Core.MessageTracker.html"},{"type":"function","title":"ElixirScope.Core.MessageTracker.disable_tracking/1","doc":"Disables message tracking for a process.","ref":"ElixirScope.Core.MessageTracker.html#disable_tracking/1"},{"type":"function","title":"ElixirScope.Core.MessageTracker.enable_tracking/1","doc":"Enables message tracking for a process.\n\nThis would be used to start tracking messages for a specific process.","ref":"ElixirScope.Core.MessageTracker.html#enable_tracking/1"},{"type":"function","title":"ElixirScope.Core.MessageTracker.get_message_flow/3","doc":"Gets message flow between two processes.\n\nCurrently returns a not implemented error. This will be enhanced\nin future iterations to provide actual message flow tracking.","ref":"ElixirScope.Core.MessageTracker.html#get_message_flow/3"},{"type":"function","title":"ElixirScope.Core.MessageTracker.get_process_messages/2","doc":"Gets all message flows for a specific process.\n\nReturns both incoming and outgoing messages for the given process.","ref":"ElixirScope.Core.MessageTracker.html#get_process_messages/2"},{"type":"function","title":"ElixirScope.Core.MessageTracker.get_statistics/0","doc":"Gets message flow statistics.\n\nReturns information about message volumes, patterns, etc.","ref":"ElixirScope.Core.MessageTracker.html#get_statistics/0"},{"type":"function","title":"ElixirScope.Core.MessageTracker.tracking_enabled?/1","doc":"Checks if message tracking is enabled for a process.","ref":"ElixirScope.Core.MessageTracker.html#tracking_enabled?/1"},{"type":"module","title":"ElixirScope.Core.StateManager","doc":"Manages process state history and temporal queries.\n\nProvides functionality for tracking GenServer state changes over time\nand reconstructing state at specific timestamps. This module will be\nenhanced in future iterations to provide full state reconstruction\ncapabilities.","ref":"ElixirScope.Core.StateManager.html"},{"type":"function","title":"ElixirScope.Core.StateManager.get_state_at/2","doc":"Reconstructs the state of a GenServer at a specific timestamp.\n\nCurrently returns a not implemented error. This will be enhanced\nin future iterations to provide actual state reconstruction.","ref":"ElixirScope.Core.StateManager.html#get_state_at/2"},{"type":"function","title":"ElixirScope.Core.StateManager.get_state_history/1","doc":"Gets the state history for a GenServer process.\n\nCurrently returns a not implemented error. This will be enhanced\nin future iterations to provide actual state history tracking.","ref":"ElixirScope.Core.StateManager.html#get_state_history/1"},{"type":"function","title":"ElixirScope.Core.StateManager.get_statistics/0","doc":"Gets state tracking statistics.\n\nReturns information about how many processes are being tracked,\nstorage usage, etc.","ref":"ElixirScope.Core.StateManager.html#get_statistics/0"},{"type":"function","title":"ElixirScope.Core.StateManager.has_state_history?/1","doc":"Checks if state tracking is available for a given process.\n\nThis is a utility function to determine if we have state history\ndata for a specific process.","ref":"ElixirScope.Core.StateManager.html#has_state_history?/1"},{"type":"module","title":"ElixirScope.Distributed.EventSynchronizer","doc":"Synchronizes events across distributed ElixirScope nodes.\n\nHandles:\n- Efficient event delta synchronization\n- Conflict resolution for overlapping events\n- Bandwidth optimization for large event sets\n- Eventual consistency guarantees","ref":"ElixirScope.Distributed.EventSynchronizer.html"},{"type":"function","title":"ElixirScope.Distributed.EventSynchronizer.full_sync_with_cluster/1","doc":"Forces a full synchronization with all cluster nodes.","ref":"ElixirScope.Distributed.EventSynchronizer.html#full_sync_with_cluster/1"},{"type":"function","title":"ElixirScope.Distributed.EventSynchronizer.handle_sync_request/1","doc":"Handles incoming synchronization requests from other nodes.","ref":"ElixirScope.Distributed.EventSynchronizer.html#handle_sync_request/1"},{"type":"function","title":"ElixirScope.Distributed.EventSynchronizer.sync_with_cluster/1","doc":"Synchronizes events with all nodes in the cluster.","ref":"ElixirScope.Distributed.EventSynchronizer.html#sync_with_cluster/1"},{"type":"function","title":"ElixirScope.Distributed.EventSynchronizer.sync_with_node/2","doc":"Synchronizes events with a specific node.","ref":"ElixirScope.Distributed.EventSynchronizer.html#sync_with_node/2"},{"type":"module","title":"ElixirScope.Distributed.GlobalClock","doc":"Distributed global clock for ElixirScope event synchronization.\n\nProvides logical timestamps and clock synchronization across distributed nodes.\nUses hybrid logical clocks for ordering events across the cluster.","ref":"ElixirScope.Distributed.GlobalClock.html"},{"type":"function","title":"ElixirScope.Distributed.GlobalClock.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ElixirScope.Distributed.GlobalClock.html#child_spec/1"},{"type":"function","title":"ElixirScope.Distributed.GlobalClock.get_state/0","doc":"Gets the current state of the global clock.","ref":"ElixirScope.Distributed.GlobalClock.html#get_state/0"},{"type":"function","title":"ElixirScope.Distributed.GlobalClock.initialize_cluster/1","doc":"Initializes the cluster with the given nodes.","ref":"ElixirScope.Distributed.GlobalClock.html#initialize_cluster/1"},{"type":"function","title":"ElixirScope.Distributed.GlobalClock.now/0","doc":"Gets the current logical timestamp.","ref":"ElixirScope.Distributed.GlobalClock.html#now/0"},{"type":"function","title":"ElixirScope.Distributed.GlobalClock.start_link/1","doc":"Starts the global clock GenServer.","ref":"ElixirScope.Distributed.GlobalClock.html#start_link/1"},{"type":"function","title":"ElixirScope.Distributed.GlobalClock.sync_with_cluster/0","doc":"Synchronizes the clock with all known cluster nodes.","ref":"ElixirScope.Distributed.GlobalClock.html#sync_with_cluster/0"},{"type":"function","title":"ElixirScope.Distributed.GlobalClock.update_from_remote/2","doc":"Updates the clock with a timestamp from another node.","ref":"ElixirScope.Distributed.GlobalClock.html#update_from_remote/2"},{"type":"module","title":"ElixirScope.Distributed.NodeCoordinator","doc":"Coordinates ElixirScope tracing across multiple BEAM nodes.\n\nHandles:\n- Node discovery and registration\n- Event synchronization across nodes\n- Distributed correlation ID management\n- Network partition handling\n- Cross-node query coordination","ref":"ElixirScope.Distributed.NodeCoordinator.html"},{"type":"function","title":"ElixirScope.Distributed.NodeCoordinator.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ElixirScope.Distributed.NodeCoordinator.html#child_spec/1"},{"type":"function","title":"ElixirScope.Distributed.NodeCoordinator.distributed_query/1","doc":"Queries events across all nodes in the cluster.","ref":"ElixirScope.Distributed.NodeCoordinator.html#distributed_query/1"},{"type":"function","title":"ElixirScope.Distributed.NodeCoordinator.get_cluster_nodes/0","doc":"Gets all nodes currently in the cluster.","ref":"ElixirScope.Distributed.NodeCoordinator.html#get_cluster_nodes/0"},{"type":"function","title":"ElixirScope.Distributed.NodeCoordinator.handle_cluster_change/1","doc":"","ref":"ElixirScope.Distributed.NodeCoordinator.html#handle_cluster_change/1"},{"type":"function","title":"ElixirScope.Distributed.NodeCoordinator.register_node/1","doc":"Registers a new node with the cluster.","ref":"ElixirScope.Distributed.NodeCoordinator.html#register_node/1"},{"type":"function","title":"ElixirScope.Distributed.NodeCoordinator.setup_cluster/1","doc":"Sets up ElixirScope cluster with the given nodes.","ref":"ElixirScope.Distributed.NodeCoordinator.html#setup_cluster/1"},{"type":"function","title":"ElixirScope.Distributed.NodeCoordinator.start_link/1","doc":"Starts the NodeCoordinator for the local node.","ref":"ElixirScope.Distributed.NodeCoordinator.html#start_link/1"},{"type":"function","title":"ElixirScope.Distributed.NodeCoordinator.sync_events/0","doc":"Synchronizes events across all cluster nodes.","ref":"ElixirScope.Distributed.NodeCoordinator.html#sync_events/0"},{"type":"module","title":"ElixirScope.Events","doc":"Core event structures for ElixirScope.\n\nDefines all event types that can be captured during execution and provides\nefficient serialization/deserialization for storage and transmission.\n\nEvents are designed to be:\n- Lightweight with minimal overhead\n- Self-contained with all necessary context\n- Timestamped with high resolution\n- Correlated with unique IDs for causal analysis","ref":"ElixirScope.Events.html"},{"type":"function","title":"ElixirScope.Events.__struct__/0","doc":"Base event structure with common fields for all event types.","ref":"ElixirScope.Events.html#__struct__/0"},{"type":"function","title":"ElixirScope.Events.deserialize/1","doc":"Deserializes an event from binary format.","ref":"ElixirScope.Events.html#deserialize/1"},{"type":"function","title":"ElixirScope.Events.function_entry/5","doc":"","ref":"ElixirScope.Events.html#function_entry/5"},{"type":"function","title":"ElixirScope.Events.function_exit/8","doc":"","ref":"ElixirScope.Events.html#function_exit/8"},{"type":"function","title":"ElixirScope.Events.message_send/5","doc":"","ref":"ElixirScope.Events.html#message_send/5"},{"type":"function","title":"ElixirScope.Events.new_event/3","doc":"Creates a new event with automatic metadata injection.\n\nThis is the recommended way to create events as it automatically populates\ncommon fields like timestamp, node, and generates unique IDs.","ref":"ElixirScope.Events.html#new_event/3"},{"type":"function","title":"ElixirScope.Events.process_spawn/6","doc":"","ref":"ElixirScope.Events.html#process_spawn/6"},{"type":"function","title":"ElixirScope.Events.serialize/1","doc":"Serializes an event to binary format for efficient storage.","ref":"ElixirScope.Events.html#serialize/1"},{"type":"function","title":"ElixirScope.Events.serialized_size/1","doc":"","ref":"ElixirScope.Events.html#serialized_size/1"},{"type":"function","title":"ElixirScope.Events.state_change/5","doc":"","ref":"ElixirScope.Events.html#state_change/5"},{"type":"module","title":"ElixirScope.Events.CallbackReply","doc":"Event fired when a GenServer callback returns a reply","ref":"ElixirScope.Events.CallbackReply.html"},{"type":"module","title":"ElixirScope.Events.CrashDump","doc":"Event fired when a process crashes","ref":"ElixirScope.Events.CrashDump.html"},{"type":"module","title":"ElixirScope.Events.ErrorEvent","doc":"Event fired when an error occurs","ref":"ElixirScope.Events.ErrorEvent.html"},{"type":"module","title":"ElixirScope.Events.FunctionEntry","doc":"Event fired when entering a function","ref":"ElixirScope.Events.FunctionEntry.html"},{"type":"module","title":"ElixirScope.Events.FunctionExecution","doc":"Event fired for function execution (call or return)","ref":"ElixirScope.Events.FunctionExecution.html"},{"type":"module","title":"ElixirScope.Events.FunctionExit","doc":"Event fired when exiting a function","ref":"ElixirScope.Events.FunctionExit.html"},{"type":"module","title":"ElixirScope.Events.GarbageCollection","doc":"Event fired for garbage collection events","ref":"ElixirScope.Events.GarbageCollection.html"},{"type":"module","title":"ElixirScope.Events.MessageEvent","doc":"Event fired for message passing events","ref":"ElixirScope.Events.MessageEvent.html"},{"type":"module","title":"ElixirScope.Events.MessageReceive","doc":"Event fired when a message is received","ref":"ElixirScope.Events.MessageReceive.html"},{"type":"module","title":"ElixirScope.Events.MessageReceived","doc":"Alias for MessageReceive for runtime tracing compatibility","ref":"ElixirScope.Events.MessageReceived.html"},{"type":"module","title":"ElixirScope.Events.MessageSend","doc":"Event fired when a message is sent","ref":"ElixirScope.Events.MessageSend.html"},{"type":"module","title":"ElixirScope.Events.MessageSent","doc":"Alias for MessageSend for runtime tracing compatibility","ref":"ElixirScope.Events.MessageSent.html"},{"type":"module","title":"ElixirScope.Events.NodeEvent","doc":"Event fired for distributed node events","ref":"ElixirScope.Events.NodeEvent.html"},{"type":"module","title":"ElixirScope.Events.PerformanceMetric","doc":"Event fired for performance measurements","ref":"ElixirScope.Events.PerformanceMetric.html"},{"type":"module","title":"ElixirScope.Events.ProcessEvent","doc":"Event fired for process lifecycle events","ref":"ElixirScope.Events.ProcessEvent.html"},{"type":"module","title":"ElixirScope.Events.ProcessExit","doc":"Event fired when a process exits","ref":"ElixirScope.Events.ProcessExit.html"},{"type":"module","title":"ElixirScope.Events.ProcessSpawn","doc":"Event fired when a process is spawned","ref":"ElixirScope.Events.ProcessSpawn.html"},{"type":"module","title":"ElixirScope.Events.SchedulerEvent","doc":"Event fired for scheduler events","ref":"ElixirScope.Events.SchedulerEvent.html"},{"type":"module","title":"ElixirScope.Events.StateChange","doc":"Event fired when GenServer state changes","ref":"ElixirScope.Events.StateChange.html"},{"type":"module","title":"ElixirScope.Events.StateSnapshot","doc":"Event fired for periodic state snapshots during time-travel debugging","ref":"ElixirScope.Events.StateSnapshot.html"},{"type":"module","title":"ElixirScope.Events.TableEvent","doc":"Event fired for ETS/DETS table operations","ref":"ElixirScope.Events.TableEvent.html"},{"type":"module","title":"ElixirScope.Events.TraceControl","doc":"Event fired for trace control operations","ref":"ElixirScope.Events.TraceControl.html"},{"type":"module","title":"ElixirScope.Events.VMEvent","doc":"Event fired for VM-level events","ref":"ElixirScope.Events.VMEvent.html"},{"type":"module","title":"ElixirScope.Events.VariableAssignment","doc":"Event fired when a traced variable is assigned","ref":"ElixirScope.Events.VariableAssignment.html"},{"type":"module","title":"ElixirScope.Phoenix.Integration","doc":"Phoenix-specific integration for ElixirScope instrumentation.\n\nThis module provides specialized tracing for Phoenix applications including:\n- HTTP request/response lifecycle\n- LiveView mount, events, and state changes\n- Channel connections and message flow\n- Ecto query correlation","ref":"ElixirScope.Phoenix.Integration.html"},{"type":"function","title":"ElixirScope.Phoenix.Integration.disable/0","doc":"Disables Phoenix instrumentation.","ref":"ElixirScope.Phoenix.Integration.html#disable/0"},{"type":"function","title":"ElixirScope.Phoenix.Integration.enable/0","doc":"Enables Phoenix instrumentation by attaching telemetry handlers.","ref":"ElixirScope.Phoenix.Integration.html#enable/0"},{"type":"function","title":"ElixirScope.Phoenix.Integration.handle_channel_event/4","doc":"","ref":"ElixirScope.Phoenix.Integration.html#handle_channel_event/4"},{"type":"function","title":"ElixirScope.Phoenix.Integration.handle_ecto_event/4","doc":"","ref":"ElixirScope.Phoenix.Integration.html#handle_ecto_event/4"},{"type":"function","title":"ElixirScope.Phoenix.Integration.handle_http_event/4","doc":"","ref":"ElixirScope.Phoenix.Integration.html#handle_http_event/4"},{"type":"function","title":"ElixirScope.Phoenix.Integration.handle_liveview_event/4","doc":"","ref":"ElixirScope.Phoenix.Integration.html#handle_liveview_event/4"},{"type":"module","title":"ElixirScope.Query.Engine","doc":"Optimized query engine for event retrieval.\n\nAnalyzes queries to determine optimal index usage and executes queries\nefficiently. Provides performance monitoring and optimization suggestions.","ref":"ElixirScope.Query.Engine.html"},{"type":"function","title":"ElixirScope.Query.Engine.analyze_query/1","doc":"Analyzes a query to determine the optimal execution strategy.","ref":"ElixirScope.Query.Engine.html#analyze_query/1"},{"type":"function","title":"ElixirScope.Query.Engine.estimate_query_cost/2","doc":"Estimates the cost of executing a query against a store.","ref":"ElixirScope.Query.Engine.html#estimate_query_cost/2"},{"type":"function","title":"ElixirScope.Query.Engine.execute_query/2","doc":"Executes a query against the EventStore.","ref":"ElixirScope.Query.Engine.html#execute_query/2"},{"type":"function","title":"ElixirScope.Query.Engine.execute_query_with_metrics/2","doc":"Executes a query with detailed performance metrics.","ref":"ElixirScope.Query.Engine.html#execute_query_with_metrics/2"},{"type":"function","title":"ElixirScope.Query.Engine.get_optimization_suggestions/2","doc":"Provides optimization suggestions for a query.","ref":"ElixirScope.Query.Engine.html#get_optimization_suggestions/2"},{"type":"module","title":"ElixirScope.Storage.DataAccess","doc":"High-performance ETS-based storage for ElixirScope events.\n\nProvides multiple indexes for fast querying across different dimensions:\n- Primary index: Event ID -> Event\n- Temporal index: Timestamp -> Event ID\n- Process index: PID -> [Event IDs]\n- Function index: {Module, Function} -> [Event IDs]\n- Correlation index: Correlation ID -> [Event IDs]\n\nDesigned for high write throughput and fast range queries.","ref":"ElixirScope.Storage.DataAccess.html"},{"type":"function","title":"ElixirScope.Storage.DataAccess.cleanup_old_events/2","doc":"Cleans up old events to maintain memory bounds.\n\nRemoves events older than the specified timestamp.","ref":"ElixirScope.Storage.DataAccess.html#cleanup_old_events/2"},{"type":"function","title":"ElixirScope.Storage.DataAccess.destroy/1","doc":"Destroys the storage and cleans up all ETS tables.","ref":"ElixirScope.Storage.DataAccess.html#destroy/1"},{"type":"function","title":"ElixirScope.Storage.DataAccess.event_exists?/1","doc":"Checks if an event exists by ID.","ref":"ElixirScope.Storage.DataAccess.html#event_exists?/1"},{"type":"type","title":"ElixirScope.Storage.DataAccess.event_id/0","doc":"","ref":"ElixirScope.Storage.DataAccess.html#t:event_id/0"},{"type":"function","title":"ElixirScope.Storage.DataAccess.get_event/2","doc":"Retrieves an event by its ID.","ref":"ElixirScope.Storage.DataAccess.html#get_event/2"},{"type":"function","title":"ElixirScope.Storage.DataAccess.get_events_since/1","doc":"Queries events since a given timestamp.","ref":"ElixirScope.Storage.DataAccess.html#get_events_since/1"},{"type":"function","title":"ElixirScope.Storage.DataAccess.get_instrumentation_plan/0","doc":"Gets the current instrumentation plan.","ref":"ElixirScope.Storage.DataAccess.html#get_instrumentation_plan/0"},{"type":"function","title":"ElixirScope.Storage.DataAccess.get_stats/1","doc":"Gets storage statistics.","ref":"ElixirScope.Storage.DataAccess.html#get_stats/1"},{"type":"function","title":"ElixirScope.Storage.DataAccess.new/1","doc":"Creates a new data access instance with ETS tables.","ref":"ElixirScope.Storage.DataAccess.html#new/1"},{"type":"function","title":"Options - ElixirScope.Storage.DataAccess.new/1","doc":"- `:name` - Base name for the tables (default: generates unique name)\n- `:max_events` - Maximum number of events to store (default: 1_000_000)","ref":"ElixirScope.Storage.DataAccess.html#new/1-options"},{"type":"function","title":"ElixirScope.Storage.DataAccess.query_by_correlation/3","doc":"Queries events by correlation ID.","ref":"ElixirScope.Storage.DataAccess.html#query_by_correlation/3"},{"type":"function","title":"ElixirScope.Storage.DataAccess.query_by_function/4","doc":"Queries events by function.","ref":"ElixirScope.Storage.DataAccess.html#query_by_function/4"},{"type":"function","title":"ElixirScope.Storage.DataAccess.query_by_process/3","doc":"Queries events by process ID.","ref":"ElixirScope.Storage.DataAccess.html#query_by_process/3"},{"type":"function","title":"ElixirScope.Storage.DataAccess.query_by_time_range/4","doc":"Queries events by time range.","ref":"ElixirScope.Storage.DataAccess.html#query_by_time_range/4"},{"type":"function","title":"Options - ElixirScope.Storage.DataAccess.query_by_time_range/4","doc":"- `:limit` - Maximum number of events to return (default: 1000)\n- `:order` - `:asc` or `:desc` (default: `:asc`)","ref":"ElixirScope.Storage.DataAccess.html#query_by_time_range/4-options"},{"type":"type","title":"ElixirScope.Storage.DataAccess.query_options/0","doc":"","ref":"ElixirScope.Storage.DataAccess.html#t:query_options/0"},{"type":"function","title":"ElixirScope.Storage.DataAccess.store_event/2","doc":"Stores an event in the data access layer.\n\nAutomatically creates all necessary indexes for fast querying.","ref":"ElixirScope.Storage.DataAccess.html#store_event/2"},{"type":"function","title":"ElixirScope.Storage.DataAccess.store_events/1","doc":"Stores multiple events (simplified interface).","ref":"ElixirScope.Storage.DataAccess.html#store_events/1"},{"type":"function","title":"ElixirScope.Storage.DataAccess.store_events/2","doc":"Stores multiple events in batch for better performance.","ref":"ElixirScope.Storage.DataAccess.html#store_events/2"},{"type":"function","title":"ElixirScope.Storage.DataAccess.store_instrumentation_plan/1","doc":"Stores an instrumentation plan.","ref":"ElixirScope.Storage.DataAccess.html#store_instrumentation_plan/1"},{"type":"type","title":"ElixirScope.Storage.DataAccess.t/0","doc":"","ref":"ElixirScope.Storage.DataAccess.html#t:t/0"},{"type":"type","title":"ElixirScope.Storage.DataAccess.table_name/0","doc":"","ref":"ElixirScope.Storage.DataAccess.html#t:table_name/0"},{"type":"module","title":"ElixirScope.Storage.EventStore","doc":"High-performance event storage with ETS-based indexing.\n\nProvides fast storage and retrieval of events with multiple indexing strategies\nfor optimal query performance. Integrates with existing DataAccess and \nTemporalBridge systems.","ref":"ElixirScope.Storage.EventStore.html"},{"type":"function","title":"ElixirScope.Storage.EventStore.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"ElixirScope.Storage.EventStore.html#child_spec/1"},{"type":"function","title":"ElixirScope.Storage.EventStore.get_events_via_data_access/1","doc":"Gets events via DataAccess interface for integration testing.","ref":"ElixirScope.Storage.EventStore.html#get_events_via_data_access/1"},{"type":"function","title":"ElixirScope.Storage.EventStore.get_index_stats/1","doc":"Gets indexing statistics.","ref":"ElixirScope.Storage.EventStore.html#get_index_stats/1"},{"type":"function","title":"ElixirScope.Storage.EventStore.query_events/2","doc":"Queries events based on filters.","ref":"ElixirScope.Storage.EventStore.html#query_events/2"},{"type":"function","title":"ElixirScope.Storage.EventStore.start_link/1","doc":"Starts the EventStore GenServer.","ref":"ElixirScope.Storage.EventStore.html#start_link/1"},{"type":"function","title":"ElixirScope.Storage.EventStore.store_event/2","doc":"Stores an event in the EventStore.","ref":"ElixirScope.Storage.EventStore.html#store_event/2"},{"type":"module","title":"ElixirScope.Utils","doc":"Utility functions for ElixirScope.\n\nProvides high-performance, reliable utilities for:\n- High-resolution timestamp generation\n- Unique ID generation\n- Data inspection and truncation\n- Performance measurement helpers","ref":"ElixirScope.Utils.html"},{"type":"function","title":"ElixirScope.Utils.format_bytes/1","doc":"Formats a byte size into a human-readable string.","ref":"ElixirScope.Utils.html#format_bytes/1"},{"type":"function","title":"Examples - ElixirScope.Utils.format_bytes/1","doc":"iex> ElixirScope.Utils.format_bytes(1024)\n    \"1.0 KB\"\n    \n    iex> ElixirScope.Utils.format_bytes(1_500_000)\n    \"1.4 MB\"","ref":"ElixirScope.Utils.html#format_bytes/1-examples"},{"type":"function","title":"ElixirScope.Utils.format_duration/1","doc":"Formats a duration in nanoseconds into a human-readable string.","ref":"ElixirScope.Utils.html#format_duration/1"},{"type":"function","title":"Examples - ElixirScope.Utils.format_duration/1","doc":"iex> ElixirScope.Utils.format_duration(1_500_000)\n    \"1.5 ms\"\n    \n    iex> ElixirScope.Utils.format_duration(2_000_000_000)\n    \"2.0 s\"","ref":"ElixirScope.Utils.html#format_duration/1-examples"},{"type":"function","title":"ElixirScope.Utils.format_timestamp/1","doc":"Converts a monotonic timestamp to a human-readable string.","ref":"ElixirScope.Utils.html#format_timestamp/1"},{"type":"function","title":"Examples - ElixirScope.Utils.format_timestamp/1","doc":"iex> ElixirScope.Utils.format_timestamp(315708474309417000)\n    \"2024-01-01 12:30:45.123456789\"","ref":"ElixirScope.Utils.html#format_timestamp/1-examples"},{"type":"function","title":"ElixirScope.Utils.generate_correlation_id/0","doc":"Generates a unique correlation ID for tracing events.\nReturns a UUID v4 string for compatibility with external systems.","ref":"ElixirScope.Utils.html#generate_correlation_id/0"},{"type":"function","title":"ElixirScope.Utils.generate_id/0","doc":"Generates a unique ID for events, calls, and other entities.\n\nThe ID is designed to be:\n- Globally unique across nodes and time\n- Sortable (roughly by creation time)\n- Compact for storage efficiency\n- Fast to generate","ref":"ElixirScope.Utils.html#generate_id/0"},{"type":"function","title":"Examples - ElixirScope.Utils.generate_id/0","doc":"iex> id1 = ElixirScope.Utils.generate_id()\n    iex> id2 = ElixirScope.Utils.generate_id()\n    iex> id1 != id2\n    true","ref":"ElixirScope.Utils.html#generate_id/0-examples"},{"type":"function","title":"ElixirScope.Utils.id_to_timestamp/1","doc":"Extracts the timestamp component from a generated ID.","ref":"ElixirScope.Utils.html#id_to_timestamp/1"},{"type":"function","title":"Examples - ElixirScope.Utils.id_to_timestamp/1","doc":"iex> id = ElixirScope.Utils.generate_id()\n    iex> timestamp = ElixirScope.Utils.id_to_timestamp(id)\n    iex> is_integer(timestamp)\n    true","ref":"ElixirScope.Utils.html#id_to_timestamp/1-examples"},{"type":"function","title":"ElixirScope.Utils.measure/1","doc":"Measures execution time of a function in nanoseconds.","ref":"ElixirScope.Utils.html#measure/1"},{"type":"function","title":"Examples - ElixirScope.Utils.measure/1","doc":"iex> {result, duration} = ElixirScope.Utils.measure(fn -> :timer.sleep(10); :ok end)\n    iex> result\n    :ok\n    iex> duration > 10_000_000  # At least 10ms in nanoseconds\n    true","ref":"ElixirScope.Utils.html#measure/1-examples"},{"type":"function","title":"ElixirScope.Utils.measure_memory/1","doc":"Measures memory usage before and after executing a function.\n\nReturns {result, {memory_before, memory_after, memory_diff}}.","ref":"ElixirScope.Utils.html#measure_memory/1"},{"type":"function","title":"Examples - ElixirScope.Utils.measure_memory/1","doc":"iex> {result, {before, after, diff}} = ElixirScope.Utils.measure_memory(fn -> \n    ...>   Enum.to_list(1..1000)\n    ...> end)\n    iex> is_list(result)\n    true\n    iex> diff > 0\n    true","ref":"ElixirScope.Utils.html#measure_memory/1-examples"},{"type":"function","title":"ElixirScope.Utils.monotonic_timestamp/0","doc":"Generates a high-resolution monotonic timestamp in nanoseconds.\n\nThis timestamp is guaranteed to be monotonically increasing and is suitable\nfor ordering events and measuring durations. It's not affected by system\nclock adjustments.","ref":"ElixirScope.Utils.html#monotonic_timestamp/0"},{"type":"function","title":"Examples - ElixirScope.Utils.monotonic_timestamp/0","doc":"iex> ElixirScope.Utils.monotonic_timestamp()\n    315708474309417000","ref":"ElixirScope.Utils.html#monotonic_timestamp/0-examples"},{"type":"function","title":"ElixirScope.Utils.process_stats/1","doc":"Gets current process statistics for performance monitoring.","ref":"ElixirScope.Utils.html#process_stats/1"},{"type":"function","title":"Examples - ElixirScope.Utils.process_stats/1","doc":"iex> stats = ElixirScope.Utils.process_stats()\n    iex> Map.has_key?(stats, :memory)\n    true\n    iex> Map.has_key?(stats, :reductions)\n    true","ref":"ElixirScope.Utils.html#process_stats/1-examples"},{"type":"function","title":"ElixirScope.Utils.safe_inspect/2","doc":"Safely inspects a term with size limits to prevent memory issues.","ref":"ElixirScope.Utils.html#safe_inspect/2"},{"type":"function","title":"Examples - ElixirScope.Utils.safe_inspect/2","doc":"iex> ElixirScope.Utils.safe_inspect(%{key: \"value\"})\n    \"%{key: \"value\"}\"\n    \n    iex> large_map = for i <- 1..1000, into: %{}, do: {i, i}\n    iex> result = ElixirScope.Utils.safe_inspect(large_map)\n    iex> String.contains?(result, \"...\")\n    true","ref":"ElixirScope.Utils.html#safe_inspect/2-examples"},{"type":"function","title":"ElixirScope.Utils.system_stats/0","doc":"Gets system-wide performance statistics.","ref":"ElixirScope.Utils.html#system_stats/0"},{"type":"function","title":"Examples - ElixirScope.Utils.system_stats/0","doc":"iex> stats = ElixirScope.Utils.system_stats()\n    iex> Map.has_key?(stats, :process_count)\n    true\n    iex> Map.has_key?(stats, :total_memory)\n    true","ref":"ElixirScope.Utils.html#system_stats/0-examples"},{"type":"function","title":"ElixirScope.Utils.term_size/1","doc":"Estimates the memory footprint of a term in bytes.","ref":"ElixirScope.Utils.html#term_size/1"},{"type":"function","title":"Examples - ElixirScope.Utils.term_size/1","doc":"iex> ElixirScope.Utils.term_size(\"hello\")\n    15","ref":"ElixirScope.Utils.html#term_size/1-examples"},{"type":"function","title":"ElixirScope.Utils.truncate_data/2","doc":"Truncates data for safe storage in events.\n\nThis is an alias for truncate_if_large/2 with a smaller default size\nsuitable for event data.","ref":"ElixirScope.Utils.html#truncate_data/2"},{"type":"function","title":"Examples - ElixirScope.Utils.truncate_data/2","doc":"iex> ElixirScope.Utils.truncate_data(\"small\")\n    \"small\"\n    \n    iex> large_data = String.duplicate(\"x\", 2000)\n    iex> ElixirScope.Utils.truncate_data(large_data)\n    {:truncated, 2000, \"binary data\"}","ref":"ElixirScope.Utils.html#truncate_data/2-examples"},{"type":"function","title":"ElixirScope.Utils.truncate_if_large/2","doc":"Truncates a term if it's too large, returning a placeholder.","ref":"ElixirScope.Utils.html#truncate_if_large/2"},{"type":"function","title":"Examples - ElixirScope.Utils.truncate_if_large/2","doc":"iex> ElixirScope.Utils.truncate_if_large(\"small\")\n    \"small\"\n    \n    iex> large_binary = String.duplicate(\"x\", 10000)\n    iex> ElixirScope.Utils.truncate_if_large(large_binary, 1000)\n    {:truncated, 10000, \"binary data\"}","ref":"ElixirScope.Utils.html#truncate_if_large/2-examples"},{"type":"function","title":"ElixirScope.Utils.valid_percentage?/1","doc":"Validates that a value is a percentage (0.0 to 1.0).","ref":"ElixirScope.Utils.html#valid_percentage?/1"},{"type":"function","title":"Examples - ElixirScope.Utils.valid_percentage?/1","doc":"iex> ElixirScope.Utils.valid_percentage?(0.5)\n    true\n    \n    iex> ElixirScope.Utils.valid_percentage?(1.5)\n    false","ref":"ElixirScope.Utils.html#valid_percentage?/1-examples"},{"type":"function","title":"ElixirScope.Utils.valid_pid?/1","doc":"Validates that a PID exists and is alive.","ref":"ElixirScope.Utils.html#valid_pid?/1"},{"type":"function","title":"Examples - ElixirScope.Utils.valid_pid?/1","doc":"iex> ElixirScope.Utils.valid_pid?(self())\n    true\n    \n    iex> dead_pid = spawn(fn -> nil end)\n    iex> Process.sleep(10)\n    iex> ElixirScope.Utils.valid_pid?(dead_pid)\n    false","ref":"ElixirScope.Utils.html#valid_pid?/1-examples"},{"type":"function","title":"ElixirScope.Utils.valid_positive_integer?/1","doc":"Validates that a value is a positive integer.","ref":"ElixirScope.Utils.html#valid_positive_integer?/1"},{"type":"function","title":"Examples - ElixirScope.Utils.valid_positive_integer?/1","doc":"iex> ElixirScope.Utils.valid_positive_integer?(42)\n    true\n    \n    iex> ElixirScope.Utils.valid_positive_integer?(-1)\n    false","ref":"ElixirScope.Utils.html#valid_positive_integer?/1-examples"},{"type":"function","title":"ElixirScope.Utils.wall_timestamp/0","doc":"Generates a wall clock timestamp in nanoseconds.\n\nThis timestamp represents the actual time and can be converted to\nhuman-readable dates. Use for correlation with external systems.","ref":"ElixirScope.Utils.html#wall_timestamp/0"},{"type":"function","title":"Examples - ElixirScope.Utils.wall_timestamp/0","doc":"iex> ElixirScope.Utils.wall_timestamp()\n    1609459200000000000","ref":"ElixirScope.Utils.html#wall_timestamp/0-examples"},{"type":"task","title":"mix compile.elixir_scope","doc":"Mix compiler that transforms Elixir ASTs to inject ElixirScope instrumentation.\n\nThis compiler:\n1. Runs before the standard Elixir compiler\n2. Transforms ASTs based on AI-generated instrumentation plans\n3. Preserves original code semantics and metadata\n4. Injects calls to ElixirScope.Capture.InstrumentationRuntime","ref":"Mix.Tasks.Compile.ElixirScope.html"},{"type":"function","title":"Mix.Tasks.Compile.ElixirScope.transform_ast/2","doc":"Transforms an AST directly with a given plan (used by tests).","ref":"Mix.Tasks.Compile.ElixirScope.html#transform_ast/2"},{"type":"extras","title":"ElixirScope: AI-Powered Execution Cinema Debugger for Elixir","doc":"# ElixirScope: AI-Powered Execution Cinema Debugger for Elixir\n\n[![Elixir](https://img.shields.io/badge/elixir-%234B275F.svg?style=for-the-badge&logo=elixir&logoColor=white)](https://elixir-lang.org/)\n[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)\n\n**ElixirScope is a next-generation debugging and observability platform for Elixir applications, designed to provide an \"Execution Cinema\" experience through deep, compile-time AST instrumentation guided by AI-powered analysis.**","ref":"readme.html"},{"type":"extras","title":"🎬 Try the Cinema Demo Now! - ElixirScope: AI-Powered Execution Cinema Debugger for Elixir","doc":"**Experience ElixirScope in action with our comprehensive working demo:**\n\n```bash\ngit clone https://github.com/your-org/elixir_scope.git\ncd elixir_scope/test_apps/cinema_demo\n./run_showcase.sh\n```\n\n**✨ See all features working in ~1 minute:** Time-travel debugging, performance monitoring, state reconstruction, and more!\n\n**[📖 Complete Demo Documentation →](https://github.com/nshkrdotcom/ElixirScope/blob/main/test_apps/cinema_demo/FULLY_BLOWN.md**","ref":"readme.html#try-the-cinema-demo-now"},{"type":"extras","title":"🎯 Vision & Mission - ElixirScope: AI-Powered Execution Cinema Debugger for Elixir","doc":"Transform Elixir development by providing unprecedented insight into application behavior through:\n\n- **Total Behavioral Recall**: Capture comprehensive execution history through compile-time instrumentation\n- **AI-Driven Guidance**: Intelligent instrumentation planning and code analysis  \n- **Compile-Time Granularity**: Access local variables, trace expressions, and inject custom logic with precision\n- **Time-Travel Debugging**: Navigate through your application's execution history (planned)\n- **Multi-Dimensional Analysis**: Correlate events across time, processes, state, and performance\n\n---","ref":"readme.html#vision-mission"},{"type":"extras","title":"🚀 Current Implementation Status - ElixirScope: AI-Powered Execution Cinema Debugger for Elixir","doc":"ElixirScope has achieved **major milestones** with a **comprehensive working demo** and core components fully operational:","ref":"readme.html#current-implementation-status"},{"type":"extras","title":"🎬 NEW: Complete Cinema Demo Available! - ElixirScope: AI-Powered Execution Cinema Debugger for Elixir","doc":"**✅ FULLY WORKING SHOWCASE** - Experience all ElixirScope features in action:\n\n```bash\ncd test_apps/cinema_demo\n./run_showcase.sh\n```\n\n**What you'll see:**\n- ✅ All 6 demo scenarios running (Task Management, Data Processing, Complex Operations, Error Handling, Performance Analysis, Time Travel Debugging)\n- ✅ Real-time performance metrics and system monitoring\n- ✅ TemporalBridge integration with working time-travel debugging\n- ✅ Complete end-to-end workflow demonstration\n- ✅ ~1 minute comprehensive feature showcase\n\n**[📖 See FULLY_BLOWN.md for complete demo documentation](https://github.com/nshkrdotcom/ElixirScope/blob/main/test_apps/cinema_demo/FULLY_BLOWN.md)**","ref":"readme.html#new-complete-cinema-demo-available"},{"type":"extras","title":"✅ Production-Ready Components - ElixirScope: AI-Powered Execution Cinema Debugger for Elixir","doc":"#### **Core Infrastructure (100% Complete)**\n- **✅ Configuration System** - `ElixirScope.Config` with environment support and validation\n- **✅ Event System** - `ElixirScope.Events` with comprehensive event type definitions\n- **✅ Utility Functions** - `ElixirScope.Utils` with ID generation, timestamps, and data formatting\n- **✅ Application Supervision** - Robust OTP application structure\n\n#### **Data Capture Pipeline (95% Complete)**\n- **✅ InstrumentationRuntime** - High-performance runtime event capture API (920 lines)\n  - Function entry/exit tracking with correlation IDs\n  - Local variable snapshots and expression tracing\n  - AST-correlated event reporting (enhanced for hybrid architecture)\n  - Phoenix, LiveView, Ecto, and GenServer integration functions\n  - <1µs overhead when disabled, <500ns when enabled\n- **✅ Ring Buffer** - Lock-free, high-performance event storage (supporting >100k events/sec)\n- **✅ Ingestor** - Ultra-fast event ingestion (<1µs per event target)\n- **✅ Pipeline Manager** - Coordinated async processing with backpressure\n- **✅ Data Access** - ETS-based storage with efficient querying\n\n#### **AST Transformation Engine (90% Complete)**\n- **✅ Core Transformer** - Production-ready AST instrumentation for functions and GenServer callbacks\n- **✅ Enhanced Transformer** - Granular instrumentation with local variable capture and expression tracing\n- **✅ Injector Helpers** - Comprehensive AST manipulation utilities\n- **Pattern Support**: GenServer, Phoenix Controller, LiveView, and Channel instrumentation\n\n#### **AI Analysis Framework (85% Complete)**\n- **✅ LLM Integration** - Complete multi-provider support:\n  - **Google Gemini API** - Production integration with authentication\n  - **Vertex AI** - Service account authentication and error handling  \n  - **Mock Provider** - Comprehensive testing infrastructure\n- **✅ AI Orchestrator** - Centralized AI coordination and instrumentation planning\n- **✅ Pattern Recognizer** - OTP pattern detection (GenServer, Supervisor, Phoenix patterns)\n- **🚧 Code Analyzer** - Basic analysis with room for enhancement\n- **🚧 Predictive Execution** - ML-based execution path and resource prediction\n\n#### **Cinema Debugger System (90% Complete)**\n- **✅ TemporalStorage** - High-performance temporal event storage with AST correlation\n- **✅ TemporalBridge** - Real-time bridge between runtime events and temporal storage\n- **✅ State Reconstruction** - Working time-travel debugging via TemporalBridge\n- **✅ Event Correlation** - AST node correlation with runtime events\n- **✅ Performance Tracking** - Real-time metrics and system monitoring\n\n#### **AST Repository System (85% Complete)**\n- **✅ Repository Core** - Central AST storage with runtime correlation\n- **✅ Function Data** - Comprehensive function-level analysis structure\n- **✅ Runtime Correlator** - Bridge between AST nodes and runtime events (working)\n- **🚧 Parser Integration** - AST parsing with instrumentation point mapping (partial)\n\n#### **Compile-Time Orchestration (80% Complete)**\n- **✅ Orchestrator** - Complete instrumentation planning and AI integration\n- **✅ Configuration Management** - Runtime configuration updates\n- **🚧 Mix Task Integration** - Automatic compile-time transformation (planned)","ref":"readme.html#production-ready-components"},{"type":"extras","title":"📋 Planned Features - ElixirScope: AI-Powered Execution Cinema Debugger for Elixir","doc":"#### **Web Interface (Next Priority)**\n- Phoenix web interface for trace visualization\n- Visual time-travel debugging interface\n- Interactive execution timeline\n- Multi-dimensional event correlation\n\n#### **Advanced Integrations (Future)**\n- IDE integration (ElixirLS compatibility)\n- Distributed tracing capabilities\n- Advanced AI analysis and recommendations\n- Hypothesis testing framework\n\n---","ref":"readme.html#planned-features"},{"type":"extras","title":"🏗️ Architecture Overview - ElixirScope: AI-Powered Execution Cinema Debugger for Elixir","doc":"ElixirScope follows a **compile-time first** approach with runtime correlation capabilities:\n\n```mermaid\ngraph TD\n    subgraph \"Developer Tools\"\n        IDE[\"IDE / IEx\"]\n        MixTask[\"Mix Tasks (Planned)\"]\n    end\n\n    subgraph \"AI Analysis Engine\"\n        Orchestrator[\"AI.Orchestrator ✅\"]\n        CodeAnalyzer[\"Code Analyzer ✅\"]\n        PatternRecognizer[\"Pattern Recognizer ✅\"]\n        LLMProviders[\"LLM Providers ✅ Gemini • Vertex • Mock\"]\n    end\n\n    subgraph \"AST Transformation\"\n        Transformer[\"AST.Transformer ✅\"]\n        EnhancedTransformer[\"Enhanced Transformer ✅\"]\n        CompileTime[\"Compile-Time Orchestrator 🚧\"]\n    end\n\n    subgraph \"Data Capture Pipeline\"\n        Runtime[\"InstrumentationRuntime ✅\"]\n        Ingestor[\"Ingestor ✅\"]\n        RingBuffer[\"Ring Buffer ✅\"]\n        Pipeline[\"Pipeline Manager ✅\"]\n        Storage[\"Data Access ✅\"]\n    end\n\n    subgraph \"Cinema Debugger System\"\n        TemporalStorage[\"TemporalStorage ✅\"]\n        TemporalBridge[\"TemporalBridge ✅\"]\n        StateReconstruction[\"State Reconstruction ✅\"]\n    end\n\n    subgraph \"AST Repository\"\n        Repository[\"Repository Core ✅\"]\n        FunctionData[\"Function Data ✅\"] \n        Correlator[\"Runtime Correlator ✅\"]\n    end\n\n    IDE --> Orchestrator\n    Orchestrator --> CodeAnalyzer\n    CodeAnalyzer --> LLMProviders\n    CodeAnalyzer --> Transformer\n    Transformer --> Runtime\n    Runtime --> Ingestor\n    Ingestor --> RingBuffer\n    RingBuffer --> Pipeline\n    Pipeline --> Storage\n    Storage --> TemporalStorage\n    TemporalStorage --> TemporalBridge\n    TemporalBridge --> StateReconstruction\n    Repository --> Correlator\n    Correlator --> TemporalBridge\n    \n    style Runtime fill:#c8e6c9,color:#000\n    style Ingestor fill:#c8e6c9,color:#000\n    style Orchestrator fill:#e1f5fe,color:#000\n    style Repository fill:#fff3e0,color:#000\n    style TemporalBridge fill:#c8e6c9,color:#000\n    style StateReconstruction fill:#c8e6c9,color:#000\n```\n\n### **Key Architectural Principles**\n\n- **Compile-Time First**: Primary focus on AST transformation for deep instrumentation\n- **AI-Guided Intelligence**: Smart instrumentation planning based on code analysis\n- **High-Performance Pipeline**: Sub-microsecond event processing with async correlation\n- **Production-Safe**: Configurable instrumentation levels with minimal overhead\n- **Extensible**: Plugin architecture for new analysis types and integrations\n\n---","ref":"readme.html#architecture-overview"},{"type":"extras","title":"🚀 Getting Started - ElixirScope: AI-Powered Execution Cinema Debugger for Elixir","doc":"### **Installation**\n\nAdd ElixirScope to your `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:elixir_scope, \"~> 0.1.0\"}\n  ]\nend\n```\n\n### **Basic Configuration**\n\n```elixir\n# config/config.exs\nconfig :elixir_scope,\n  # Data capture settings\n  capture: [\n    buffer_size: 10_000,\n    batch_size: 100,\n    flush_interval: 1_000\n  ],\n  \n  # AI analysis settings  \n  ai: [\n    llm_provider: :mock,  # :gemini, :vertex, :mock\n    analysis_timeout: 30_000,\n    planning: [\n      default_strategy: :balanced\n    ]\n  ],\n  \n  # AST instrumentation settings\n  ast: [\n    default_instrumentation_level: :function_boundaries,\n    performance_monitoring: true,\n    variable_capture: false\n  ]\n```\n\n### **Quick Start - Try the Cinema Demo!**\n\nThe fastest way to experience ElixirScope is through our comprehensive demo:\n\n```bash\n# Clone the repository\ngit clone https://github.com/nshkrdotcom/ElixirScope.git elixir_scope\ncd elixir_scope\n\n# Run the complete showcase\ncd test_apps/cinema_demo\n./run_showcase.sh\n```\n\nThis will demonstrate:\n- ✅ **Task Management** - GenServer state tracking and lifecycle management\n- ✅ **Data Processing** - Complex data transformation pipelines\n- ✅ **Time Travel Debugging** - State reconstruction at any point in time\n- ✅ **Performance Analysis** - Real-time metrics and bottleneck identification\n- ✅ **Error Handling** - Graceful recovery and error correlation\n- ✅ **Complex Operations** - Deep call stacks and recursive function analysis\n\n### **Current Usage Examples**\n\n#### **Main Application API**\n```elixir\n# Start ElixirScope with your application\nchildren = [\n  # Your application children...\n  {ElixirScope, []}\n]\n\n# Use the main API\nElixirScope.start(strategy: :full_trace, sampling_rate: 1.0)\nstatus = ElixirScope.status()\n\n# Check if running\nElixirScope.running?()\n# => true\n\n# Update configuration at runtime\nElixirScope.update_config([:ai, :planning, :sampling_rate], 0.5)\n```\n\n#### **Cinema Debugger Features**\n```elixir\n# Start TemporalBridge for time-travel debugging\n{:ok, bridge} = ElixirScope.Capture.TemporalBridge.start_link(\n  name: :my_bridge,\n  buffer_size: 1000\n)\n\n# Get bridge statistics\n{:ok, stats} = ElixirScope.Capture.TemporalBridge.get_stats(bridge)\n\n# Reconstruct state at specific timestamp\n{:ok, past_state} = ElixirScope.Capture.TemporalBridge.reconstruct_state_at(\n  bridge, \n  timestamp\n)\n```\n\n#### **AI-Powered Code Analysis**\n```elixir\n# Analyze code with AI\n{:ok, analysis} = ElixirScope.AI.CodeAnalyzer.analyze_module(MyModule)\n\n# Generate instrumentation plan\n{:ok, plan} = ElixirScope.AI.Orchestrator.plan_for_module(source_code)\n\n# Recognize patterns\npatterns = ElixirScope.AI.PatternRecognizer.extract_patterns(ast)\n```\n\n### **LLM Provider Setup**\n\n#### **Google Gemini API**\n```bash\nexport GOOGLE_API_KEY=\"your-gemini-api-key\"\n```\n\n```elixir\nconfig :elixir_scope, ai: [llm_provider: :gemini]\n```\n\n#### **Vertex AI**\n```bash\nexport VERTEX_JSON_FILE=\"/path/to/service-account.json\"\n```\n\n```elixir\nconfig :elixir_scope, ai: [llm_provider: :vertex]\n```\n\n---","ref":"readme.html#getting-started"},{"type":"extras","title":"🧪 Testing & Development - ElixirScope: AI-Powered Execution Cinema Debugger for Elixir","doc":"ElixirScope has comprehensive testing with **723 tests passing, 0 failures** and extensive coverage across all components.\n\n### **Test Commands**\n\n```bash\n# Default test command - excludes live API tests, shows full test names\nmix test\n\n# All tests including live API tests (may hang without API keys)\nmix test.all\n\n# Fast tests (parallelized)  \nmix test.fast\n\n# LLM provider tests\nmix test.mock          # Mock provider only\nmix test.gemini        # Live Gemini API tests\nmix test.vertex        # Live Vertex AI tests\nmix test.live          # All live API tests\n\n# Legacy alias (same as default mix test)\nmix test.trace\n\n# Performance validation\nmix test.performance\n```\n\n### **Cinema Demo Testing**\n\n```bash\n# Test the complete demo application\ncd test_apps/cinema_demo\nmix test\n\n# Run individual demo scenarios\nmix run -e \"CinemaDemo.run_task_management_demo()\"\nmix run -e \"CinemaDemo.run_time_travel_debugging_demo()\"\n\n# Run the complete showcase\n./run_showcase.sh\n```\n\n### **Live API Testing**\n\nTo run tests against real LLM APIs:\n\n```bash\n# Set up credentials\nexport GOOGLE_API_KEY=\"your-key\"\nexport VERTEX_JSON_FILE=\"/path/to/service-account.json\"\n\n# Run live tests\nmix test.live\n```\n\n---","ref":"readme.html#testing-development"},{"type":"extras","title":"📊 Performance Characteristics - ElixirScope: AI-Powered Execution Cinema Debugger for Elixir","doc":"### **Current Benchmarks**\n\n| Component | Performance | Status |\n|-----------|-------------|---------|\n| **InstrumentationRuntime** | <100µs per event | ✅ Production Ready |\n| **TemporalBridge** | <100µs event forwarding | ✅ Production Ready |\n| **Ring Buffer** | >100k events/sec throughput | ✅ Production Ready |\n| **Event Ingestor** | <1µs per event processing | ✅ Production Ready |\n| **State Reconstruction** | <10ms for typical GenServer | ✅ Production Ready |\n| **AST Transformation** | <100ms for medium modules | ✅ Production Ready |\n| **AI Analysis** | <30s for project analysis | ✅ Functional |\n| **Cinema Demo** | ~1 minute complete showcase | ✅ Fully Working |\n\n### **Memory Usage**\n\n- **Base overhead**: ~10MB for core system\n- **TemporalBridge**: ~5MB per bridge instance\n- **Per-module overhead**: 50KB (small), 200KB (medium), 1MB (large)\n- **Ring buffer**: Configurable, 1-10MB typical\n- **Cinema Demo**: ~15MB total during showcase\n- **Total overhead**: <50MB for typical projects\n\n---","ref":"readme.html#performance-characteristics"},{"type":"extras","title":"🗺️ Development Roadmap - ElixirScope: AI-Powered Execution Cinema Debugger for Elixir","doc":"### **✅ Phase 1: Foundation Complete (May 2025)**\n\n#### **Major Achievements**\n- ✅ Complete Cinema Demo with all 6 scenarios working\n- ✅ TemporalBridge integration for time-travel debugging\n- ✅ State reconstruction capabilities\n- ✅ Performance monitoring and metrics\n- ✅ AST-runtime correlation system\n- ✅ Comprehensive test suite (723 tests passing)\n- ✅ Production-ready core components\n\n### **Phase 2: Web Interface & Enhanced Features (Q2 2025)**\n\n#### **Immediate Priorities**\n- [ ] Phoenix web interface for Cinema Debugger\n- [ ] Visual time-travel debugging interface\n- [ ] Interactive execution timeline\n- [ ] Real-time event streaming dashboard\n\n#### **Enhanced Features**\n- [ ] Mix task for automatic instrumentation\n- [ ] IEx helpers for debugging workflow\n- [ ] Enhanced AI orchestration and planning\n- [ ] User-friendly instrumentation API\n\n### **Phase 3: Advanced Features (Q2-Q3 2025)**\n\n- [ ] Distributed tracing across nodes\n- [ ] Advanced AI analysis and recommendations\n- [ ] IDE integration (ElixirLS)\n- [ ] Production deployment patterns\n- [ ] Performance optimization tools\n\n---","ref":"readme.html#development-roadmap"},{"type":"extras","title":"🤝 Contributing - ElixirScope: AI-Powered Execution Cinema Debugger for Elixir","doc":"We welcome contributions! ElixirScope is built with a solid foundation and clear architecture.\n\n### **Current Contribution Opportunities**\n\n1. **Web Interface** - Build the Phoenix-based Cinema Debugger web UI\n2. **Visual Debugging** - Create interactive time-travel debugging interface\n3. **AI Enhancement** - Improve code analysis and pattern recognition\n4. **Performance Optimization** - Enhance event processing and storage\n5. **Documentation** - Improve guides and examples\n6. **Testing** - Add property-based and chaos testing\n\n### **Getting Started with Development**\n\n1. Fork the repository\n2. Set up development environment:\n   ```bash\n   mix deps.get\n   mix test  # Ensure all tests pass (723 tests, excludes live API tests)\n   ```\n3. Try the Cinema Demo:\n   ```bash\n   cd test_apps/cinema_demo\n   ./run_showcase.sh\n   ```\n4. Create a feature branch\n5. Add comprehensive tests for new functionality\n6. Submit a pull request\n\n### **Development Guidelines**\n\n- **Test-driven development**: All new features need tests (current: 723 tests passing)\n- **Performance-conscious**: Maintain <100µs instrumentation overhead\n- **Backward compatibility**: Don't break existing APIs\n- **Documentation**: Update guides for new features\n- **Demo integration**: Consider adding features to Cinema Demo showcase\n\n---","ref":"readme.html#contributing"},{"type":"extras","title":"📄 License - ElixirScope: AI-Powered Execution Cinema Debugger for Elixir","doc":"ElixirScope is released under the MIT License. See the [LICENSE](LICENSE) file for details.\n\n---","ref":"readme.html#license"},{"type":"extras","title":"🙏 Acknowledgments - ElixirScope: AI-Powered Execution Cinema Debugger for Elixir","doc":"ElixirScope builds on the excellent foundation of the Elixir and OTP ecosystem. Special thanks to:\n\n- The Elixir core team for creating such an introspectable language\n- The Phoenix team for demonstrating excellent debugging tools\n- The Erlang/OTP team for the robust foundation\n- The Elixir community for inspiration and feedback\n\n---","ref":"readme.html#acknowledgments"},{"type":"extras","title":"📞 Support & Community - ElixirScope: AI-Powered Execution Cinema Debugger for Elixir","doc":"- **Documentation**: [Coming Soon]\n- **Issues**: [GitHub Issues](https://github.com/your-org/elixir_scope/issues)\n- **Discussions**: [GitHub Discussions](https://github.com/your-org/elixir_scope/discussions)\n- **Elixir Forum**: Tag your posts with `elixir-scope`\n\n---\n\n**ElixirScope**: Transforming Elixir development through intelligent instrumentation and AI-powered analysis. **The future of debugging is here - and it's working!** 🎬✨\n\n**[🚀 Try the Cinema Demo Now!](test_apps/cinema_demo/)**","ref":"readme.html#support-community"},{"type":"extras","title":"ElixirScope Public API Documentation","doc":"# ElixirScope Public API Documentation\n\n**Version**: 0.0.1\n**Last Updated**: May 26, 2025\n**Status**: Foundation Complete - Cinema Demo Available\n\nElixirScope is an AI-powered execution cinema debugger for Elixir applications that provides deep observability, time-travel debugging, and comprehensive event capture with minimal overhead.","ref":"public_docs.html"},{"type":"extras","title":"🎬 Try the Working Demo! - ElixirScope Public API Documentation","doc":"**Experience ElixirScope in action:**\n\n```bash\ngit clone https://github.com/nshkrdotcom/ElixirScope.git\ncd ElixirScope/test_apps/cinema_demo\n./run_showcase.sh\n```\n\n**✨ See all features working in ~1 minute!**","ref":"public_docs.html#try-the-working-demo"},{"type":"extras","title":"📋 Implementation Status - ElixirScope Public API Documentation","doc":"- ✅ **Core Application API** - `ElixirScope.start/1`, `status/0`, `running?/0` - **WORKING**\n- ✅ **Configuration Management** - Runtime config updates - **WORKING**  \n- ✅ **Cinema Debugger** - TemporalBridge, state reconstruction - **WORKING**\n- ✅ **Performance Monitoring** - Real-time metrics - **WORKING**\n- ⚠️ **Event Querying** - `get_events/1` returns `{:error, :not_implemented_yet}` - **PLANNED**\n- ⚠️ **Time Travel API** - `get_state_at/2` returns `{:error, :not_implemented_yet}` - **PLANNED**\n- ⚠️ **Phoenix Integration** - Web interface - **PLANNED**\n\n**Note**: Use TemporalBridge APIs for working time-travel debugging and event analysis.","ref":"public_docs.html#implementation-status"},{"type":"extras","title":"Table of Contents - ElixirScope Public API Documentation","doc":"1. [Quick Start](#quick-start)\n2. [Core API](#core-api)\n3. [Configuration Management](#configuration-management)\n4. [Event Querying](#event-querying)\n5. [Cinema Debugger](#cinema-debugger)\n6. [Phoenix Integration](#phoenix-integration)\n7. [AST Repository](#ast-repository)\n8. [Performance Monitoring](#performance-monitoring)\n9. [Advanced Usage](#advanced-usage)\n10. [Error Handling](#error-handling)\n11. [Best Practices](#best-practices)\n\n---","ref":"public_docs.html#table-of-contents"},{"type":"extras","title":"Quick Start - ElixirScope Public API Documentation","doc":"","ref":"public_docs.html#quick-start"},{"type":"extras","title":"Installation - ElixirScope Public API Documentation","doc":"Add ElixirScope to your `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:elixir_scope, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"public_docs.html#installation"},{"type":"extras","title":"Basic Usage (Working APIs) - ElixirScope Public API Documentation","doc":"```elixir\n# Start ElixirScope with default configuration\n:ok = ElixirScope.start()\n\n# Check if running\nElixirScope.running?()\n# => true\n\n# Get system status\nstatus = ElixirScope.status()\n# => %{running: true, config: %{...}, stats: %{...}}\n\n# Update configuration at runtime\n:ok = ElixirScope.update_config([:ai, :planning, :sampling_rate], 0.5)\n\n# Stop ElixirScope\n:ok = ElixirScope.stop()\n```","ref":"public_docs.html#basic-usage-working-apis"},{"type":"extras","title":"Working Time-Travel Debugging - ElixirScope Public API Documentation","doc":"```elixir\n# Start TemporalBridge for time-travel debugging\n{:ok, bridge} = ElixirScope.Capture.TemporalBridge.start_link(\n  name: :my_bridge,\n  buffer_size: 1000\n)\n\n# Register as event handler\n:ok = ElixirScope.Capture.TemporalBridge.register_as_handler(bridge)\n\n# Get bridge statistics\n{:ok, stats} = ElixirScope.Capture.TemporalBridge.get_stats(bridge)\n\n# Reconstruct state at specific timestamp (WORKING!)\n{:ok, past_state} = ElixirScope.Capture.TemporalBridge.reconstruct_state_at(\n  bridge, \n  timestamp\n)\n```","ref":"public_docs.html#working-time-travel-debugging"},{"type":"extras","title":"Configuration - ElixirScope Public API Documentation","doc":"```elixir\n# config/config.exs\nconfig :elixir_scope,\n  ai: [\n    provider: :mock,  # :mock, :gemini, :vertex\n    planning: [\n      default_strategy: :balanced,  # :minimal, :balanced, :full_trace\n      sampling_rate: 1.0\n    ]\n  ],\n  capture: [\n    ring_buffer: [\n      size: 1_048_576,\n      max_events: 100_000\n    ]\n  ]\n```\n\n---","ref":"public_docs.html#configuration"},{"type":"extras","title":"Core API - ElixirScope Public API Documentation","doc":"","ref":"public_docs.html#core-api"},{"type":"extras","title":"ElixirScope Main Module - ElixirScope Public API Documentation","doc":"The primary interface for all ElixirScope operations.\n\n#### Application Lifecycle\n\n```elixir\n@spec start(keyword()) :: :ok | {:error, term()}\ndef start(opts \\\\ [])\n```\n\nStarts ElixirScope with optional configuration overrides.\n\n**Options:**\n- `:strategy` - Instrumentation strategy (`:minimal`, `:balanced`, `:full_trace`)\n- `:sampling_rate` - Event sampling rate (0.0 to 1.0)\n- `:modules` - Specific modules to instrument\n- `:exclude_modules` - Modules to exclude from instrumentation\n\n**Examples:**\n\n```elixir\n# Start with default configuration\nElixirScope.start()\n\n# Start with full tracing for debugging\nElixirScope.start(strategy: :full_trace, sampling_rate: 1.0)\n\n# Start with minimal overhead for production\nElixirScope.start(strategy: :minimal, sampling_rate: 0.1)\n\n# Instrument only specific modules\nElixirScope.start(modules: [MyApp.Worker, MyApp.Server])\n```\n\n---\n\n```elixir\n@spec stop() :: :ok\ndef stop()\n```\n\nStops ElixirScope and all tracing.\n\n**Example:**\n\n```elixir\nElixirScope.stop()\n```\n\n---\n\n```elixir\n@spec status() :: map()\ndef status()\n```\n\nGets comprehensive system status including configuration, performance stats, and storage usage.\n\n**Returns:**\n\n```elixir\n%{\n  running: true,\n  timestamp: 1640995200000000000,\n  config: %{\n    strategy: :balanced,\n    sampling_rate: 1.0,\n    performance_target: 0.01,\n    ring_buffer_size: 1048576,\n    hot_storage_limit: 100000\n  },\n  stats: %{\n    events_captured: 12345,\n    events_per_second: 1250,\n    memory_usage: 2048576,\n    ring_buffer_utilization: 0.7\n  },\n  storage: %{\n    hot_events: 5000,\n    warm_events: 25000,\n    cold_events: 100000,\n    memory_usage: \"2.1 MB\",\n    disk_usage: \"15.3 MB\"\n  }\n}\n```\n\n---\n\n```elixir\n@spec running?() :: boolean()\ndef running?()\n```\n\nChecks if ElixirScope is currently active.\n\n**Example:**\n\n```elixir\nif ElixirScope.running?() do\n  # ElixirScope is active\n  events = ElixirScope.get_events(limit: 100)\nend\n```\n\n---","ref":"public_docs.html#elixirscope-main-module"},{"type":"extras","title":"Configuration Management - ElixirScope Public API Documentation","doc":"","ref":"public_docs.html#configuration-management"},{"type":"extras","title":"ElixirScope.Config - ElixirScope Public API Documentation","doc":"Centralized configuration management with validation and runtime updates.\n\n#### Configuration Access\n\n```elixir\n@spec get() :: ElixirScope.Config.t() | {:error, term()}\ndef get()\n```\n\nGets the complete current configuration.\n\n**Example:**\n\n```elixir\nconfig = ElixirScope.get_config()\nsampling_rate = config.ai.planning.sampling_rate\n```\n\n---\n\n```elixir\n@spec get([atom()]) :: term()\ndef get(path)\n```\n\nGets a specific configuration value by path.\n\n**Examples:**\n\n```elixir\n# Get AI provider\nprovider = ElixirScope.Config.get([:ai, :provider])\n# => :mock\n\n# Get ring buffer size\nbuffer_size = ElixirScope.Config.get([:capture, :ring_buffer, :size])\n# => 1048576\n\n# Get sampling rate\nsampling_rate = ElixirScope.Config.get([:ai, :planning, :sampling_rate])\n# => 1.0\n```\n\n---\n\n```elixir\n@spec update([atom()], term()) :: :ok | {:error, term()}\ndef update(path, value)\n```\n\nUpdates configuration at runtime. Only certain paths can be updated for safety.\n\n**Updatable Paths:**\n- `[:ai, :planning, :sampling_rate]`\n- `[:ai, :planning, :default_strategy]`\n- `[:capture, :processing, :batch_size]`\n- `[:capture, :processing, :flush_interval]`\n- `[:interface, :query_timeout]`\n\n**Examples:**\n\n```elixir\n# Update sampling rate\n:ok = ElixirScope.update_config([:ai, :planning, :sampling_rate], 0.8)\n\n# Update instrumentation strategy\n:ok = ElixirScope.update_config([:ai, :planning, :default_strategy], :full_trace)\n\n# Update query timeout\n:ok = ElixirScope.update_config([:interface, :query_timeout], 10_000)\n\n# Attempt to update non-updatable path (will fail)\n{:error, :not_updatable} = ElixirScope.update_config([:ai, :provider], :openai)\n```\n\n#### Configuration Structure\n\n```elixir\n%ElixirScope.Config{\n  ai: %{\n    provider: :mock | :gemini | :vertex,\n    api_key: String.t() | nil,\n    model: String.t(),\n    analysis: %{\n      max_file_size: pos_integer(),\n      timeout: pos_integer(),\n      cache_ttl: pos_integer()\n    },\n    planning: %{\n      default_strategy: :minimal | :balanced | :full_trace,\n      performance_target: float(),\n      sampling_rate: float()\n    }\n  },\n  capture: %{\n    ring_buffer: %{\n      size: pos_integer(),\n      max_events: pos_integer(),\n      overflow_strategy: :drop_oldest | :drop_newest | :block,\n      num_buffers: pos_integer() | :schedulers\n    },\n    processing: %{\n      batch_size: pos_integer(),\n      flush_interval: pos_integer(),\n      max_queue_size: pos_integer()\n    }\n  },\n  storage: %{\n    hot: %{\n      max_events: pos_integer(),\n      max_age_seconds: pos_integer(),\n      prune_interval: pos_integer()\n    },\n    warm: %{\n      enable: boolean(),\n      path: String.t(),\n      max_size_mb: pos_integer(),\n      compression: :zstd | :gzip | :none\n    }\n  },\n  interface: %{\n    iex_helpers: boolean(),\n    query_timeout: pos_integer(),\n    web: %{\n      enable: boolean(),\n      port: pos_integer()\n    }\n  }\n}\n```\n\n---","ref":"public_docs.html#elixirscope-config"},{"type":"extras","title":"Event Querying - ElixirScope Public API Documentation","doc":"> ⚠️ **Status**: The `ElixirScope.get_events/1` API currently returns `{:error, :not_implemented_yet}`. \n> For working event analysis, use the **TemporalBridge APIs** shown in the [Cinema Debugger](#cinema-debugger) section.","ref":"public_docs.html#event-querying"},{"type":"extras","title":"ElixirScope.get_events/1 - ElixirScope Public API Documentation","doc":"Primary interface for querying captured events. **[PLANNED - NOT YET IMPLEMENTED]**\n\n```elixir\n@spec get_events(keyword()) :: [ElixirScope.Events.t()] | {:error, term()}\ndef get_events(query \\\\ [])\n```\n\n**Query Options:**\n- `:pid` - Filter by process ID (`:all` for all processes)\n- `:event_type` - Filter by event type (`:all` for all types)\n- `:since` - Events since timestamp or DateTime\n- `:until` - Events until timestamp or DateTime\n- `:limit` - Maximum number of events to return\n\n**Examples:**\n\n```elixir\n# Get last 100 events for current process\nevents = ElixirScope.get_events(pid: self(), limit: 100)\n\n# Get all function entry events\nevents = ElixirScope.get_events(event_type: :function_entry)\n\n# Get events from the last minute\nsince = DateTime.utc_now() |> DateTime.add(-60, :second)\nevents = ElixirScope.get_events(since: since)\n\n# Get events in a specific time range\nstart_time = DateTime.utc_now() |> DateTime.add(-300, :second)\nend_time = DateTime.utc_now()\nevents = ElixirScope.get_events(since: start_time, until: end_time, limit: 1000)\n\n# Get all events for a specific process\nevents = ElixirScope.get_events(pid: worker_pid, limit: 500)\n```","ref":"public_docs.html#elixirscope-get_events-1"},{"type":"extras","title":"State History Queries - ElixirScope Public API Documentation","doc":"```elixir\n@spec get_state_history(pid()) :: [ElixirScope.Events.StateChange.t()] | {:error, term()}\ndef get_state_history(pid)\n```\n\nGets the complete state change history for a GenServer process.\n\n**Example:**\n\n```elixir\n# Get state history for a GenServer\n{:ok, worker} = MyApp.Worker.start_link()\nhistory = ElixirScope.get_state_history(worker)\n\n# Each entry shows state transitions\n[\n  %ElixirScope.Events.StateChange{\n    timestamp: 1640995200000000000,\n    old_state: %{count: 0},\n    new_state: %{count: 1},\n    reason: {:handle_cast, :increment}\n  },\n  # ... more state changes\n]\n```\n\n---\n\n```elixir\n@spec get_state_at(pid(), integer()) :: term() | {:error, term()}\ndef get_state_at(pid, timestamp)\n```\n\nReconstructs the state of a GenServer at a specific timestamp (time-travel debugging). **[PLANNED - NOT YET IMPLEMENTED]**\n\n> ⚠️ **Use TemporalBridge instead**: `ElixirScope.Capture.TemporalBridge.reconstruct_state_at/2` provides working time-travel debugging.\n\n**Example:**\n\n```elixir\n# Get state at a specific point in time\ntimestamp = System.monotonic_time(:nanosecond) - 60_000_000_000  # 60 seconds ago\nstate = ElixirScope.get_state_at(worker_pid, timestamp)\n# => %{count: 42, status: :active}\n```","ref":"public_docs.html#state-history-queries"},{"type":"extras","title":"Message Flow Analysis - ElixirScope Public API Documentation","doc":"```elixir\n@spec get_message_flow(pid(), pid(), keyword()) :: [ElixirScope.Events.MessageSend.t()] | {:error, term()}\ndef get_message_flow(sender_pid, receiver_pid, opts \\\\ [])\n```\n\nGets message flow between two processes.\n\n**Options:**\n- `:since` - Start timestamp\n- `:until` - End timestamp\n- `:limit` - Maximum messages to return\n\n**Examples:**\n\n```elixir\n# Get all messages between two processes\nmessages = ElixirScope.get_message_flow(sender_pid, receiver_pid)\n\n# Get messages in a time range\nstart_time = DateTime.utc_now() |> DateTime.add(-300, :second)\nend_time = DateTime.utc_now()\nmessages = ElixirScope.get_message_flow(\n  sender_pid, \n  receiver_pid, \n  since: start_time, \n  until: end_time\n)\n\n# Analyze message patterns\nmessages\n|> Enum.group_by(& &1.message_type)\n|> Enum.map(fn {type, msgs} -> {type, length(msgs)} end)\n# => [call: 45, cast: 23, info: 12]\n```\n\n---","ref":"public_docs.html#message-flow-analysis"},{"type":"extras","title":"Cinema Debugger - ElixirScope Public API Documentation","doc":"The Cinema Debugger provides time-travel debugging capabilities with AST correlation.","ref":"public_docs.html#cinema-debugger"},{"type":"extras","title":"TemporalStorage - ElixirScope Public API Documentation","doc":"High-performance temporal event storage with AST correlation.\n\n```elixir\n# Start temporal storage\n{:ok, storage} = ElixirScope.Capture.TemporalStorage.start_link()\n\n# Store events with temporal indexing\nevent = %{\n  timestamp: System.monotonic_time(:nanosecond),\n  ast_node_id: \"MyModule:my_function:42:function_def\",\n  correlation_id: \"corr_123\",\n  data: %{type: :function_entry, args: [1, 2, 3]}\n}\n:ok = ElixirScope.Capture.TemporalStorage.store_event(storage, event)\n\n# Query events by time range\n{:ok, events} = ElixirScope.Capture.TemporalStorage.get_events_in_range(\n  storage, \n  start_time, \n  end_time\n)\n\n# Query events for specific AST node\n{:ok, node_events} = ElixirScope.Capture.TemporalStorage.get_events_for_ast_node(\n  storage, \n  \"MyModule:my_function:42:function_def\"\n)\n```","ref":"public_docs.html#temporalstorage"},{"type":"extras","title":"TemporalBridge - ElixirScope Public API Documentation","doc":"Bridges runtime events with temporal storage for Cinema Debugger functionality.\n\n```elixir\n# Start temporal bridge\n{:ok, bridge} = ElixirScope.Capture.TemporalBridge.start_link(\n  name: :my_bridge,\n  buffer_size: 1000,\n  flush_interval: 100\n)\n\n# Register as event handler\n:ok = ElixirScope.Capture.TemporalBridge.register_as_handler(bridge)\n\n# Query current execution state\n{:ok, state} = ElixirScope.Capture.TemporalBridge.query_current_state(bridge)\n\n# Reconstruct state at specific time\n{:ok, historical_state} = ElixirScope.Capture.TemporalBridge.reconstruct_state_at(\n  bridge, \n  timestamp\n)\n\n# Time-travel debugging: replay events\n{:ok, replay_state} = ElixirScope.Capture.TemporalBridge.replay_events_for_state(\n  bridge,\n  start_time,\n  end_time\n)\n```","ref":"public_docs.html#temporalbridge"},{"type":"extras","title":"Cinema Demo Usage - ElixirScope Public API Documentation","doc":"```elixir\n# Run comprehensive demo scenarios\nresult = CinemaDemo.run_full_demo()\n\n# Individual demo scenarios\ntask_result = CinemaDemo.run_task_management_demo()\ndata_result = CinemaDemo.run_data_processing_demo()\nnested_result = CinemaDemo.run_complex_nested_operations_demo()\nerror_result = CinemaDemo.run_error_handling_demo()\nperf_result = CinemaDemo.run_performance_analysis_demo()\ntime_travel_result = CinemaDemo.run_time_travel_debugging_demo()\n\n# Each result contains:\n%{\n  demo_type: :task_management,\n  execution_time_ms: 1250,\n  events_captured: 45,\n  tasks_processed: 4,\n  success_rate: 1.0,\n  statistics: %{...}\n}\n```\n\n---","ref":"public_docs.html#cinema-demo-usage"},{"type":"extras","title":"Phoenix Integration - ElixirScope Public API Documentation","doc":"> ⚠️ **Status**: Phoenix integration is **PLANNED** for future releases. The APIs shown below are not yet implemented.\n\nElixirScope provides specialized Phoenix integration for web applications. **[PLANNED - NOT YET IMPLEMENTED]**","ref":"public_docs.html#phoenix-integration"},{"type":"extras","title":"Setup - ElixirScope Public API Documentation","doc":"```elixir\n# In your Phoenix application\ndefmodule MyAppWeb.Application do\n  def start(_type, _args) do\n    children = [\n      MyAppWeb.Endpoint,\n      # Add ElixirScope\n      {ElixirScope, [\n        capture: [buffer_size: 20_000],\n        ai: [provider: :gemini]\n      ]}\n    ]\n    \n    opts = [strategy: :one_for_one, name: MyAppWeb.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```","ref":"public_docs.html#setup"},{"type":"extras","title":"Enable Phoenix Instrumentation - ElixirScope Public API Documentation","doc":"```elixir\n# Enable Phoenix-specific tracing\nElixirScope.Phoenix.Integration.enable()\n\n# Disable when not needed\nElixirScope.Phoenix.Integration.disable()\n```","ref":"public_docs.html#enable-phoenix-instrumentation"},{"type":"extras","title":"Instrumented Components - ElixirScope Public API Documentation","doc":"**HTTP Requests:**\n- Request start/stop with timing\n- Controller action entry/exit\n- Route dispatch timing\n- Response size and status codes\n\n**LiveView:**\n- Mount lifecycle\n- Event handling (`handle_event`, `handle_info`)\n- State changes and assigns tracking\n- Render performance\n\n**Channels:**\n- Channel join/leave events\n- Message handling\n- Real-time communication patterns\n\n**Ecto Queries:**\n- Query execution timing\n- Parameter binding\n- Result set analysis\n- Database correlation","ref":"public_docs.html#instrumented-components"},{"type":"extras","title":"Phoenix Query Examples - ElixirScope Public API Documentation","doc":"```elixir\n# Get all HTTP requests in the last hour\nrequests = ElixirScope.get_events(\n  event_type: :phoenix_request_start,\n  since: DateTime.utc_now() |> DateTime.add(-3600, :second)\n)\n\n# Analyze controller performance\ncontroller_events = ElixirScope.get_events(event_type: :phoenix_controller_entry)\n|> Enum.group_by(fn event -> \n  {event.data.controller, event.data.action} \nend)\n|> Enum.map(fn {{controller, action}, events} ->\n  avg_duration = events \n    |> Enum.map(& &1.data.duration_ms) \n    |> Enum.sum() \n    |> div(length(events))\n  \n  {controller, action, avg_duration, length(events)}\nend)\n\n# LiveView event analysis\nliveview_events = ElixirScope.get_events(event_type: :liveview_handle_event)\n|> Enum.group_by(& &1.data.event)\n|> Enum.map(fn {event_name, events} -> \n  {event_name, length(events)} \nend)\n```\n\n---","ref":"public_docs.html#phoenix-query-examples"},{"type":"extras","title":"AST Repository - ElixirScope Public API Documentation","doc":"The AST Repository provides static analysis integration with runtime correlation.","ref":"public_docs.html#ast-repository"},{"type":"extras","title":"Repository Management - ElixirScope Public API Documentation","doc":"```elixir\n# Start AST repository\n{:ok, repo} = ElixirScope.ASTRepository.Repository.start_link()\n\n# Store module data\nmodule_data = ElixirScope.ASTRepository.ModuleData.new(MyModule, ast)\n:ok = ElixirScope.ASTRepository.Repository.store_module(repo, module_data)\n\n# Get module information\n{:ok, module_data} = ElixirScope.ASTRepository.Repository.get_module(repo, MyModule)\n\n# Store function data\nfunction_data = ElixirScope.ASTRepository.FunctionData.new(\n  {MyModule, :my_function, 2}, \n  function_ast\n)\n:ok = ElixirScope.ASTRepository.Repository.store_function(repo, function_data)\n\n# Get repository statistics\n{:ok, stats} = ElixirScope.ASTRepository.Repository.get_statistics(repo)\n```","ref":"public_docs.html#repository-management"},{"type":"extras","title":"Runtime Correlation - ElixirScope Public API Documentation","doc":"```elixir\n# Start runtime correlator\n{:ok, correlator} = ElixirScope.ASTRepository.RuntimeCorrelator.start_link(\n  repository_pid: repo\n)\n\n# Correlate runtime event with AST\nruntime_event = %{\n  correlation_id: \"corr_123\",\n  module: MyModule,\n  function: :my_function,\n  timestamp: System.monotonic_time(:nanosecond)\n}\n\n{:ok, {correlation_id, ast_node_id}} = \n  ElixirScope.ASTRepository.RuntimeCorrelator.correlate_event(correlator, runtime_event)\n\n# Get events for specific AST node\n{:ok, events} = ElixirScope.ASTRepository.RuntimeCorrelator.get_events_for_ast_node(\n  correlator, \n  ast_node_id\n)\n\n# Query temporal events\n{:ok, temporal_events} = ElixirScope.ASTRepository.RuntimeCorrelator.query_temporal_events(\n  correlator,\n  start_time,\n  end_time\n)\n\n# Get correlation statistics\n{:ok, stats} = ElixirScope.ASTRepository.RuntimeCorrelator.get_statistics(correlator)\n```","ref":"public_docs.html#runtime-correlation"},{"type":"extras","title":"AST Analysis - ElixirScope Public API Documentation","doc":"```elixir\n# Parse module AST with instrumentation points\n{:ok, {ast, instrumentation_points}} = \n  ElixirScope.ASTRepository.Parser.parse_module_with_instrumentation(MyModule)\n\n# Get instrumentation recommendations\n{:ok, recommendations} = ElixirScope.Core.AIManager.recommend_instrumentation([MyModule])\n\n# Analyze codebase\n{:ok, analysis} = ElixirScope.analyze_codebase(modules: [MyModule, OtherModule])\n```\n\n---","ref":"public_docs.html#ast-analysis"},{"type":"extras","title":"Performance Monitoring - ElixirScope Public API Documentation","doc":"","ref":"public_docs.html#performance-monitoring"},{"type":"extras","title":"System Metrics - ElixirScope Public API Documentation","doc":"```elixir\n# Get performance statistics\nstats = ElixirScope.status()\n\n# Memory usage breakdown\nmemory_stats = %{\n  total_usage_mb: 48.2,\n  repository_mb: 32.1,\n  correlation_cache_mb: 8.4,\n  event_buffer_mb: 7.7\n}\n\n# Throughput metrics\nthroughput_stats = %{\n  events_per_second: 12_500,\n  correlations_per_second: 11_200,\n  queries_per_second: 450\n}\n\n# Correlation accuracy\ncorrelation_stats = %{\n  total_events: 125_000,\n  successful_correlations: 121_875,\n  accuracy: 0.975,\n  avg_latency_ms: 1.8,\n  p95_latency_ms: 4.1,\n  p99_latency_ms: 8.7\n}\n```","ref":"public_docs.html#system-metrics"},{"type":"extras","title":"Health Monitoring - ElixirScope Public API Documentation","doc":"```elixir\n# System health check\nhealth = ElixirScope.status()\ncase health do\n  %{running: true, stats: %{events_per_second: eps}} when eps > 1000 ->\n    IO.puts(\"System healthy - high throughput\")\n  \n  %{running: true, stats: %{memory_usage: mem}} when mem > 1_000_000_000 ->\n    IO.puts(\"Warning - high memory usage\")\n  \n  %{running: false} ->\n    IO.puts(\"ElixirScope not running\")\nend\n\n# Component health\n{:ok, repo_health} = ElixirScope.ASTRepository.Repository.health_check(repo)\n{:ok, correlator_health} = ElixirScope.ASTRepository.RuntimeCorrelator.health_check(correlator)\n```","ref":"public_docs.html#health-monitoring"},{"type":"extras","title":"Performance Tuning - ElixirScope Public API Documentation","doc":"```elixir\n# Adjust sampling rate for performance\nElixirScope.update_config([:ai, :planning, :sampling_rate], 0.1)  # 10% sampling\n\n# Increase buffer size for high-throughput applications\nElixirScope.update_config([:capture, :processing, :batch_size], 2000)\n\n# Adjust flush interval for latency vs throughput trade-off\nElixirScope.update_config([:capture, :processing, :flush_interval], 50)  # 50ms\n```\n\n---","ref":"public_docs.html#performance-tuning"},{"type":"extras","title":"Advanced Usage - ElixirScope Public API Documentation","doc":"","ref":"public_docs.html#advanced-usage"},{"type":"extras","title":"Custom Event Types - ElixirScope Public API Documentation","doc":"```elixir\n# Define custom event structure\ndefmodule MyApp.CustomEvent do\n  defstruct [:custom_field, :timestamp, :metadata]\nend\n\n# Ingest custom events\ncustom_event = %MyApp.CustomEvent{\n  custom_field: \"important_data\",\n  timestamp: System.monotonic_time(:nanosecond),\n  metadata: %{source: :my_system}\n}\n\n# Store via ring buffer\n{:ok, buffer} = ElixirScope.Capture.RingBuffer.new(size: 1024)\n:ok = ElixirScope.Capture.RingBuffer.write(buffer, custom_event)\n```","ref":"public_docs.html#custom-event-types"},{"type":"extras","title":"Distributed Tracing - ElixirScope Public API Documentation","doc":"```elixir\n# Synchronize events across cluster nodes\ncluster_nodes = [:\"app@node1\", :\"app@node2\", :\"app@node3\"]\n{:ok, sync_results} = ElixirScope.Distributed.EventSynchronizer.sync_with_cluster(cluster_nodes)\n\n# Force full synchronization\n{:ok, full_sync_results} = ElixirScope.Distributed.EventSynchronizer.full_sync_with_cluster(cluster_nodes)\n\n# Get distributed correlation\n{:ok, distributed_events} = ElixirScope.Distributed.EventSynchronizer.get_distributed_events(\n  correlation_id,\n  cluster_nodes\n)\n```","ref":"public_docs.html#distributed-tracing"},{"type":"extras","title":"AI Integration - ElixirScope Public API Documentation","doc":"```elixir\n# Configure AI provider\nElixirScope.AI.LLM.Config.get_primary_provider()\n# => :gemini\n\n# Analyze codebase with AI\n{:ok, analysis} = ElixirScope.analyze_codebase()\n\n# Get AI recommendations\n{:ok, recommendations} = ElixirScope.Core.AIManager.recommend_instrumentation([MyModule])\n\n# Update instrumentation based on AI analysis\n{:ok, updated_plan} = ElixirScope.update_instrumentation(\n  strategy: :balanced,\n  add_modules: [NewModule]\n)\n```\n\n---","ref":"public_docs.html#ai-integration"},{"type":"extras","title":"Error Handling - ElixirScope Public API Documentation","doc":"","ref":"public_docs.html#error-handling"},{"type":"extras","title":"Common Error Patterns - ElixirScope Public API Documentation","doc":"```elixir\n# Handle ElixirScope not running\ncase ElixirScope.get_events(limit: 100) do\n  {:error, :not_running} ->\n    IO.puts(\"ElixirScope is not started\")\n    ElixirScope.start()\n    \n  events when is_list(events) ->\n    IO.puts(\"Got #{length(events)} events\")\n    \n  {:error, reason} ->\n    IO.puts(\"Error: #{inspect(reason)}\")\nend\n\n# Handle configuration errors\ncase ElixirScope.update_config([:ai, :planning, :sampling_rate], 1.5) do\n  :ok ->\n    IO.puts(\"Configuration updated\")\n    \n  {:error, reason} ->\n    IO.puts(\"Configuration error: #{inspect(reason)}\")\nend\n\n# Handle correlation failures\ncase ElixirScope.ASTRepository.RuntimeCorrelator.correlate_event(correlator, event) do\n  {:ok, {correlation_id, ast_node_id}} ->\n    IO.puts(\"Correlated: #{correlation_id} -> #{ast_node_id}\")\n    \n  {:error, :no_correlation_id} ->\n    IO.puts(\"Event missing correlation ID\")\n    \n  {:error, :not_found} ->\n    IO.puts(\"No AST correlation found\")\n    \n  {:error, reason} ->\n    IO.puts(\"Correlation failed: #{inspect(reason)}\")\nend\n```","ref":"public_docs.html#common-error-patterns"},{"type":"extras","title":"Error Recovery - ElixirScope Public API Documentation","doc":"```elixir\n# Graceful degradation\ndefmodule MyApp.SafeTracing do\n  def trace_function(module, function, args) do\n    if ElixirScope.running?() do\n      try do\n        # Attempt to trace\n        ElixirScope.Capture.InstrumentationRuntime.report_function_entry(\n          module, function, args, self()\n        )\n      rescue\n        error ->\n          Logger.warning(\"Tracing failed: #{inspect(error)}\")\n          :ok  # Continue execution\n      end\n    else\n      :ok  # No tracing when not running\n    end\n  end\nend\n```\n\n---","ref":"public_docs.html#error-recovery"},{"type":"extras","title":"Best Practices - ElixirScope Public API Documentation","doc":"","ref":"public_docs.html#best-practices"},{"type":"extras","title":"Performance Optimization - ElixirScope Public API Documentation","doc":"1. **Sampling Strategy:**\n   ```elixir\n   # Production: Use minimal sampling\n   ElixirScope.start(strategy: :minimal, sampling_rate: 0.1)\n   \n   # Development: Use balanced approach\n   ElixirScope.start(strategy: :balanced, sampling_rate: 0.5)\n   \n   # Debugging: Use full tracing\n   ElixirScope.start(strategy: :full_trace, sampling_rate: 1.0)\n   ```\n\n2. **Memory Management:**\n   ```elixir\n   # Configure appropriate buffer sizes\n   config :elixir_scope,\n     capture: [\n       ring_buffer: [\n         size: 2_097_152,      # 2MB for high-throughput\n         max_events: 200_000   # Adjust based on memory constraints\n       ]\n     ]\n   ```\n\n3. **Query Optimization:**\n   ```elixir\n   # Use specific time ranges\n   events = ElixirScope.get_events(\n     since: DateTime.utc_now() |> DateTime.add(-300, :second),\n     until: DateTime.utc_now(),\n     limit: 1000\n   )\n   \n   # Filter by process for focused analysis\n   events = ElixirScope.get_events(pid: worker_pid, limit: 500)\n   ```","ref":"public_docs.html#performance-optimization"},{"type":"extras","title":"Production Deployment - ElixirScope Public API Documentation","doc":"1. **Configuration:**\n   ```elixir\n   # config/prod.exs\n   config :elixir_scope,\n     ai: [\n       provider: :mock,  # Disable AI in production\n       planning: [\n         default_strategy: :minimal,\n         sampling_rate: 0.05  # 5% sampling\n       ]\n     ],\n     storage: [\n       hot: [\n         max_events: 50_000,\n         max_age_seconds: 1800  # 30 minutes\n       ]\n     ]\n   ```\n\n2. **Monitoring:**\n   ```elixir\n   # Regular health checks\n   defmodule MyApp.ElixirScopeMonitor do\n     use GenServer\n     \n     def init(_) do\n       :timer.send_interval(30_000, :health_check)\n       {:ok, %{}}\n     end\n     \n     def handle_info(:health_check, state) do\n       case ElixirScope.status() do\n         %{running: true, stats: %{memory_usage: mem}} when mem > 100_000_000 ->\n           Logger.warning(\"ElixirScope high memory usage: #{mem}\")\n         \n         %{running: false} ->\n           Logger.error(\"ElixirScope not running\")\n         \n         _ ->\n           :ok\n       end\n       \n       {:noreply, state}\n     end\n   end\n   ```","ref":"public_docs.html#production-deployment"},{"type":"extras","title":"Development Workflow - ElixirScope Public API Documentation","doc":"1. **Testing Integration:**\n   ```elixir\n   # test/test_helper.exs\n   ExUnit.start()\n   \n   # Configure for testing\n   Application.put_env(:elixir_scope, :test_mode, true)\n   \n   # Start ElixirScope for integration tests\n   if System.get_env(\"ELIXIR_SCOPE_TESTS\") == \"true\" do\n     ElixirScope.start(strategy: :balanced, sampling_rate: 1.0)\n   end\n   ```\n\n2. **Debugging Sessions:**\n   ```elixir\n   # Start with full tracing\n   ElixirScope.start(strategy: :full_trace)\n   \n   # Run problematic code\n   MyApp.problematic_function()\n   \n   # Analyze events\n   events = ElixirScope.get_events(\n     since: DateTime.utc_now() |> DateTime.add(-60, :second),\n     limit: 1000\n   )\n   \n   # Focus on specific process\n   process_events = ElixirScope.get_events(pid: problematic_pid)\n   \n   # Time-travel debugging\n   historical_state = ElixirScope.get_state_at(pid, timestamp)\n   ```","ref":"public_docs.html#development-workflow"},{"type":"extras","title":"Security Considerations - ElixirScope Public API Documentation","doc":"1. **Data Sanitization:**\n   ```elixir\n   # ElixirScope automatically truncates large data\n   # Configure truncation limits\n   config :elixir_scope,\n     capture: [\n       processing: [\n         max_data_size: 1024,  # Truncate data larger than 1KB\n         sanitize_sensitive: true\n       ]\n     ]\n   ```\n\n2. **Access Control:**\n   ```elixir\n   # Restrict ElixirScope access in production\n   defmodule MyApp.ElixirScopeAuth do\n     def authorized?(user) do\n       user.role in [:admin, :developer] and \n       Application.get_env(:my_app, :environment) != :production\n     end\n   end\n   ```\n\n---","ref":"public_docs.html#security-considerations"},{"type":"extras","title":"API Reference Summary - ElixirScope Public API Documentation","doc":"","ref":"public_docs.html#api-reference-summary"},{"type":"extras","title":"Core Functions - ElixirScope Public API Documentation","doc":"| Function | Description | Returns |\n|----------|-------------|---------|\n| `ElixirScope.start/1` | Start ElixirScope with options | `:ok \\| {:error, term()}` |\n| `ElixirScope.stop/0` | Stop ElixirScope | `:ok` |\n| `ElixirScope.status/0` | Get system status | `map()` |\n| `ElixirScope.running?/0` | Check if running | `boolean()` |\n| `ElixirScope.get_events/1` | Query events | `[event()] \\| {:error, term()}` |\n| `ElixirScope.get_config/0` | Get configuration | `Config.t() \\| {:error, term()}` |\n| `ElixirScope.update_config/2` | Update configuration | `:ok \\| {:error, term()}` |","ref":"public_docs.html#core-functions"},{"type":"extras","title":"Event Querying - ElixirScope Public API Documentation","doc":"| Function | Description | Returns |\n|----------|-------------|---------|\n| `get_state_history/1` | Get GenServer state history | `[StateChange.t()] \\| {:error, term()}` |\n| `get_state_at/2` | Get state at timestamp | `term() \\| {:error, term()}` |\n| `get_message_flow/3` | Get message flow between processes | `[MessageSend.t()] \\| {:error, term()}` |","ref":"public_docs.html#event-querying-1"},{"type":"extras","title":"Configuration - ElixirScope Public API Documentation","doc":"| Function | Description | Returns |\n|----------|-------------|---------|\n| `Config.get/0` | Get full configuration | `Config.t()` |\n| `Config.get/1` | Get configuration by path | `term()` |\n| `Config.update/2` | Update configuration path | `:ok \\| {:error, term()}` |\n| `Config.validate/1` | Validate configuration | `:ok \\| {:error, term()}` |","ref":"public_docs.html#configuration-1"},{"type":"extras","title":"Phoenix Integration - ElixirScope Public API Documentation","doc":"| Function | Description | Returns |\n|----------|-------------|---------|\n| `Phoenix.Integration.enable/0` | Enable Phoenix tracing | `:ok` |\n| `Phoenix.Integration.disable/0` | Disable Phoenix tracing | `:ok` |\n\n---\n\n**For more detailed examples and advanced usage patterns, see the [Cinema Demo Application](https://github.com/nshkrdotcom/ElixirScope/tree/main/test_apps/cinema_demo) and [Integration Tests](https://github.com/nshkrdotcom/ElixirScope/blob/main/test/elixir_scope/capture/instrumentation_runtime_integration_test.exs).**\n\n**Support**: For issues and questions, please refer to the project repository and documentation.","ref":"public_docs.html#phoenix-integration-1"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}